@@ -76,8 +76,6 @@
 #include <sinfo_msg.h>
 #include <sinfo_error.h>
 #include <sinfo_utils_wrappers.h>
-//Only for sinfo_propertylist_has
-#include <sinfo_dfs.h>
 
 
 
@@ -393,7 +391,7 @@ sinfo_rec_distortion(cpl_parameterlist *config, cpl_frameset *set)
     cknull(plist = cpl_propertylist_load(file_name, 0),
            "getting header from reference ima frame %s",file_name);
 
-    if (sinfo_propertylist_has(plist, KEY_NAME_LAMP_HALO)) {
+    if (cpl_propertylist_has(plist, KEY_NAME_LAMP_HALO)) {
         cpl_propertylist_set_bool(plist, KEY_NAME_LAMP_HALO, LAMP_OFF);
     } else {
         cpl_propertylist_append_bool(plist, KEY_NAME_LAMP_HALO,LAMP_OFF);
@@ -655,13 +653,12 @@ new_pre_process(cpl_frameset* set,
 
     int nf=0;
     int ng=10;
-    int ns=0;
-    int nr=0;
+
+
     int nt=0;
 
     int i=0;
-    int j=0;
-    int k=0;
+
     int lo_cut=0;
     int hi_cut=0;
 
@@ -673,13 +670,11 @@ new_pre_process(cpl_frameset* set,
     char* file_name=NULL;
 
     cpl_propertylist* plist=NULL;
-    cpl_imagelist* imset_tmp=NULL;
+
     cpl_imagelist* imset_tot=NULL;
     cpl_image** avg_img_list=NULL;
 
     cpl_image* img=NULL;
-    cpl_image* img_tmp=NULL;
-    cpl_image* img_dup=NULL;
 
     cpl_image** img_list=NULL;
 
@@ -709,24 +704,25 @@ new_pre_process(cpl_frameset* set,
     if( nf > ng) {
 
         sinfo_msg("Total raw frames nf=%d > max frm per group ng=%d",nf,ng);
-        ns = (nf+1)/ng;
-        nr = nf-ns*ng;
+        int ns = (nf+1)/ng;
+        int nr = nf-ns*ng;
         imset_tot=cpl_imagelist_new();
         avg_img_list=cpl_malloc((ns+1) * sizeof(cpl_image *));
 
-
+        int k=0;
+        cpl_imagelist* imset_tmp=NULL;
         for (i=0;i<ns;i++) {
             sinfo_msg("iteration i=%d\n",i);
             imset_tmp=cpl_imagelist_new();
             img_list=cpl_malloc(ng * sizeof(cpl_image *));
 
 
-            for (j=0;j<ng;j++) {
+            for (int j=0;j<ng;j++) {
                 k=i*ng+j;
                 frame = cpl_frameset_get_frame(fibre_raw_set,k);
                 file_name=(char*)cpl_frame_get_filename(frame);
-                img_tmp=cpl_image_load(file_name,CPL_TYPE_FLOAT,0,0);
-                img_dup=cpl_image_duplicate(img_tmp);
+                cpl_image* img_tmp=cpl_image_load(file_name,CPL_TYPE_FLOAT,0,0);
+                cpl_image* img_dup=cpl_image_duplicate(img_tmp);
                 cpl_imagelist_set(imset_tmp,img_dup,j);
                 cpl_image_delete(img_tmp);
             }
