@@ -22,15 +22,6 @@
  * $Date: 2012-03-02 08:42:20 $
  * $Revision: 1.3 $
  * $Name: not supported by cvs2svn $
- * $Log: not supported by cvs2svn $
- * Revision 1.2  2009/04/28 11:42:18  amodigli
- * now return cpl_error_code
- *
- * Revision 1.1  2009/01/02 08:27:58  amodigli
- * added to repository
- *
- * Revision 1.8  2007/06/06 08:17:33  amodigli
- * replace tab with 4 spaces
  *
  */
 
@@ -430,12 +421,12 @@ void barvel(double DJE, double DEQ,
 	    double DVELH[4], double DVELB[4])
 {
   double sn[5];
-  double DT,DTL,DTSQ,DLOCAL;
+  double DT,DTL,DTSQ;
   double DRD,DRLD;
   double DXBD,DYBD,DZBD,DZHD,DXHD,DYHD;
   double DYAHD,DZAHD,DYABD,DZABD;
-  double DML,DEPS,PHI,PHID,PSID,DPARAM,PARAM;
-  double PLON,POMG,PECC;
+  double DEPS,PHI,PHID,PSID,DPARAM,PARAM;
+
   double PERTL,PERTLD,PERTRD,PERTP,PERTR,PERTPD;
   double SINA,TL;
   double COSA,ESQ;
@@ -565,14 +556,16 @@ void barvel(double DJE, double DEQ,
 
   TSQ=DTSQ;
 
-  DML = 0;  /* Suppress warning */
-  for (K = 1; K <= 8; K++) {
+  double DML = 0;  /* Suppress warning */
 
-    DLOCAL=fmod(DCFEL(1,K)+DT*DCFEL(2,K)+DTSQ*DCFEL(3,K),DC2PI);
+  /* special case K == 1 */
+  DML=fmod(DCFEL(1,1)+DT*DCFEL(2,1)+DTSQ*DCFEL(3,1),DC2PI);
 
-    if (K == 1)  DML=DLOCAL;
+  /* other cases K> 1 */
+  for (K = 2; K <= 8; K++) {
+
+    FORBEL(K-1)=fmod(DCFEL(1,K)+DT*DCFEL(2,K)+DTSQ*DCFEL(3,K),DC2PI);
 
-    if (K != 1)  FORBEL(K-1)=DLOCAL;
   }
 
   DEPS=fmod(DCEPS(1)+DT*DCEPS(2)+DTSQ*DCEPS(3), DC2PI);
@@ -710,11 +703,11 @@ void barvel(double DJE, double DEQ,
 
   for (K = 1; K <= 4; K++) {
 
-    PLON=FORBEL(K+3);
+    double PLON=FORBEL(K+3);
 
-    POMG=SORBEL(K+1);
+    double POMG=SORBEL(K+1);
 
-    PECC=SORBEL(K+9);
+    double PECC=SORBEL(K+9);
 
     TL=fmod(PLON+2.0*PECC* sin(PLON-POMG), CC2PI);
 
