@@ -19,134 +19,11 @@
 /*************************************************************************
  * E.S.O. - VLT project
  *
- *
- *
  * who       when      what
  * --------  --------  ----------------------------------------------
  * schreib  27/02/01  created
  */
 
-/************************************************************************
- *   NAME
- *        new_boltzmann.c -
- *        routines to determine the absolute positions of the slitlets out
- *        of an emission line frame
- *
- *   SYNOPSIS
- *   #include "absolute.h"
- *
- *   1) float sinfo_new_boltz ( float * xdat, float * parlist )
- *   2) void sinfo_new_boltz_deriv( float * xdat, float * parlist,
-                                   float * dervs )
- *   3) static int sinfo_new_inv_mat (void)
- *   4) static void sinfo_new_get_mat ( float * xdat,
- *                            int   * xdim,
- *                            float * ydat,
- *                            float * wdat,
- *                            int   * ndat,
- *                            float * fpar,
- *                            float * epar,
- *                            int   * npar )
- *   5) static int sinfo_new_get_vec ( float * xdat,
- *                           int   * xdim,
- *                           float * ydat,
- *                           float * wdat,
- *                           int   * ndat,
- *                           float * fpar,
- *                           float * epar,
- *                           int   * npar )
- *   6) int sinfo_new_lsqfit ( float * xdat,
- *                   int   * xdim,
- *                   float * ydat,
- *                   float * wdat,
- *                   int   * ndat,
- *                   float * fpar,
- *                   float * epar,
- *                   int   * mpar,
- *                   int   * npar,
- *                   float * tol ,
- *                   int   * its ,
- *                   float * lab  )
- *   7) int sinfo_new_fit_slits_boltz( cpl_image   * lineImage,
- *                         FitParams ** par,
- *                         float     ** slit_pos,
- *                         int          box_length,
- *                         float        y_box,
- *                         float        diff_tol )
- *   8) int sinfo_new_fit_slits_boltz_single_line ( cpl_image   * lineImage,
- *                                    float     ** slit_pos,
- *                                    int          box_length,
- *                                    float        y_box,
- *                                int          low_pos,
- *                                    int          high_pos )
- *   9) int sinfo_new_fit_slits_boltz_with_estimate ( cpl_image   * lineImage,
- *                                      float     ** slit_pos,
- *                                      int          box_length,
- *                                      float        y_box,
- *                                      float        diff_tol,
- *                                      int          low_pos,
- *                           int          high_pos )
- *
- *   DESCRIPTION
- *   1) calculates the value of a Boltzmann function with parameters
- *      parlist at the position xdat
- *   2) calculates the partial derivatives for a Boltzmann function with
- *      parameters parlist at position xdat
- *   3) calculates the inverse of matrix2. The algorithm used
- *      is the Gauss-Jordan algorithm described in Stoer,
- *      Numerische Mathematik, 1. Teil.
- *   4) builds the sinfo_matrix
- *   5) calculates the correction sinfo_vector. The sinfo_matrix has been
- *      built by get_mat(), we only have to rescale it for the
- *      current value of labda. The sinfo_matrix is rescaled so that
- *      the diagonal gets the value 1 + labda.
- *      Next we calculate the inverse of the sinfo_matrix and then
- *      the correction sinfo_vector.
- *   6) this is a routine for making a least-squares fit of a
- *      function to a set of data points. The method used is
- *      described in: Marquardt, J.Soc.Ind.Appl.Math. 11. 431 (1963).
- *      This method is a mixture of the steepest descent method
- *      and the Taylor method.
- *   7) fits the beginning and end position of the slitlets
- *      by using non-linear least square fitting of Boltzmann function
- *      fits a Boltzmann function to the slitlet edges exposed and indicated
- *      by the brightest emission lines. To achieve this, the fit
- *      parameters are used to find the brightest emission line
- *      and to get its position for each column.
- *      The least squares fit is done by using a box smaller than
- *      the size of two slitlets
- *   8) fits the beginning and end position of the slitlets
- *      by using non-linear least square fitting of a Boltzmann function
- *      fits a Boltzmann function to the slitlet edges exposed and indicated
- *      by the brightest emission lines. The slitlet is searched within
- *      user given positions.
- *      The least squares fit is done by using a box smaller than
- *      the size of two slitlets
- *   9) fits the beginning and end position of the slitlets
- *      by using non-linear least square fitting of a Boltzmann function
- *      fits a Boltzmann function to the slitlet edges exposed and indicated
- *      by the brightest emission lines. The slitlet is searched within
- *      user given positions.
- *      The least squares fit is done by using a box smaller than
- *      the size of two slitlets
- *
- *   FILES
- *
- *   ENVIRONMENT
- *
- *   RETURN VALUES
- *
- *   CAUTIONS
- *
- *   EXAMPLES
- *
- *   SEE ALSO
- *
- *   BUGS
- *
- *------------------------------------------------------------------------
- */
-
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
@@ -215,7 +92,8 @@ static int sinfo_new_get_vec ( float * xdat,
 /**
  * @defgroup sinfo_boltzmann Boltzmann function operations
  *
- * TBD
+ * routines to determine the absolute positions of the slitlets out of an
+ * emission line frame
  */
 
 /**@{*/
@@ -224,6 +102,7 @@ static int sinfo_new_get_vec ( float * xdat,
  *--------------------------------------------------------------------------*/
 
 /**
+@name sinfo_new_boltz
 @brief calculates the value of a Boltzmann function with parameters 
                         parlist at the position xdat 
 
@@ -235,6 +114,7 @@ static int sinfo_new_get_vec ( float * xdat,
             #            parlist(1): background2
             #            parlist(2): central position
             #            parlist(3): width
+
   @returns              function value of a Boltzmann function
                         that is 
                         y = (parlist(0) - parlist(1)) / 
@@ -255,6 +135,7 @@ float sinfo_new_boltz ( float * xdat, float * parlist )
 }
 
 /**
+ @name sinfo_new_boltz_deriv
  @brief calculates the partial derivatives for a Boltzmann function with
                         parameters parlist at position xdat 
 
@@ -294,6 +175,7 @@ void sinfo_new_boltz_deriv( float * xdat, float * parlist, float * dervs )
 }
 
 /**
+ * @name sinfo_new_inv_mat
  @brief calculates the inverse of matrix2.
 
    @param               void
@@ -308,9 +190,9 @@ static int sinfo_new_inv_mat (void)
     double even ;
     double hv[NPAR] ;
     double mjk ;
-    double rowmax ;
+
     int evin ;
-    int i, j, k, row ;
+    int i, j, k;
     int per[NPAR] ;
 
     /* set permutation array */
@@ -322,8 +204,8 @@ static int sinfo_new_inv_mat (void)
     for ( j = 0 ; j < nfree ; j++ ) /* in j-th column */
     {
         /* determine largest element of a row */                                
-        rowmax = fabs ( matrix2[j][j] ) ;
-        row = j ;                         
+        double rowmax = fabs ( matrix2[j][j] ) ;
+        int row = j ;
 
         for ( i = j + 1 ; i < nfree ; i++ )
         {
@@ -410,7 +292,8 @@ static int sinfo_new_inv_mat (void)
 }
 
 /**
-@brief  builds the sinfo_matrix
+@name sinfo_new_get_mat
+@brief  builds the matrix
 
    @param                     xdat position
    @param                     xdim factor of the indices of the position array
@@ -419,7 +302,7 @@ static int sinfo_new_inv_mat (void)
    @param                     ndat number of data points
    @param                     fpar function parameters
    @param                     epar partial derivatives of the function
-   @param                     npar number of function parameters
+   //@param                     npar number of function parameters
    @return                    void
  */
 
@@ -433,7 +316,6 @@ static void sinfo_new_get_mat ( float * xdat,
                       int   * npar*/ )
 {
     double wd ;
-    double wn ;
     double yd ;
     int i, j, n ;
 
@@ -451,7 +333,7 @@ static void sinfo_new_get_mat ( float * xdat,
     /* loop through data points */
     for ( n = 0 ; n < (*ndat) ; n++ )
     {
-        wn = wdat[n] ;
+        double wn = wdat[n] ;
         if ( wn > 0.0 )  /* legal weight ? */
         {
             yd = ydat[n] - sinfo_new_boltz( &xdat[(*xdim) * n], fpar ) ;
@@ -472,7 +354,8 @@ static void sinfo_new_get_mat ( float * xdat,
 
 
 /**
- @brief calculates the correction sinfo_vector.
+ @name sinfo_new_get_vec
+ @brief calculates the correction vector.
 
    @param           :       xdat: position
    @param                     xdim: factor of the indices of the position array
@@ -486,10 +369,11 @@ static void sinfo_new_get_mat ( float * xdat,
                                     -5 or -7 if diagonal element is wrong, or 
                                     -6, if determinant is zero )
 
-   The sinfo_matrix has been built by get_mat(), we only have to rescale 
-   it for the current value of labda. The matrix is rescaled so that 
-   the diagonal gets the value 1 + labda. Next we calculate the inverse of 
-   the sinfo_matrix and then the correction sinfo_vector.
+   The matrix has been built by get_mat(), we only have to re-scale
+   it for the current value of lambda. The matrix is rescaled so that
+   the diagonal gets the value 1 + lambda. Next we calculate the inverse of
+   the matrix and then the correction vector.
+
  */
 
 static int sinfo_new_get_vec ( float * xdat,
@@ -501,12 +385,12 @@ static int sinfo_new_get_vec ( float * xdat,
                                float * epar,
                                int   * npar )
 {
-    double dj ;
+
     double dy ;
     double mii ;
     double mji ;
     double mjj ;
-    double wn ;
+
     int i, j, n, r ;
 
     /* loop to modify and scale the sinfo_matrix */
@@ -539,7 +423,7 @@ static int sinfo_new_get_vec ( float * xdat,
     /* loop to calculate correction sinfo_vector */
     for ( j = 0 ; j < nfree ; j++ )
     {
-        dj = 0.0 ;
+        double dj = 0.0 ;
         mjj = matrix1[j][j] ;
         if ( mjj <= 0.0)               /* not allowed */
         {
@@ -563,7 +447,7 @@ static int sinfo_new_get_vec ( float * xdat,
     /* loop through the data points */
     for ( n = 0 ; n < (*ndat) ; n++ )
     {
-        wn = wdat[n] ;               /* get weight */
+        double wn = wdat[n] ;               /* get weight */
         if ( wn > 0.0 )              /* legal weight */
         {
             dy = ydat[n] - sinfo_new_boltz( &xdat[(*xdim) * n], epar) ;
@@ -576,6 +460,8 @@ static int sinfo_new_get_vec ( float * xdat,
 
 
 /**
+ *
+ @name  sinfo_new_lsqfit
  @brief makes a least-squares fit of a function to a set of data points.
 
    @param               xdat: position, coordinates of data points.
@@ -620,8 +506,11 @@ static int sinfo_new_get_vec ( float * xdat,
     #                    -6 determinant of the coefficient sinfo_matrix is zero
     #                    -7 square root of a negative number 
 
-The method used is described in: Marquardt, J.Soc.Ind.Appl.Math. 11. 431 (1963).
-This method is a mixture of the steepest descent method and the Taylor method.
+ @doc this is a routine for making a least-squares fit of a function to a set of
+ data points. The method used is described in:
+ Marquardt, J.Soc.Ind.Appl.Math. 11. 431 (1963).
+ This method is a mixture of the steepest descent method and the Taylor method.
+
  */
 
 int sinfo_new_lsqfit ( float * xdat,
@@ -823,6 +712,8 @@ int sinfo_new_lsqfit ( float * xdat,
 }
 
 /**
+ *
+@name  sinfo_new_fit_slits_boltz
 @brief fits the beginning and end position of the slitlets by using non-linear 
        least square fitting of a Boltzmann function fits a Boltzmann function 
        to the slitlet edges exposed and indicated by the brightest emission 
@@ -860,6 +751,7 @@ int sinfo_new_lsqfit ( float * xdat,
           used to find the brightest emission line and to get its position for 
           each column. The least squares fit is done by using a box smaller 
           than the size of two slitlets 
+
  ---------------------------------------------------------------------------*/
 
 int sinfo_new_fit_slits_boltz ( cpl_image   * lineImage, 
@@ -876,15 +768,15 @@ int sinfo_new_fit_slits_boltz ( cpl_image   * lineImage,
     Vector * box_buffer ;
     Vector * half_buffer ;
     Vector * in_buffer ;
-    float max_intensity ;
-    float row_pos ;
+
+
     int   row, col ;
-    int   i, j, k, m, n, ed ;
-    int   found, init1 ;
+    int   i, j, k, n, ed ;
+    int   init1 ;
     int   line ; 
     int   nel, n_right, left_right ;
     int   n_buf, edge_ind, shift ;
-    int   column ;
+
     int   slit_length ;
     int   agreed ;
     int   bad_line ;
@@ -897,7 +789,7 @@ int sinfo_new_fit_slits_boltz ( cpl_image   * lineImage,
     float fitpar[NPAR] ;
     float dervpar[NPAR] ;
     float minval, maxval ;
-    float min ;
+
     float pos, last_pos ;
     int old_col=0;
     int old_pos=0;
@@ -960,8 +852,8 @@ int sinfo_new_fit_slits_boltz ( cpl_image   * lineImage,
     bad_line = -1 ;
     while( agreed == -1 )
     {
-        found = -1 ;
-        max_intensity = -FLT_MAX ;
+        int found = -1 ;
+        float max_intensity = -FLT_MAX ;
         for ( col = 0 ; col < slit_length ; col++ )
         {
             for ( i = 0 ; i < par[0]->n_params ; i++ )
@@ -986,8 +878,8 @@ int sinfo_new_fit_slits_boltz ( cpl_image   * lineImage,
          * have intensity on near rows in neighbouring slitlets 
          */
         line    = par[found]->line ;
-        column  = par[found]->column ;
-        row_pos = par[found]->fit_par[2] ;
+        int column  = par[found]->column ;
+        double row_pos = par[found]->fit_par[2] ;
         if ( found >= 0 && max_intensity > 0. )
         {
             for ( i = 0 ; i < par[0]->n_params ; i++ )
@@ -1121,6 +1013,7 @@ int sinfo_new_fit_slits_boltz ( cpl_image   * lineImage,
         cpl_free( edgeclean ) ;
         cpl_free( dummyedge ) ;
         cpl_free( pos_rowclean ) ;
+        cpl_free( position );
         return -8 ;
     } 
 
@@ -1228,7 +1121,7 @@ int sinfo_new_fit_slits_boltz ( cpl_image   * lineImage,
 
     for ( j = 0 ; j <= k ; j++ )
     {
-        m = 0 ;
+        int m = 0 ;
         if ( j == 0 )
         {
             box_buffer = sinfo_new_vector( edgeclean[0] + margin ) ;
@@ -1289,7 +1182,7 @@ int sinfo_new_fit_slits_boltz ( cpl_image   * lineImage,
 
         /* determine the minimum value in the box to get background1 
            value for the sinfo_edge slitlets */
-        min = FLT_MAX ;
+        double min = FLT_MAX ;
         for ( i = 0 ; i < box_buffer->n_elements ; i++ )
         {
             if ( box_buffer -> data[i] < min )
@@ -1590,6 +1483,7 @@ int sinfo_new_fit_slits_boltz ( cpl_image   * lineImage,
 }
 
 /**
+ * @name sinfo_new_fit_slits_boltz_single_line
 @brief fits the beginning and end position of the slitlets by using 
        non-linear least square fitting of a Boltzmann function
 @param lineImage  emission line frame
@@ -1614,6 +1508,7 @@ int sinfo_new_fit_slits_boltz ( cpl_image   * lineImage,
           user given positions.
           The least squares fit is done by using a box smaller than
           the size of two slitlets
+
  */
 
 int 
@@ -1631,9 +1526,9 @@ sinfo_new_fit_slits_boltz_single_line ( cpl_image   * lineImage,
     Vector * box_buffer ;
     Vector * half_buffer ;
     Vector * in_buffer ;
-    int   found_row ;
+
     int   row, col ;
-    int   i, j, k, m, ed ;
+    int   i, j, k, ed ;
     int   init1 ;
     int   nel, n_right, left_right ;
     int   n_buf, edge_ind, shift ;
@@ -1704,7 +1599,7 @@ sinfo_new_fit_slits_boltz_single_line ( cpl_image   * lineImage,
 
     for ( col = 0 ; col < ilx ; col++ )
     {
-        found_row = -1 ;
+        int found_row = -1 ;
         maxval = -FLT_MAX ;
         for ( row = low_pos ; row <= high_pos ; row++ )
         {
@@ -1745,6 +1640,7 @@ sinfo_new_fit_slits_boltz_single_line ( cpl_image   * lineImage,
         cpl_free( edgeclean ) ;
         cpl_free( dummyedge ) ;
         cpl_free( pos_rowclean ) ;
+        cpl_free( position );
         return -1 ;
     }
 
@@ -1816,7 +1712,7 @@ sinfo_new_fit_slits_boltz_single_line ( cpl_image   * lineImage,
      */
     for ( j = 0 ; j <= k ; j++ )
     {
-        m = 0 ;
+        int m = 0 ;
         if ( j == 0 )
         {
             box_buffer = sinfo_new_vector( edgeclean[0] + margin ) ;
@@ -2134,6 +2030,7 @@ sinfo_new_fit_slits_boltz_single_line ( cpl_image   * lineImage,
 }
 
 /**
+ * @name sinfo_new_fit_slits_boltz_with_estimate
 @brief its the beginning and end position of the slitlets by using 
          non-linear least square fitting of a Boltzmann function
 
@@ -2159,6 +2056,7 @@ sinfo_new_fit_slits_boltz_single_line ( cpl_image   * lineImage,
      user given positions.
          The least squares fit is done by using a box smaller than
          the size of two slitlets 
+
  */
 
 int 
@@ -2173,11 +2071,11 @@ sinfo_new_fit_slits_boltz_with_estimate ( cpl_image   * lineImage,
     int*     position=NULL ;
     Vector * box_buffer ;
     Vector * in_buffer ;
-    int   found_row ;
+
     int   row, col ;
     int   col_first, col_last ;
     int   row_first, row_last ;
-    int   i, j, m, n ;
+    int   i, j, m;
     int   init1 ;
     int   left_right ;
     int   n_buf, shift ;
@@ -2199,7 +2097,7 @@ sinfo_new_fit_slits_boltz_with_estimate ( cpl_image   * lineImage,
     int ily=0;
     float* pidata=NULL;
 
-    slit_length = SLITLENGTH ; /* this setting is too much 64 */
+    /* slit_length = SLITLENGTH ; this setting is too much 64 */
     slit_length = N_SLITLETS ; /* this setting is better: 32 */
 
     if ( NULL == lineImage )
@@ -2247,7 +2145,7 @@ sinfo_new_fit_slits_boltz_with_estimate ( cpl_image   * lineImage,
     position=cpl_calloc(ilx,sizeof(int)) ;
     for ( col = 0 ; col < ilx ; col++ )
     {
-        found_row = -1 ;
+        int found_row = -1 ;
         maxval = -FLT_MAX ;
         for ( row = low_pos ; row <= high_pos ; row++ )
         {
@@ -2277,7 +2175,7 @@ sinfo_new_fit_slits_boltz_with_estimate ( cpl_image   * lineImage,
         /* now go through the columns and determine the slitlet positions by
          * calculating the median of the found positions 
          */
-        n = 0 ;
+        int n = 0 ;
 
         for ( col = sinfo_new_nint(slit_pos[j][0])+ 1 ; 
                         col < sinfo_new_nint(slit_pos[j][1]) -1 ; col++ )
