@@ -17,79 +17,20 @@
  * Foundation, 51 Franklin St, Fifth Floor, Boston, MA  02111-1307  USA
  */
 /*******************************************************************************
-* E.S.O. - VLT project
-*
-*
-*
-* who       when      what
-* --------  --------  ----------------------------------------------
-* schreib  19/12/00  created
-*/
+ * E.S.O. - VLT project
+ *
+ *
+ *
+ * who       when      what
+ * --------  --------  ----------------------------------------------
+ * schreib  19/12/00  created
+ */
 
 /************************************************************************
-*   NAME
-*        sinfo_coltilt.c -
-*        procedures to correct for tilted spectra 
-*
-*   SYNOPSIS
-*   1) float sinfo_new_slope_of_spectrum(cpl_image * ns_image,
-*                             int        box_length,
-*                             float      fwhm,
-*                             float      minDiff )
-*   2) cpl_image * sinfo_new_shift_rows(cpl_image * image,
-*                            float      slope )
-*   3) void sinfo_new_parameter_to_ascii ( float * parameter, 
-*                              int n,
-*                              char * filename )
-*   4) float * sinfo_new_ascii_to_parameter ( char * filename,
-*                                 int * n )
-*   5) double * sinfo_new_curvature_of_spectrum( cpl_image * ns_image,
-*                              int        order,
-*                                    int        box_length,
-*                                    int        left_pos,
-*                                    int        right_pos,
-*                                    float      fwhm,
-*                                    float      minDiff )
-*
-*
-*   DESCRIPTION
-*   1)  determines the sub-pixel shifts of each row by using
-*       an image with at least one continuum spectrum of a pinhole
-*       this is done by searching the spectrum within the image
-*       then fitting the spectrum along the rows within a given box
-*       by a Gaussian, so that the exact position is determined for
-*       each row. Afterwards, a straight line is fitted through the
-*       fitted positions. The slope of this linear fit is returned.
-*   2)  shifts the rows of a raw image by using the output of 
-*       sinfo_slopeOfSpectrum and applying polynomial interpolation
-*   3)  stores parameters in an ASCII file 
-*   4)  writes parameters stored in an ASCII file in an float array
-*   5)  this routine determines the curvature of a spectrum by fitting
-*       a polynomial to a continuum spectrum. This is done by using
-*       an image with at least one continuum spectrum of a pinhole.
-*       this is done by searching the spectrum within the image
-*       then fitting the spectrum along the rows within a given box
-*       by a Gaussian, so that the exact position is determined for
-*       each row. Afterwards, a polynomial is fitted through the
-*       found positions. The polynomial coefficients are returned.
-*
-*
-*   FILES
-*
-*   ENVIRONMENT
-*
-*   RETURN VALUES
-*
-*   CAUTIONS
-*
-*   EXAMPLES
-*
-*   SEE ALSO
-*
-*   BUGS
-*
-*------------------------------------------------------------------------
-*/
+ *   NAME
+ *        sinfo_coltilt.c
+ *------------------------------------------------------------------------
+ */
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
@@ -113,7 +54,7 @@
 /**
  * @defgroup sinfo_coltilt Column tilt computation
  *
- * TBD
+ * procedures to correct for tilted spectra
  */
 
 /*----------------------------------------------------------------------------
@@ -123,31 +64,34 @@
 /**
    @name   sinfo_new_slope_of_spectrum()
    @memo   determines the sub-pixel shifts of each row
-   @param  ns_image   image with at least one continuum spectrum of a pinhole
+
+   @param  ns_image   image with at least one continuum spectrum of a pin-hole
    @param  box_length width of the box in which the lines are fit by a Gaussian
    @param  fwhm       first guess of the full width at half maximum
-   @param  min_amplitude_factor factor peak/background below given threshold 
-           the fit is not carried through
+   @param  minDiff    factor peak/background below given threshold the fit is
+                      not carried through
+
    @return slope of a straight line fitted to the spectrum. -FLT_MAX if 
            something went wrong.
+
    @doc    determines the sub-pixel shifts of each row by using an image with 
-           at least one continuum spectrum of a pinhole this is done by 
+           at least one continuum spectrum of a pin-hole this is done by
            searching the spectrum within the image then fitting the spectrum 
            along the rows within a given box by a Gaussian, so that the exact 
            position is determined for each row. Afterwards, a straight line is 
            fitted through the fitted positions. The slope of this linear fit 
            is returned.
 
-  */
+ */
 
 float 
 sinfo_new_slope_of_spectrum( cpl_image * ns_image,
-                       int        box_length,
-                       float      fwhm,
-                       float      minDiff )
+                             int        box_length,
+                             float      fwhm,
+                             float      minDiff )
 {
     int i, k, row, col ;
-    int counter, iters ;
+    int iters ;
     int xdim, ndat, its, numpar ;
     float maxval ;
     float tol, lab ;
@@ -159,11 +103,11 @@ sinfo_new_slope_of_spectrum( cpl_image * ns_image,
 
 
     int col_median ;
-    float * xdat, * wdat ;
-    int * mpar ;
+
+
     Vector * line ;
     FitParams ** dec_par ;
-    FitParams *  par ;
+
 
     float* x=NULL; 
     float* y=NULL; 
@@ -172,7 +116,7 @@ sinfo_new_slope_of_spectrum( cpl_image * ns_image,
     int position ;
     int ndata, mwt ;
     float a, b, siga, sigb, chi2, q ;
-    int bad_ind ;
+
     int lx=0;
     int ly=0;
     float* pdata=NULL;
@@ -236,7 +180,7 @@ sinfo_new_slope_of_spectrum( cpl_image * ns_image,
        to have the brightest spectrum */
     col_median = (int)sinfo_new_median(col_position, ly) ;
     sinfo_msg ("sinfo_new_median column position of brightest spectrum %d\n", 
-              col_median) ;
+               col_median) ;
 
     /* now find the peaks around col_median over the whole spectral range */
     for ( row = 0 ; row < ly ; row++ )
@@ -245,7 +189,7 @@ sinfo_new_slope_of_spectrum( cpl_image * ns_image,
         column_value[row] = -FLT_MAX ;
         column_position[row] = -1 ;
         for ( col = col_median - box_length ; 
-              col <= col_median + box_length ; col++ )
+                        col <= col_median + box_length ; col++ )
         {
             if ( pdata[col+row*lx] > column_value[row] )
             {
@@ -262,22 +206,22 @@ sinfo_new_slope_of_spectrum( cpl_image * ns_image,
         }
 
         /* allocate memory */
-        xdat = (float *) cpl_calloc( line -> n_elements, sizeof (float) ) ;
-        wdat = (float *) cpl_calloc( line -> n_elements, sizeof (float) ) ;
-        mpar = (int *)   cpl_calloc( MAXPAR, sizeof (int) ) ;
+        float* xdat = (float *) cpl_calloc( line -> n_elements, sizeof (float) ) ;
+        float* wdat = (float *) cpl_calloc( line -> n_elements, sizeof (float) ) ;
+        int* mpar = (int *)   cpl_calloc( MAXPAR, sizeof (int) ) ;
         dec_par = sinfo_new_fit_params(1) ;
-        par = dec_par[0];
+        FitParams *  par = dec_par[0];
 
-        counter = 0 ;
-        bad_ind = 0 ;
+        int counter = 0 ;
+        int bad_ind = 0 ;
         /* store the values to fit in a Vector object */
         for ( col = column_position[row] - box_length ; 
-              col <= column_position[row] + box_length ; col++ )
+                        col <= column_position[row] + box_length ; col++ )
         {
             if ( col < 0 || col >= lx )
             {
                 sinfo_msg_error ("wrong spectrum position or box_length "
-                                 "given in row: %d", row) ;
+                                "given in row: %d", row) ;
                 cpl_free (xdat) ;
                 cpl_free (wdat) ;
                 cpl_free (mpar) ;
@@ -295,12 +239,12 @@ sinfo_new_slope_of_spectrum( cpl_image * ns_image,
                 counter++ ;
             }
         }
- 
+
         /* go to the next row if a bad pixel is inside the box */
         if ( bad_ind == 1 )
         {
             sinfo_msg_warning ("sorry, bad pixel inside fitting "
-                               "box in row: %d", row) ;
+                            "box in row: %d", row) ;
             cpl_free (xdat) ;
             cpl_free (wdat) ;
             cpl_free (mpar) ;
@@ -336,14 +280,14 @@ sinfo_new_slope_of_spectrum( cpl_image * ns_image,
         (*par).fit_par[1] = fwhm ;
         (*par).fit_par[2] = (float) position ;
         (*par).fit_par[3] = (float) (line -> data[0] + 
-                            line -> data[line->n_elements - 1]) / 2.0 ;
+                        line -> data[line->n_elements - 1]) / 2.0 ;
 
         (*par).fit_par[0]  = maxval - ((*par).fit_par[3]) ;
         /* exclude negative peaks and low signal cases */
         if ( (*par).fit_par[0] < minDiff )
         {
             sinfo_msg_warning ("sorry, negative peak or signal of line "
-                               "too low to fit in row: %d", row) ;
+                            "too low to fit in row: %d", row) ;
             cpl_free (xdat) ;
             cpl_free (wdat) ;
             cpl_free (mpar) ;
@@ -360,13 +304,13 @@ sinfo_new_slope_of_spectrum( cpl_image * ns_image,
 
         /* finally, do the least square fit using a sinfo_gaussian */
         if ( 0 > ( iters = sinfo_new_lsqfit_c( xdat, &xdim, 
-                                               line -> data, wdat, 
-                                               &ndat, (*par).fit_par,
-                                               (*par).derv_par, mpar, 
-                                               &numpar, &tol, &its, &lab )) )
+                        line -> data, wdat,
+                        &ndat, (*par).fit_par,
+                        (*par).derv_par, mpar,
+                        &numpar, &tol, &its, &lab )) )
         {
             sinfo_msg_warning ("sinfo_new_lsqfit_c: least squares fit "
-                               "failed in row: %d, error no.: %d",row,iters) ;
+                            "failed in row: %d, error no.: %d",row,iters) ;
             cpl_free (xdat) ;
             cpl_free (wdat) ;
             cpl_free (mpar) ;
@@ -377,10 +321,10 @@ sinfo_new_slope_of_spectrum( cpl_image * ns_image,
 
         /* check for negative fit results */
         if ( (*par).fit_par[0] <= 0. || (*par).fit_par[1] <= 0. ||
-             (*par).fit_par[2] <= 0. )
+                        (*par).fit_par[2] <= 0. )
         {
             sinfo_msg_warning ("negative parameters as fit result, "
-                               "not used! in row: %d", row) ;
+                            "not used! in row: %d", row) ;
             cpl_free (xdat) ;
             cpl_free (wdat) ;
             cpl_free (mpar) ;
@@ -392,7 +336,7 @@ sinfo_new_slope_of_spectrum( cpl_image * ns_image,
         /* correct the fitted position for the given row of the line in 
            image coordinates */
         x_position[row] =  (float) (column_position[row] - box_length) + 
-                           (*par).fit_par[2] ;
+                        (*par).fit_par[2] ;
 
         /* store the fit errors of the positions as weights for the later 
            linear fit */
@@ -452,14 +396,18 @@ sinfo_new_slope_of_spectrum( cpl_image * ns_image,
 
 /**
    @name sinfo_new_shift_rows()
+
    @param image   raw image in which the rows should be shifted
    @param slope   slope of a fitted straight line along a spectrum
                   output of sinfo_slopeOfSpectrum
    @param n_order order of the interpolation polynomial
+
    @return resulting image with shifted rows
+
    @doc   shifts the rows of a raw image by using the output of
           sinfo_slopeOfSpectrum and applying polynomial interpolation
-   
+
+
  */
 
 cpl_image * 
@@ -468,9 +416,9 @@ sinfo_new_shift_rows( cpl_image * image,
                       int        n_order )
 {
     cpl_image * returnImage=NULL ;
-    float xshift=0 ;
-    int   intshift = 0 ;
-    float sum=0;
+
+
+
     float new_sum=0;
 
     float* xnum=NULL ;
@@ -490,7 +438,7 @@ sinfo_new_shift_rows( cpl_image * image,
     /*
     int olx=0;
     int oly=0;
-    */
+     */
     float* pidata=NULL;
     float* podata=NULL;
 
@@ -518,7 +466,7 @@ sinfo_new_shift_rows( cpl_image * image,
     /*
     olx=cpl_image_get_size_x(returnImage);
     oly=cpl_image_get_size_y(returnImage);
-    */
+     */
     pidata=cpl_image_get_data_float(image);
     podata=cpl_image_get_data_float(returnImage);
 
@@ -548,46 +496,46 @@ sinfo_new_shift_rows( cpl_image * image,
     for ( row = 0 ; row < ily ; row++ )
     {
         /* determine the shift for each row, the middle row is not shifted */
-        xshift = slope * (float)( (ily / 2) - row ) ;
+        float xshift = slope * (float)( (ily / 2) - row ) ;
 
-        intshift = sinfo_new_nint(xshift) ;
+        int intshift = sinfo_new_nint(xshift) ;
         xshift = xshift - (float)intshift ;
 
         for ( col = 0 ; col < ilx ; col++ )
         {
             corrected_row_data[col] = 0. ;
         }
-        sum = 0. ; /* initialize flux for later rescaling */
+        float sum = 0. ; /* initialize flux for later rescaling */
         /* go through the image columns */
         for ( col = 0 ; col < ilx ; col++ )
         {
-        /* consider integer pixel shifts */
-        if ( intshift < 0 )
+            /* consider integer pixel shifts */
+            if ( intshift < 0 )
             {
-        if ( col - intshift < ilx )
-        {
-            row_data[col] = pidata[col-intshift+row*ilx] ;
+                if ( col - intshift < ilx )
+                {
+                    row_data[col] = pidata[col-intshift+row*ilx] ;
                 }
-        else
-        {
-            row_data[col] = 0. ;
+                else
+                {
+                    row_data[col] = 0. ;
                 }
-        }
-        else if ( intshift > 0 )
-        {
-        if ( col - intshift >= 0 )
-        {
-            row_data[col] = pidata[col-intshift+row*ilx] ;
+            }
+            else if ( intshift > 0 )
+            {
+                if ( col - intshift >= 0 )
+                {
+                    row_data[col] = pidata[col-intshift+row*ilx] ;
                 }
-        else
-        {
-            row_data[col] = 0. ;
-        }
-        }
-        else
-        {
-               row_data[col] = pidata[col+row*ilx] ;
-        }
+                else
+                {
+                    row_data[col] = 0. ;
+                }
+            }
+            else
+            {
+                row_data[col] = pidata[col+row*ilx] ;
+            }
 
             /* don't consider the sinfo_edge pixels for flux calculation */
             if ( col != 0 && col != ilx - 1 && !isnan(row_data[col]) )
@@ -622,7 +570,7 @@ sinfo_new_shift_rows( cpl_image * image,
              */
             if ( isnan(corrected_row_data[col]) )
             {
-                 continue ;
+                continue ;
             }
             if ( col - firstpos < 0 )
             {
@@ -640,9 +588,9 @@ sinfo_new_shift_rows( cpl_image * image,
                 eval     = (float)firstpos - xshift ;
             }
 
-        flag=0;
-        corrected_row_data[col]=sinfo_new_nev_ille(xnum,imageptr,
-                                                       n_order,eval,&flag);
+            flag=0;
+            corrected_row_data[col]=sinfo_new_nev_ille(xnum,imageptr,
+                            n_order,eval,&flag);
             /*polint( xnum - 1, imageptr, n_points, eval, 
                       &corrected_row_data[col], &dy ) ;*/
 
@@ -666,12 +614,12 @@ sinfo_new_shift_rows( cpl_image * image,
             }
             else
             {
-              /* rescale the row data and fill the returned image */
-              /* This gives sometimes inconsistent results if 
+                /* rescale the row data and fill the returned image */
+                /* This gives sometimes inconsistent results if
                  bad pixels are around */
-              /* rescaling is commented out because it delivers wrong results
+                /* rescaling is commented out because it delivers wrong results
                  in case of appearance of blanks or bad pixels */
-             /*   corrected_row_data[col] *= sum / new_sum ; */
+                /*   corrected_row_data[col] *= sum / new_sum ; */
                 podata[col+row*ilx] = corrected_row_data[col] ;
             }
         }
@@ -688,17 +636,19 @@ sinfo_new_shift_rows( cpl_image * image,
 /**
    @name  sinfo_new_parameter_to_ascii()
    @memo stores parameters in an ASCII file
+
    @param parameter float parameter array to be stored in an ASCII file
-   @param number number of parameters
+   @param n number of parameters
    @param filename filename of ASCII file
+
    @return void
-    
-*/
+
+ */
 
 void 
 sinfo_new_parameter_to_ascii ( float * parameter, 
-                        int n,
-                        char * filename )
+                               int n,
+                               char * filename )
 {
     FILE * fp ;
     int     i=0 ;
@@ -708,7 +658,7 @@ sinfo_new_parameter_to_ascii ( float * parameter,
         sinfo_msg_error ("input is missing or wrong!") ;
         return ;
     }
-    
+
     if ( NULL == (fp = fopen ( filename, "w" ) ) )
     {
         sinfo_msg_error("cannot open %s", filename) ;
@@ -722,68 +672,23 @@ sinfo_new_parameter_to_ascii ( float * parameter,
     fclose (fp ) ;
 }
 
-/**
-   @name  sinfo_new_ascii_to_parameter()
-   @param filename filename of ASCII file
-   @param n number of parameters in the parameter array array of parameters
-   @doc writes parameters stored in an ASCII file in an float array
-*/
-
-float * 
-sinfo_new_ascii_to_parameter ( char * filename,
-                           int * n )
-{
-    FILE * fp ;
-    float * parameter=NULL ;
-    int     i=0 ;
-
-    if ( filename == NULL || n == NULL )
-    {
-        sinfo_msg_error ("Input is missing or wrong") ;
-        return NULL ;
-    }
-    
-    if ( NULL == (fp = fopen ( filename, "r" ) ) )
-    {
-        sinfo_msg_error("cannot open %s", filename) ;
-        return NULL ;
-    }
-
-    /* allocate memory */
-
-    if (NULL == ( parameter = (float*) cpl_calloc (ESTIMATE, sizeof(float)) ) )
-    {
-        sinfo_msg_error ("cannot allocate memory") ;
-        fclose (fp ) ;
-        return NULL ;
-    }
-
-    i = 0 ;
-    while ( fscanf(fp, "%g\n", &parameter[i]) != EOF )
-    {
-        i++ ;
-    }
-    *n = i ;
-
-    fclose (fp ) ;
-
-    return parameter ;
-}
-
 
 /**
     @name  sinfo_new_curvature_of_spectrum()
-   @param ns_image   image with at least one continuum spectrum of a pinhole
-   @param order      order of the fit polynomial
-   @param box_length width of the box in which the lines are fit by a Gaussian
-   @param left_pos
-   @param right_pos left and right positions between which the spectrum should 
+
+    @param ns_image   image with at least one continuum spectrum of a pinhole
+    @param order      order of the fit polynomial
+    @param box_length width of the box in which the lines are fit by a Gaussian
+    @param left_pos
+    @param right_pos left and right positions between which the spectrum should
                     be located
-   @param fwhm      first guess of the full width at half maximum
-   @param min_amplitude_factor factor peak/background below given
+    @param fwhm      first guess of the full width at half maximum
+    @param minDiff factor peak/background below given
                        threshold the fit is not carried through
-   @return resulting polynomial coefficients.
-   @doc    this routine determines the curvature of a spectrum by fitting
+
+    @return resulting polynomial coefficients.
+
+    @doc    this routine determines the curvature of a spectrum by fitting
            a polynomial to a continuum spectrum. This is done by using
        an image with at least one continuum spectrum of a pinhole.
        this is done by searching the spectrum within the image
@@ -791,22 +696,24 @@ sinfo_new_ascii_to_parameter ( char * filename,
        by a sinfo_gaussian, so that the exact position is determined for
        each row. Afterwards, a polynomial is fitted through the
        found positions. The polynomial coefficients are returned.
-*/  
+
+ *
+ */
 
 double * 
 sinfo_new_curvature_of_spectrum( cpl_image * ns_image,
-                    int        order,
-                         int        box_length,
-                 int        left_pos,
-             int        right_pos,
-                         float      fwhm,
-                         float      minDiff )
+                                 int        order,
+                                 int        box_length,
+                                 int        left_pos,
+                                 int        right_pos,
+                                 float      fwhm,
+                                 float      minDiff )
 {
     int i=0;
     int k=0;
     int row=0;
     int col=0;
-    int counter=0;
+
     int iters=0;
     int xdim=0;
     int ndat=0;
@@ -823,15 +730,15 @@ sinfo_new_curvature_of_spectrum( cpl_image * ns_image,
     float* x_position=NULL ;
 
     int col_median=0;
-    float * xdat=NULL;
-    float * wdat=NULL;
-    int * mpar=NULL;
+
+
+
     Vector * line=NULL;
     FitParams ** dec_par=NULL ;
-    FitParams * par=NULL ;
+
     int position=0 ;
     int ndata=0 ;
-    int bad_ind=0 ;
+
     dpoint * list=NULL ;
     double * coeffs=NULL ;
     double offset=0 ;
@@ -875,7 +782,7 @@ sinfo_new_curvature_of_spectrum( cpl_image * ns_image,
     col_position=(pixelvalue*)cpl_calloc(ly,sizeof(pixelvalue)) ;
     column_position=cpl_calloc(ly,sizeof(int)) ;
     x_position=cpl_calloc(ly,sizeof(float)) ;
-
+    pdata=cpl_image_get_data_float(ns_image);
     /* go through the image rows */
     for ( row = 0 ; row < ly ; row++ )
     {
@@ -903,7 +810,7 @@ sinfo_new_curvature_of_spectrum( cpl_image * ns_image,
         column_value[row] = -FLT_MAX ;
         column_position[row] = -1 ;
         for ( col = col_median - box_length ; 
-              col <= col_median + box_length ; col++ )
+                        col <= col_median + box_length ; col++ )
         {
             if ( pdata[col+row*lx] > column_value[row] )
             {
@@ -920,22 +827,22 @@ sinfo_new_curvature_of_spectrum( cpl_image * ns_image,
         }
 
         /* allocate memory */
-        xdat = (float *) cpl_calloc( line -> n_elements, sizeof (float) ) ;
-        wdat = (float *) cpl_calloc( line -> n_elements, sizeof (float) ) ;
-        mpar = (int *)   cpl_calloc( MAXPAR, sizeof (int) ) ;
+        float* xdat = (float *) cpl_calloc( line -> n_elements, sizeof (float) ) ;
+        float* wdat = (float *) cpl_calloc( line -> n_elements, sizeof (float) ) ;
+        int* mpar = (int *)   cpl_calloc( MAXPAR, sizeof (int) ) ;
         dec_par = sinfo_new_fit_params(1) ;
-        par = dec_par[0];
-    
-        counter = 0 ;
-        bad_ind = 0 ;
+        FitParams * par = dec_par[0];
+
+        int counter = 0 ;
+        int bad_ind = 0 ;
         /* store the values to fit in a Vector object */
         for ( col = column_position[row] - box_length ; 
-              col <= column_position[row] + box_length ; col++ )
+                        col <= column_position[row] + box_length ; col++ )
         {
             if ( col < 0 || col >= lx )
             {
                 sinfo_msg_error ("wrong spectrum position or box_length "
-                                 "given in row: %d", row) ;
+                                "given in row: %d", row) ;
                 cpl_free (xdat) ;
                 cpl_free (wdat) ;
                 cpl_free (mpar) ;
@@ -953,12 +860,12 @@ sinfo_new_curvature_of_spectrum( cpl_image * ns_image,
                 counter++ ;
             }
         }
- 
+
         /* go to the next row if a bad pixel is inside the box */
         if ( bad_ind == 1 )
         {
             sinfo_msg_warning ("sorry, bad pixel inside fitting box "
-                               "in row: %d", row) ;
+                            "in row: %d", row) ;
             cpl_free (xdat) ;
             cpl_free (wdat) ;
             cpl_free (mpar) ;
@@ -994,14 +901,14 @@ sinfo_new_curvature_of_spectrum( cpl_image * ns_image,
         (*par).fit_par[1] = fwhm ;
         (*par).fit_par[2] = (float) position ;
         (*par).fit_par[3] = (float) (line -> data[0] + 
-                                     line -> data[line->n_elements - 1]) / 2.0;
+                        line -> data[line->n_elements - 1]) / 2.0;
 
         (*par).fit_par[0]  = maxval - ((*par).fit_par[3]) ;
         /* exclude negative peaks and low signal cases */
         if ( (*par).fit_par[0] < minDiff )
         {
             sinfo_msg_warning ("sorry, negative peak or signal of line "
-                               "too low to fit in row: %d", row) ;
+                            "too low to fit in row: %d", row) ;
             cpl_free (xdat) ;
             cpl_free (wdat) ;
             cpl_free (mpar) ;
@@ -1018,13 +925,13 @@ sinfo_new_curvature_of_spectrum( cpl_image * ns_image,
 
         /* finally, do the least square fit using a sinfo_gaussian */
         if ( 0 > ( iters = sinfo_new_lsqfit_c( xdat, &xdim, 
-                                               line -> data, wdat, 
-                                               &ndat, (*par).fit_par,
-                                               (*par).derv_par, mpar, 
-                                               &numpar, &tol, &its, &lab )) )
+                        line -> data, wdat,
+                        &ndat, (*par).fit_par,
+                        (*par).derv_par, mpar,
+                        &numpar, &tol, &its, &lab )) )
         {
             sinfo_msg_warning ("least squares fit failed in row: "
-                               "%d, error no.: %d", row, iters) ;
+                            "%d, error no.: %d", row, iters) ;
             cpl_free (xdat) ;
             cpl_free (wdat) ;
             cpl_free (mpar) ;
@@ -1035,10 +942,10 @@ sinfo_new_curvature_of_spectrum( cpl_image * ns_image,
 
         /* check for negative fit results */
         if ( (*par).fit_par[0] <= 0. || (*par).fit_par[1] <= 1. ||
-             (*par).fit_par[2] <= 0. )
+                        (*par).fit_par[2] <= 0. )
         {
             sinfo_msg_warning ("negative parameters as fit result, "
-                               "not used! in row: %d", row) ;
+                            "not used! in row: %d", row) ;
             cpl_free (xdat) ;
             cpl_free (wdat) ;
             cpl_free (mpar) ;
@@ -1050,7 +957,7 @@ sinfo_new_curvature_of_spectrum( cpl_image * ns_image,
         /* correct the fitted position for the given row of the line 
            in image coordinates */
         x_position[row] =  (float) (column_position[row] - box_length) + 
-                                   (*par).fit_par[2] ;
+                        (*par).fit_par[2] ;
         printf("%d %f %f\n",row, (*par).fit_par[1], x_position[row] ) ;
 
         /* free memory */
@@ -1087,7 +994,7 @@ sinfo_new_curvature_of_spectrum( cpl_image * ns_image,
             ndata++ ;
         }
     }
-    
+
 
     if ( NULL == (coeffs = sinfo_fit_1d_poly(order, list, ndata, NULL)) )
     {
@@ -1103,84 +1010,86 @@ sinfo_new_curvature_of_spectrum( cpl_image * ns_image,
     cpl_free(col_position) ;
     cpl_free(column_position) ;
     cpl_free(x_position) ;
-     
+
     return coeffs ;
 }
 
 /**
 @name sinfo_new_image_warp_fits
 @memo correct optical distortions
+
 @param image distorted image
 @param kernel_type type of kernel to correct distortions
 @param poly_table table containing distortion coefficients
+
 @return image distortion corrected
-*/    
+ */
 cpl_image * 
 sinfo_new_image_warp_fits( cpl_image * image,
-                      char      * kernel_type, 
-                      char      * poly_table )
+                           char      * kernel_type,
+                           char      * poly_table )
 {
-        cpl_image  * warped=NULL;
+    cpl_image  * warped=NULL;
     /* Following are for polynomial transforms */
     cpl_polynomial    * poly_u=NULL;        /* polynomial definition */
     cpl_polynomial    * poly_v=NULL;        /* polynomial definition */
-        cpl_table* poly_tbl=NULL;
+
     cpl_vector      *   profile=NULL ;
-        cpl_size local_pow[2];
-        int             i=0;
+    cpl_size local_pow[2];
+
 
     /*fscanf(poly_in,"%s",poly_string);*/
     /* sinfo_msg("%s",poly_string); */
-    
+
     poly_u = cpl_polynomial_new(2);
-        if (poly_u == NULL) {
-            sinfo_msg_error("cannot read 2D poly from arc table") ;
+    if (poly_u == NULL) {
+        sinfo_msg_error("cannot read 2D poly from arc table") ;
+        return NULL ;
+    }
+
+    if (poly_u != NULL) {
+        sinfo_msg_debug("Get the arc distortion from the file %s",
+                        poly_table);
+        if(sinfo_is_fits_file(poly_table) != 1) {
+            sinfo_msg_error("Input file %s is not FITS",poly_table);
+            return NULL;
+        }
+        cpl_table* poly_tbl=NULL;
+        if(NULL==(poly_tbl = cpl_table_load(poly_table,1,0))) {
+            sinfo_msg_error("cannot load the arc table") ;
+            cpl_polynomial_delete(poly_u) ;
             return NULL ;
         }
- 
-        if (poly_u != NULL) {
-      sinfo_msg_debug("Get the arc distortion from the file %s",
-                          poly_table);
-      if(sinfo_is_fits_file(poly_table) != 1) {
-        sinfo_msg_error("Input file %s is not FITS",poly_table);
-        return NULL;
-      }
 
-      if(NULL==(poly_tbl = cpl_table_load(poly_table,1,0))) {
-        sinfo_msg_error("cannot load the arc table") ;
-        cpl_polynomial_delete(poly_u) ;
-        return NULL ;
-      }
-
-      for (i=0 ; i<cpl_table_get_nrow(poly_tbl) ; i++) {
+        for (int i=0 ; i<cpl_table_get_nrow(poly_tbl) ; i++) {
             local_pow[0] = cpl_table_get_int(poly_tbl, "degx", i, NULL) ; 
             local_pow[1] = cpl_table_get_int(poly_tbl, "degy", i, NULL) ;
             cpl_polynomial_set_coeff(poly_u, local_pow,
-           cpl_table_get_double(poly_tbl, "coeff", i, NULL)) ;
-      }
+                                     cpl_table_get_double(poly_tbl, "coeff", i, NULL)) ;
+        }
 
-      cpl_table_delete(poly_tbl) ;
+        cpl_table_delete(poly_tbl) ;
     } else {
-      sinfo_msg("Use the ID polynomial for the arc dist") ;
-      local_pow[0] = 1 ;
-      local_pow[1] = 0 ;
-      cpl_polynomial_set_coeff(poly_u, local_pow, 1.0) ;
+        sinfo_msg("Use the ID polynomial for the arc dist") ;
+        local_pow[0] = 1 ;
+        local_pow[1] = 0 ;
+        cpl_polynomial_set_coeff(poly_u, local_pow, 1.0) ;
     }
 
-        poly_v=cpl_polynomial_new(2);
-        local_pow[0]=0;
-        local_pow[1]=1;
+    poly_v=cpl_polynomial_new(2);
+    local_pow[0]=0;
+    local_pow[1]=1;
 
-        cpl_polynomial_set_coeff(poly_v,local_pow,1.0);
+    cpl_polynomial_set_coeff(poly_v,local_pow,1.0);
     profile = cpl_vector_new(CPL_KERNEL_DEF_SAMPLES) ;
     cpl_vector_fill_kernel_profile(profile, CPL_KERNEL_TANH,
-                       CPL_KERNEL_DEF_WIDTH) ;
+                                   CPL_KERNEL_DEF_WIDTH) ;
     warped=sinfo_new_warp_image_generic(image,kernel_type,poly_u,poly_v);
     /* YVES WAY 
       warped = cpl_image_new(cpl_image_get_size_x(image),
                                  cpl_image_get_size_y(image),
                                  CPL_TYPE_FLOAT);
-       
+
     if (cpl_image_warp_polynomial(warped, image, poly_u, poly_v, 
                       profile,CPL_KERNEL_DEF_WIDTH,
                       profile,CPL_KERNEL_DEF_WIDTH)
@@ -1192,13 +1101,13 @@ sinfo_new_image_warp_fits( cpl_image * image,
             cpl_vector_delete(profile) ;
             return NULL;
     }
-    */
+     */
 
-      cpl_vector_delete(profile) ;
-      if (poly_u!=NULL) cpl_polynomial_delete(poly_u);
-      if (poly_v!=NULL) cpl_polynomial_delete(poly_v);
-    
-      return warped;
+    cpl_vector_delete(profile) ;
+    if (poly_u!=NULL) cpl_polynomial_delete(poly_u);
+    if (poly_v!=NULL) cpl_polynomial_delete(poly_v);
+
+    return warped;
 }
-    
+
 /**@}*/
