@@ -703,7 +703,7 @@ cpl_polynomial * sinfo_distortion_estimate(
         double              offset,
         cpl_apertures   **  arcs)
 {
-    const char      *   fctid = "sinfo_distortion_estimate" ;
+
     cpl_image       *   local_im ;
     cpl_image       *   label_image ;
     double              rightmost, leftmost ;
@@ -748,22 +748,22 @@ cpl_polynomial * sinfo_distortion_estimate(
         local_im = cpl_image_duplicate(org) ;
     }
     if (local_im == NULL) {
-        cpl_msg_error(fctid, "Cannot clean the image") ;
+        cpl_msg_error(cpl_func, "Cannot clean the image") ;
         return NULL ;
     }
 
     /* Detect the arcs in the input image */
-    cpl_msg_info(fctid, "Detect arcs") ;
+    cpl_msg_info(cpl_func, "Detect arcs") ;
     if ((*arcs = sinfo_distortion_detect_arcs(local_im,
                     &label_image,
                     arc_sat, max_arc_width,
                     xmin, ymin, xmax, ymax)) == NULL) {
         cpl_image_delete(local_im) ;
-        cpl_msg_error(fctid, "Cannot detect the arcs") ;
+        cpl_msg_error(cpl_func, "Cannot detect the arcs") ;
         return NULL ;
     }
     n_arcs = cpl_apertures_get_size(*arcs) ;
-    cpl_msg_info(fctid, "%d detected arcs", n_arcs) ;
+    cpl_msg_info(cpl_func, "%d detected arcs", n_arcs) ;
 
     /* Check that the arcs are not concentrated in the same zone */
     rightmost = leftmost = cpl_apertures_get_pos_x(*arcs, 1) ;
@@ -775,7 +775,7 @@ cpl_polynomial * sinfo_distortion_estimate(
     }
     min_arc_range = (int)(nx / ARC_RANGE_FACT) ;
     if ((int)(rightmost-leftmost) < min_arc_range) {
-        cpl_msg_error(fctid, "too narrow range (%g-%g)<%d",
+        cpl_msg_error(cpl_func, "too narrow range (%g-%g)<%d",
                 rightmost, leftmost, min_arc_range) ;
         cpl_apertures_delete(*arcs) ;
         cpl_image_delete(local_im) ;
@@ -784,11 +784,11 @@ cpl_polynomial * sinfo_distortion_estimate(
     }
 
     /* Create a 2-D deformation grid with detected arcs */
-    cpl_msg_info(fctid, "Create deformation grid") ;
+    cpl_msg_info(cpl_func, "Create deformation grid") ;
     lines_pos = cpl_malloc(n_arcs * sizeof(double)) ;
     if ((arcs_pos = sinfo_distortion_get_arc_positions(local_im,
                     label_image, *arcs, n_calib, &lines_pos))==NULL){
-        cpl_msg_error(fctid, "cannot get arcs positions") ;
+        cpl_msg_error(cpl_func, "cannot get arcs positions") ;
         cpl_apertures_delete(*arcs) ;
         cpl_image_delete(local_im) ;
         cpl_free(lines_pos) ;
@@ -802,7 +802,7 @@ cpl_polynomial * sinfo_distortion_estimate(
     lines_pos_tmp=cpl_vector_new(n_arcs);
     plines_pos_tmp=cpl_vector_get_data(lines_pos_tmp);
 
-    cpl_msg_info(fctid, "Fit the 2d polynomial") ;
+    cpl_msg_info(cpl_func, "Fit the 2d polynomial") ;
     grid = cpl_bivector_new(n_arcs * n_calib) ;
     pgridx = cpl_bivector_get_x_data(grid) ;
     pgridy = cpl_bivector_get_y_data(grid) ;
@@ -880,7 +880,7 @@ cpl_polynomial * sinfo_distortion_estimate(
     /* Apply the fitting */
     if ((poly2d = sinfo_polynomial_fit_2d_create(grid, values_to_fit,
                     degree, NULL))==NULL) {
-        cpl_msg_error(fctid, "cannot apply the 2d fit") ;
+        cpl_msg_error(cpl_func, "cannot apply the 2d fit") ;
         cpl_bivector_delete(grid) ;
         cpl_vector_delete(values_to_fit) ;
         cpl_apertures_delete(*arcs) ;
@@ -921,7 +921,7 @@ static cpl_apertures * sinfo_distortion_detect_arcs(
         int             xmax,
         int             ymax)
 {
-    const char      *   fctid = "sinfo_distortion_detect_arcs" ;
+
     cpl_image       *   filt_im ;
     cpl_matrix      *   filter ;
     cpl_image       *   collapsed ;
@@ -943,7 +943,7 @@ static cpl_apertures * sinfo_distortion_detect_arcs(
     fillval = median_val-sigma/2.0 ;
     if (sinfo_distortion_fill_badzones(im, xmin, ymin, xmax, ymax,
                 fillval) == -1) {
-        cpl_msg_error(fctid, "cannot fill bad zones") ;
+        cpl_msg_error(cpl_func, "cannot fill bad zones") ;
         return NULL ;
     }
 
@@ -976,7 +976,7 @@ static cpl_apertures * sinfo_distortion_detect_arcs(
     /* Threshold to keep only the arcs - use of the collapsed image */
     if (sinfo_distortion_threshold1d(filt_im, median_val,
                                      collapsed, 0.0)==-1) {
-        cpl_msg_error(fctid, "cannot threshold the filtered image") ;
+        cpl_msg_error(cpl_func, "cannot threshold the filtered image") ;
         cpl_image_delete(filt_im) ;
         cpl_image_delete(collapsed) ;
         return NULL ;
@@ -988,14 +988,14 @@ static cpl_apertures * sinfo_distortion_detect_arcs(
             SINFO_DBL_MAX);
     cpl_image_delete(filt_im) ;
     if (bin_im == NULL) {
-        cpl_msg_error(fctid, "cannot binarise the image") ;
+        cpl_msg_error(cpl_func, "cannot binarise the image") ;
         return NULL ;
     }
 
     /* Test if there are enough good pixels */
     ngoodpix = cpl_mask_count(bin_im) ;
     if (ngoodpix < ARC_MINGOODPIX) {
-        cpl_msg_error(fctid, "Too few (%d) white pixels", ngoodpix) ;
+        cpl_msg_error(cpl_func, "Too few (%d) white pixels", ngoodpix) ;
         cpl_mask_delete(bin_im) ;
         return NULL ;
     }
@@ -1012,7 +1012,7 @@ static cpl_apertures * sinfo_distortion_detect_arcs(
 
     /* Compute statistics on objects */
     if ((det = cpl_apertures_new_from_image(im, *label_im)) == NULL) {
-        cpl_msg_error(fctid, "Cannot compute arcs stats") ;
+        cpl_msg_error(cpl_func, "Cannot compute arcs stats") ;
         cpl_image_delete(*label_im) ;
         *label_im = NULL ;
         return NULL ;
@@ -1024,14 +1024,14 @@ static cpl_apertures * sinfo_distortion_detect_arcs(
     /* Purge non-relevant arcs */
     if (sinfo_distortion_purge_arcs(im, &det, label_im, min_arclen,
                 max_arc_width, arc_sat) == -1) {
-        cpl_msg_error(fctid, "Cannot purge the arcs") ;
+        cpl_msg_error(cpl_func, "Cannot purge the arcs") ;
         cpl_image_delete(*label_im) ;
         *label_im = NULL ;
         cpl_apertures_delete(det) ;
         return NULL ;
     }
     if (cpl_apertures_get_size(det) < ARC_MINNBARCS) {
-        cpl_msg_error(fctid, "Not enough valid arcs (%" 
+        cpl_msg_error(cpl_func, "Not enough valid arcs (%"
                       CPL_SIZE_FORMAT " < %d)",
                 cpl_apertures_get_size(det), ARC_MINNBARCS) ;
         cpl_image_delete(*label_im) ;
@@ -1191,11 +1191,11 @@ static int sinfo_distortion_purge_arcs(
         int                 max_arcwidth,
         double              arc_sat)
 {
-    const char  *   fctid = "sinfo_distortion_purge_arcs" ;
+
     int             nb_arcs ;
-    int         *   selection ;
-    int             arclen, arcwidth, edge ;
-    double          mean ;
+
+
+
     int         *   plabim ;
     cpl_mask    *   bin_im ;
     int             nx, ny ;
@@ -1212,16 +1212,16 @@ static int sinfo_distortion_purge_arcs(
     ny = cpl_image_get_size_y(*lab_im) ;
 
     /* Allocate selection array */
-    selection = cpl_malloc(nb_arcs * sizeof(int)) ;
+    int* selection = cpl_malloc(nb_arcs * sizeof(int)) ;
     /* Loop on the different arcs candidates */
     /* sinfo_msg("min_arclen=%d max_arcwidth=%d",min_arclen,max_arcwidth); */
     for (i=0 ; i<nb_arcs ; i++) {
-        arclen = cpl_apertures_get_top(*arcs, i+1) -
+        int arclen = cpl_apertures_get_top(*arcs, i+1) -
             cpl_apertures_get_bottom(*arcs, i+1) + 1 ;
-        arcwidth = cpl_apertures_get_right(*arcs, i+1) -
+        int arcwidth = cpl_apertures_get_right(*arcs, i+1) -
             cpl_apertures_get_left(*arcs, i+1) + 1 ;
-        edge = cpl_apertures_get_left_y(*arcs, i+1) ;
-        mean = cpl_apertures_get_mean(*arcs, i+1) ;
+        int edge = cpl_apertures_get_left_y(*arcs, i+1) ;
+        double mean = cpl_apertures_get_mean(*arcs, i+1) ;
 
         /* Test if the current object is a valid arc */
 
@@ -1269,7 +1269,7 @@ static int sinfo_distortion_purge_arcs(
 
     /* Check if there are some valid arcs */
     if (cpl_apertures_get_size(*arcs) <= 0) {
-        cpl_msg_error(fctid, "No valid arc found") ;
+        cpl_msg_error(cpl_func, "No valid arc found") ;
         return -1 ;
     }
     /* Return  */
@@ -1284,7 +1284,7 @@ sinfo_distortion_get_arc_positions(
         int                 nb_samples,
         double          **  lines_pos)
 {
-    const char      *   fctid = "sinfo_distortion_get_arc_positions" ;
+
     int                 n_arcs ;
     cpl_image       *   filt_img ;
     cpl_matrix      *   kernel ;
@@ -1295,7 +1295,7 @@ sinfo_distortion_get_arc_positions(
     int             *   plabel_im ;
     int             *   arcs_samples_y ;
     int             *   computed ;
-    double              arclen ;
+
     int                 use_this_arc ;
     int                 obj ;
     int                 nx, ny ;
@@ -1330,7 +1330,7 @@ sinfo_distortion_get_arc_positions(
 
     /* Find out the Y coordinates along the arcs  */
     for (j=0 ; j<n_arcs ; j++) {
-        arclen = cpl_apertures_get_top(det,j+1) -
+        double arclen = cpl_apertures_get_top(det,j+1) -
             cpl_apertures_get_bottom(det,j+1) + 1 ;
         for (i=0 ; i<nb_samples ; i++) {
             arcs_samples_y[i+j*nb_samples] =
@@ -1362,7 +1362,7 @@ sinfo_distortion_get_arc_positions(
                 /* Find x coordinate of obj at the Y coord. */
                 if ((x_finepos = sinfo_distortion_fine_pos(filt_img,
                                 label_im, i, j)) < 0.0) {
-                    cpl_msg_error(fctid, "cannot find fine arc position") ;
+                    cpl_msg_error(cpl_func, "cannot find fine arc position") ;
                     cpl_image_delete(filt_img) ;
                     cpl_free(arcs_samples_y);
                     cpl_free(computed) ;
@@ -1403,7 +1403,7 @@ sinfo_distortion_fine_pos(
     double      grav_c ;
     double      sum ;
     double      max ;
-    double      val ;
+
     int         maxpos ;
     //int         im_extrem ;
     double      arc_pos ;
@@ -1423,7 +1423,7 @@ sinfo_distortion_fine_pos(
 
     /* While we stay in the same object... */
     do {
-        val = (double)pim[start_pos + y * nx] ;
+        double val = (double)pim[start_pos + y * nx] ;
         if (start_pos == 0) grav_c = 0.0 ;
         else grav_c += start_pos * val ;
         sum += val ;
@@ -1469,11 +1469,11 @@ sinfo_distortion_fine_pos(
 #define SQR(x) ((x)*(x))
 static cpl_image * sinfo_distortion_remove_ramp(const cpl_image * in)
 {
-    const char      *   fctid = "sinfo_distortion_remove_ramp" ;
+
     int                 ramp_present ;
     int                 nx, ny ;
-    int                 y, yhi, ylo;
-    cpl_vector      *   tmp_vector ;
+    int                 yhi, ylo;
+
     cpl_bivector    *   testpointlo ;
     double          *   testpointlo_x ;
     double          *   testpointlo_y ;
@@ -1490,8 +1490,8 @@ static cpl_image * sinfo_distortion_remove_ramp(const cpl_image * in)
     double              slope ;
     cpl_image       *   out ;
     float           *   pout ;
-    float               val ;
-    int                 i, j ;
+
+
 
     /* Initialise */
     nx = cpl_image_get_size_x(in) ;
@@ -1501,7 +1501,7 @@ static cpl_image * sinfo_distortion_remove_ramp(const cpl_image * in)
     if (in==NULL) return NULL ;
 
     if (ny<IS_SKIPZONE*IS_NB_TESTPOINTS){
-        cpl_msg_error(fctid, "image has %d lines, min=%d ",
+        cpl_msg_error(cpl_func, "image has %d lines, min=%d ",
                 ny, (int)(IS_SKIPZONE*IS_NB_TESTPOINTS*2));
         return NULL ;
     }
@@ -1517,9 +1517,10 @@ static cpl_image * sinfo_distortion_remove_ramp(const cpl_image * in)
     testpointlo = cpl_bivector_new(IS_NB_TESTPOINTS) ;
     testpointlo_x = cpl_bivector_get_x_data(testpointlo) ;
     testpointlo_y = cpl_bivector_get_y_data(testpointlo) ;
+    int i;
     for (i=0 ; i<IS_NB_TESTPOINTS ; i++) {
-        y = yhi + i * spacing;
-        tmp_vector = cpl_vector_new_from_image_row(in, y+1) ;
+        int y = yhi + i * spacing;
+        cpl_vector* tmp_vector = cpl_vector_new_from_image_row(in, y+1) ;
         testpointhi_x[i] = y - ny / 2;
         testpointhi_y[i] = cpl_vector_get_median_const(tmp_vector) ;
         cpl_vector_delete(tmp_vector) ;
@@ -1581,6 +1582,8 @@ static cpl_image * sinfo_distortion_remove_ramp(const cpl_image * in)
     out = cpl_image_duplicate(in) ;
     pout = cpl_image_get_data_float(out) ;
     if (ramp_present == 1) {
+        int j;
+        float val;
         for (j=0 ; j<ny/2 ; j++) {
             val = slope * (j-ny/2) ;
             for (i=0 ; i<nx ; i++)
