@@ -202,9 +202,9 @@ sinfo_print_cpl_frameset(const cpl_frameset *frames)
         sinfo_msg("NULL");
     }
     else {
-        const cpl_frame *f = NULL;
-        check(f = cpl_frameset_get_first_const(frames),
-                        "Error reading frameset");
+
+        cpl_frameset_iterator* it = cpl_frameset_iterator_new(frames);
+        const cpl_frame *f = cpl_frameset_iterator_get_const(it);
 
         if (f == NULL ) {
             sinfo_msg("[Empty frame set]");
@@ -212,10 +212,13 @@ sinfo_print_cpl_frameset(const cpl_frameset *frames)
         else {
             while (f != NULL ) {
                 check(sinfo_print_cpl_frame(f), "Could not print frame");
-                check(f = cpl_frameset_get_next_const(frames),
-                                "Error reading frameset");
+
+                cpl_frameset_iterator_advance(it, 1);
+                f = cpl_frameset_iterator_get_const(it);
+
             }
         }
+        cpl_frameset_iterator_delete(it);
     }
 
     cleanup: return cpl_error_get_code();
