@@ -29,114 +29,6 @@
 /************************************************************************
 *   NAME
 *        sinfo_focus.c -
-*        routines to determine the focus position of the detector
-*
-*   SYNOPSIS
-*   #include "sinfo_focus.h"
-*
-*   1) double sinfo_new_gaussian_ellipse ( double * xdat, double * parlist )
-*   2) void sinfo_new_gaussian_ellipse_deriv( double * xdat, 
-                                              double * parlist, 
-                                              double * dervs )
-*   3) static int new_inv_mat (void)
-*   4) static void new_get_mat ( double * xdat,
-*                            int    * xdim,
-*                            double * ydat,
-*                            double * wdat,
-*                            int    * ndat,
-*                            double * fpar,
-*                            double * epar,
-*                            int    * npar )
-*   5) static int new_get_vec ( double * xdat,
-*                           int    * xdim,
-*                           double * ydat,
-*                           double * wdat,
-*                           int    * ndat,
-*                           double * fpar,
-*                           double * epar,
-*                           int    * npar )
-*   6) int new_lsqfit ( double * xdat,
-*                   int    * xdim,
-*                   double * ydat,
-*                   double * wdat,
-*                   int    * ndat,
-*                   double * fpar,
-*                   double * epar,
-*                   int    * mpar,
-*                   int    * npar,
-*                   double * tol ,
-*                   int    * its ,
-*                   double * lab  )
-*   7) int sinfo_new_fit_2d_gaussian( cpl_image   * lineImage, 
-*                         double     * fit_par, 
-*                         double     * derv_par   
-*                         int        * mpar,
-*                         int          lleftx,
-*                         int          llefty,
-*                         int          halfbox_x,
-*                         int          halfbox_y, int* check )
-*   8) cpl_image * sinfo_new_plot_gaussian ( cpl_image   * image, 
-*                                double     * parlist )
-*   9) static int new_gauss2ellipse ( double     * parlist ,
-*  10) float sinfo_new_determine_conversion_factor ( cpl_imagelist * cube, 
-*                                        float     mag,
-*                                        float     exptime,
-*                                        int       lleftx,
-*                                        int       llefty,
-*                                        int       halfbox_x,
-*                                        int       halfbox_y, 
-*                                        int* check )
-*
-*   DESCRIPTION
-*   1) Compute the value of a 2d Gaussian function at a given point.
-*      The ellptical 2D Gaussian is:
-*      F(x,y) = par(2) * EXP( -4.0*log(2.0)*[(xr/par(4))^2+(yr/par(5))^2]) + 
-                par(3),
-*      where: xr = xo * cos(par(6)) + yo * sin(par(6))
-*      yr = -xo * sin(par(6)) + yo * cos(par(6))
-*      and:   x0 = x - par(0)
-*             y0 = y - par(1)
-*   2) calculates the partial derivatives for a 2d Gaussian function with
-*      parameters parlist at position xdat 
-*   3) calculates the inverse of matrix2. The algorithm used 
-*      is the Gauss-Jordan algorithm described in Stoer,
-*      Numerische Mathematik, 1. Teil.
-*   4) builds the sinfo_matrix 
-*   5) calculates the correction sinfo_vector. The sinfo_matrix has been
-*      built by get_mat(), we only have to rescale it for the 
-*      current value of labda. The sinfo_matrix is rescaled so that
-*      the diagonal gets the value 1 + labda.
-*      Next we calculate the inverse of the sinfo_matrix and then
-*      the correction sinfo_vector.
-*   6) this is a routine for making a least-squares fit of a
-*      function to a set of data points. The method used is
-*      described in: Marquardt, J.Soc.Ind.Appl.Math. 11. 431 (1963).
-*      This method is a mixture of the steepest descent method 
-*      and the Taylor method.
-*   7) fits the image of a point source by using a 2-D Gaussian
-*      fit.
-*   8) plots an image of a given 2D-Gaussian 
-*   9) converts gauss parameters to ellipse parameters. 
-*  10) determines an intensity conversion factor for the instrument
-*      by fitting a 2D-Gaussian to an collapsed image of a standard star
-*      with known brightness (only for non-AO observations).
-*      Then the resulting Gaussian is integrated and the counts
-*      are divided by the exposure time (Fits header information) 
-*
-*   FILES
-*
-*   ENVIRONMENT
-*
-*   RETURN VALUES
-*
-*   CAUTIONS
-*
-*   EXAMPLES
-*
-*   SEE ALSO
-*
-*   BUGS
-*
 *------------------------------------------------------------------------
 */
 
@@ -214,7 +106,7 @@ static int new_gauss2Ellipse ( double  * parlist ) ;
 /**
  * @defgroup sinfo_focus Focus determination functions
  *
- * TBD
+ * routines to determine the focus position of the detector
  */
 
 
@@ -368,6 +260,7 @@ sinfo_new_gaussian_ellipse_deriv(double * xdat,
    
    The algorithm used is the Gauss-Jordan algorithm described in Stoer,
    Numerische Mathematik, 1. Teil.
+
  */
 
 static int new_inv_mat (void)
@@ -375,9 +268,9 @@ static int new_inv_mat (void)
     double even ;
     double hv[NPAR] ;
     double mjk ;
-    double rowmax ;
+
     int evin ;
-    int i, j, k, row ;
+    int i, j, k;
     int per[NPAR] ;
    
     /* set permutation array */
@@ -389,8 +282,8 @@ static int new_inv_mat (void)
     for ( j = 0 ; j < nfree ; j++ ) /* in j-th column */
     {
         /* determine largest element of a row */                                
-        rowmax = fabs ( matrix2[j][j] ) ;
-        row = j ;                         
+        double rowmax = fabs ( matrix2[j][j] ) ;
+        int row = j ;
 
         for ( i = j + 1 ; i < nfree ; i++ )
         {
@@ -502,7 +395,7 @@ static void new_get_mat ( double * xdat,
                       int    * npar */)
 {
     double wd ;
-    double wn ;
+
     double yd ;
     int i, j, n ;
 
@@ -520,7 +413,7 @@ static void new_get_mat ( double * xdat,
     /* loop through data points */
     for ( n = 0 ; n < (*ndat) ; n++ )
     {
-        wn = wdat[n] ;
+        double wn = wdat[n] ;
         if ( wn > 0.0 )  /* legal weight ? */
         {
             yd=ydat[n] - sinfo_new_gaussian_ellipse(&xdat[(*xdim) * n],fpar) ;
@@ -559,10 +452,12 @@ static void new_get_mat ( double * xdat,
           )
  
 
-calculates the correction sinfo_vector. The sinfo_matrix has been
-built by get_mat(), we only have to rescale it for the current value of labda. 
-The sinfo_matrix is rescaled so that the diagonal gets the value 1 + labda.
+calculates the correction vector. The matrix has been
+built by get_mat(), we only have to re-scale it for the current value of lambda.
+The matrix is rescaled so that the diagonal gets the value 1 + lambda.
 Next we calculate the inverse of the matrix and then the correction vector.
+
+
  */
             
 static int new_get_vec ( double * xdat,
@@ -574,12 +469,12 @@ static int new_get_vec ( double * xdat,
                      double * epar,
                      int    * npar )
 {
-    double dj ;
+
     double dy ;
     double mii ;
     double mji ;
     double mjj ;
-    double wn ;
+
     int i, j, n, r ;
 
     /* loop to modify and scale the sinfo_matrix */
@@ -612,7 +507,7 @@ static int new_get_vec ( double * xdat,
     /* loop to calculate correction sinfo_vector */
     for ( j = 0 ; j < nfree ; j++ )
     {
-        dj = 0.0 ;
+        double dj = 0.0 ;
         mjj = matrix1[j][j] ;
         if ( mjj <= 0.0)               /* not allowed */
         {
@@ -636,7 +531,7 @@ static int new_get_vec ( double * xdat,
     /* loop through the data points */
     for ( n = 0 ; n < (*ndat) ; n++ )
     {
-        wn = wdat[n] ;               /* get weight */
+        double wn = wdat[n] ;               /* get weight */
         if ( wn > 0.0 )              /* legal weight */
         {
             dy=ydat[n] - sinfo_new_gaussian_ellipse(&xdat[(*xdim) * n],epar);
@@ -693,6 +588,7 @@ static int new_get_vec ( double * xdat,
  data points. The method used is described in: 
  Marquardt, J.Soc.Ind.Appl.Math. 11. 431 (1963).
  This method is a mixture of the steepest descent method and the Taylor method.
+
  */
 
 int sinfo_new_lsqfitd ( double * xdat,
@@ -917,6 +813,8 @@ int sinfo_new_lsqfitd ( double * xdat,
   values corresponds to a shift of theta by PI/2. Consequently, an expected 
   theta > |PI/4| will result in an exchange of the fwhm values and a shift of 
   theta by PI/2 to a value < |PI/4| what yields exactly the same image.
+
+
  */
 
 int 
@@ -953,11 +851,11 @@ sinfo_new_fit_2d_gaussian ( cpl_image   * image,
     double xco, yco ;
     double value ;
     double denom ;
-    double temp ;
+
     int llx, lly ;
     int foundrow ;
     int foundcol ;
-    int k ;
+
     int ilx=0;
     int ily=0;
     float* pidata=NULL;
@@ -1194,8 +1092,8 @@ sinfo_new_fit_2d_gaussian ( cpl_image   * image,
   
     /* first scale the moments */
     /* TODO: why use Mx is later this is never used? */
-    Mx  /= M ;
-    My  /= M ;
+    //Mx  /= M ;
+    //My  /= M ;
     Mxx /= M ;
     Myy /= M ;
     Mxy /= M ;
@@ -1275,7 +1173,7 @@ sinfo_new_fit_2d_gaussian ( cpl_image   * image,
         /* first convert angle to smaller than 2 pi */
         if ( fabs (fit_par[6]) >= 2. * PI_NUMB )
         { 
-            k = (int) (fit_par[6] / (2.*PI_NUMB)) ;
+            int k = (int) (fit_par[6] / (2.*PI_NUMB)) ;
             if ( k > 0 ) 
             {
                 fit_par[6] -= k*2.*PI_NUMB ;
@@ -1300,7 +1198,7 @@ sinfo_new_fit_2d_gaussian ( cpl_image   * image,
 
         if ( fabs (fit_par[6]) > PI_NUMB / 4. )
         {
-            temp       = fit_par[4] ;
+            double temp       = fit_par[4] ;
             fit_par[4] = fit_par[5] ;
             fit_par[5] = temp ;
             if ( fit_par[6] < 0. )
@@ -1327,7 +1225,7 @@ sinfo_new_fit_2d_gaussian ( cpl_image   * image,
  */
 
 cpl_image * 
-sinfo_new_plot_gaussian (cpl_image   * image, 
+sinfo_crea_gaussian (cpl_image   * image,
                          double     * parlist )
 {
     int col, row ;
@@ -1370,7 +1268,7 @@ sinfo_new_plot_gaussian (cpl_image   * image,
 @brief converts gauss parameters to ellipse parameters.
 
    @param parlist: parameters of 2D-Gaussian
-   @return parlist: transformed Gaussian parameters to ellipse parameters
+   @return 0 (transformed Gaussian parameters to ellipse parameters)
   */
 
 static int new_gauss2Ellipse ( double     * parlist )
@@ -1429,7 +1327,7 @@ static int new_gauss2Ellipse ( double     * parlist )
 }
 
 /**
-@brief Determines the convertion factor for an instrument
+@brief Determines the conversion factor for an instrument
    
    @param cube       reduced data cube of a standard star
    @param mag        brightness of the standard star
@@ -1449,6 +1347,8 @@ static int new_gauss2Ellipse ( double     * parlist )
    2D-Gaussian to an collapsed image of a standard star with known brightness 
    (only for non-AO observations). Then the resulting Gaussian is integrated 
    and the counts are divided by the exposure time (Fits header information) 
+
+
  */
 
 float sinfo_new_determine_conversion_factor ( cpl_imagelist * cube, 
@@ -1467,7 +1367,7 @@ float sinfo_new_determine_conversion_factor ( cpl_imagelist * cube,
     int mpar[7] ;
     double fit_par[7] ;
     double derv_par[7] ;
-    int fitInd ;
+
     double sum ;
     double xdat[2] ;
     cpl_image * summedIm ;
@@ -1510,6 +1410,7 @@ float sinfo_new_determine_conversion_factor ( cpl_imagelist * cube,
     {
         mpar[i] = 1 ;
     }
+    int fitInd ;
     if ( -1 == (fitInd = sinfo_new_fit_2d_gaussian(summedIm, fit_par, derv_par,
                                                    mpar, llx, lly, halfbox_x, 
                                                    halfbox_y, check)) )
