@@ -401,6 +401,7 @@ function1d_generate_smooth_kernel(int filt_type, int hw)
     default:
         sinfo_msg_error("unrecognized low pass filter: "
                         "cannot generate kernel") ;
+        cpl_free( kernel );
         return (double*)NULL ;
         break ;
     }
@@ -543,7 +544,7 @@ sinfo_function1d_remove_thermalbg(
     *    spl_y ;
     double            med_y ;
     double            avg2med ;
-    double            dist ;
+
 
 
     /* Detect all local minima */
@@ -590,7 +591,7 @@ sinfo_function1d_remove_thermalbg(
 
     /* Reset all pixels out of sinfo_median + 2 * avg2med to zero. */
     for (i=0 ; i<ns ; i++) {
-        dist = fabs((double)pixel_signal[i] - med_y);
+        double dist = fabs((double)pixel_signal[i] - med_y);
         if (dist > (2.0*avg2med)) {
             spl_y[i] = (pixelvalue)0 ;
         }
@@ -644,11 +645,11 @@ sinfo_function1d_interpolate_linear(
 {
     double        a, b ;
     int            i, j ;
-    int            found ;
+
 
     for (i=0 ; i<spl_len ; i++) {
         /* Find (x1,y1) on the left of the current point */
-        found = 0 ;
+        int found = 0 ;
         for (j=0 ; j<(len-1) ; j++) {
             if ((spl_x[i]>=x[j]) && (spl_x[i]<=x[j+1])) {
                 found++ ;
@@ -691,15 +692,13 @@ function1d_search_value(
                 int         *    foundPtr
 )
 {
-    int    high,
-    low,
-    middle;
 
-    low  = 0;
-    high = len - 1;
+
+    int low  = 0;
+    int high = len - 1;
 
     while (high >= low) {
-        middle = (high + low) / 2;
+        int middle = (high + low) / 2;
         if (key > x[middle]) {
             low = middle + 1;
         } else if (key < x[middle]) {
@@ -762,8 +761,7 @@ sinfo_function1d_natural_spline(
     *    a,
     *    b,
     *    c,
-    *    d,
-    v;
+    *    d;
 
     end = len - 1;
 
@@ -819,7 +817,7 @@ sinfo_function1d_natural_spline(
 
     /* Now calculate the new values */
     for (j = 0; j < splLen; j++) {
-        v = (double)splX[j];
+        double v = (double)splX[j];
         splY[j] = (pixelvalue)0;
 
         /* Is it outside the interval? */
@@ -940,7 +938,7 @@ sinfo_function1d_xcorrelate(
     int      nsteps ;
     int      i ;
     int      step ;
-    int      nval ;
+
 
 
     /* Compute normalization factors */
@@ -968,7 +966,7 @@ sinfo_function1d_xcorrelate(
     xcorr = cpl_malloc(nsteps * sizeof(double));
     for (step=STEP_MIN ; step<=STEP_MAX ; step++) {
         xcorr[step-STEP_MIN] = 0.00 ;
-        nval = 0 ;
+        int nval = 0 ;
         for (i=0 ; i<width_t ; i++) {
             if ((i+step > 0) &&
                             (i+step < width_i)) {
