@@ -39,9 +39,6 @@ int sinfo_print_rec_status(const int val);
 cpl_frameset *
 sinfo_frameset_extract(const cpl_frameset *frames,const char *tag);
 
-int 
-sinfo_propertylist_has(cpl_propertylist* plist,const char* key);
-
 cpl_vector* 
 sinfo_vector_clip(const cpl_vector* vinp, 
                   const double kappa, 
@@ -58,29 +55,7 @@ sinfo_image_estimate_noise(cpl_image* img,
 
 cpl_table* sinfo_compute_gain(cpl_frameset* son, cpl_frameset* sof);
 cpl_table* sinfo_compute_linearity(cpl_frameset* son, cpl_frameset* sof);
-cpl_error_code sinfo_fit_lm(const cpl_matrix *x, 
-                            const cpl_matrix *sigma_x,
-                const cpl_vector *y, 
-                            const cpl_vector *sigma_y,
-                      cpl_vector *a, 
-                            const int ia[],
-                int    (*f)(const double x[], 
-                                        const double a[], 
-                          double *result),
-                 int (*dfda)(const double x[], 
-                                             const double a[], 
-                         double result[]),
-                 double *mse,
-                 double *red_chisq,
-                 cpl_matrix **covariance);
 
-void
-sinfo_fit_amoeba(double**p, 
-       double y[], 
-       int ndim, 
-       double ftol, 
-       double (*funk)(double[]),
-       int* nfunk);
 
 int sinfo_vector_dindgen(cpl_vector** v);
 int sinfo_is_fits_file(const char *filename);
