@@ -85,14 +85,13 @@
 pixelvalue 
 sinfo_kth_smallest(pixelvalue a[], int n, int k)
 {
-    register int i,j,l,m ;
-    register pixelvalue x ;
 
-    l=0 ; m=n-1 ;
+    register int l=0 ;
+    register int m=n-1 ;
     while (l<m) {
-        x=a[k] ;
-        i=l ;
-        j=m ;
+        register pixelvalue x=a[k] ;
+        register int i=l ;
+        register int j=m ;
         do {
             while (a[i]<x) i++ ;
             while (x<a[j]) j-- ;
@@ -128,14 +127,13 @@ sinfo_kth_smallest(pixelvalue a[], int n, int k)
 double 
 sinfo_kth_smallest_double(double a[], int n, int k)
 {
-    register int i,j,l,m ;
-    register double x ;
 
-    l=0 ; m=n-1 ;
+    register int l=0 ;
+    register int m=n-1 ;
     while (l<m) {
-        x=a[k] ;
-        i=l ;
-        j=m ;
+        register double x=a[k] ;
+        register int i=l ;
+        register int j=m ;
         do {
             while (a[i]<x) i++ ;
             while (x<a[j]) j-- ;
