@@ -190,8 +190,6 @@ sinfo_new_c_bezier_interpolate_image(cpl_image *im, cpl_image *mask,
     float* ptdata = NULL;
     float* padata = NULL;
 
-    cpl_image* sc_img = NULL;
-    cpl_image* drs_img = NULL;
 
     mlx = cpl_image_get_size_x(mask);
     mly = cpl_image_get_size_y(mask);
@@ -217,7 +215,7 @@ sinfo_new_c_bezier_interpolate_image(cpl_image *im, cpl_image *mask,
     }
 
     for (i = 0; i < szz; i++) {
-        sc_img = cpl_image_new(szx, szy, CPL_TYPE_FLOAT);
+        cpl_image* sc_img = cpl_image_new(szx, szy, CPL_TYPE_FLOAT);
         cpl_imagelist_set(sc_im, sc_img, i);
     }
 
@@ -226,7 +224,7 @@ sinfo_new_c_bezier_interpolate_image(cpl_image *im, cpl_image *mask,
         return NULL ;
     }
     for (i = 0; i < szz; i++) {
-        drs_img = cpl_image_new(szx, szy, CPL_TYPE_FLOAT);
+        cpl_image* drs_img = cpl_image_new(szx, szy, CPL_TYPE_FLOAT);
         cpl_imagelist_set(drs_sc_mask, drs_img, i);
     }
 
@@ -327,8 +325,6 @@ short rx,
     float* pidata = NULL;
     //float* pmdata=NULL;
 
-    cpl_image* sc_img = NULL;
-    cpl_image* drs_img = NULL;
 
     mlx = cpl_image_get_size_x(mask);
     mly = cpl_image_get_size_y(mask);
@@ -353,7 +349,7 @@ short rx,
         return NULL ;
     }
     for (i = 0; i < szz; i++) {
-        sc_img = cpl_image_new(szx, szy, CPL_TYPE_FLOAT);
+        cpl_image* sc_img = cpl_image_new(szx, szy, CPL_TYPE_FLOAT);
         cpl_imagelist_set(sc_im, sc_img, i);
     }
 
@@ -362,7 +358,7 @@ short rx,
         return NULL ;
     }
     for (i = 0; i < szz; i++) {
-        drs_img = cpl_image_new(szx, szy, CPL_TYPE_FLOAT);
+        cpl_image* drs_img = cpl_image_new(szx, szy, CPL_TYPE_FLOAT);
         cpl_imagelist_set(drs_sc_mask, drs_img, i);
     }
 
@@ -705,6 +701,7 @@ sinfo_new_c_bezier_correct_pixel_2D(int ipos, int jpos, cpl_image * im,
                     counter++;
                 }
                 sc_img = cpl_imagelist_get(sc_im, ks);
+                pscdata = cpl_image_get_data_float(sc_img);
                 pscdata[sinfo_cu_xy(sc_im, is, js)] = pidata[sinfo_im_xy(im,
                                 indexI, indexJ)];
                 drs_img = cpl_imagelist_get(drs_sc_mask, ks);
@@ -794,8 +791,8 @@ sinfo_new_c_bezier_interpol(cpl_imagelist * im, cpl_imagelist * action)
     new_XYZW indata[1000];
     new_XYZW res;
     new_XYZW selected;
-    float step, cumstep, distance, selected_distance;
-    new_Dim *point = NULL;
+    float step, cumstep, selected_distance;
+    new_Dim *point;
     double munk;
     int ilx = 0;
     int ily = 0;
@@ -877,7 +874,7 @@ sinfo_new_c_bezier_interpol(cpl_imagelist * im, cpl_imagelist * action)
     for (i = 0; (i < 100) && (munk != 0.0); i++) {
         memset(&res, 0x00, sizeof(new_XYZW));
         sinfo_new_bezier(indata, pos - 1, cumstep, munk, &res);
-        distance = sqrt(
+        float distance = sqrt(
                         pow(((*point).x - res.x), 2)
                                         + pow(((*point).y - res.y), 2)
                                         + pow(((*point).z - res.z), 2));
@@ -910,15 +907,13 @@ sinfo_new_c_bezier_interpol(cpl_imagelist * im, cpl_imagelist * action)
 int
 sinfo_new_bezier(new_XYZW *p, int n, double mu, double munk, new_XYZW *res)
 {
-    int k, kn, nn, nkn;
-    double blend, muk;
 
-    muk = 1;
-    for (k = 0; k <= n; k++) {
-        nn = n;
-        kn = k;
-        nkn = n - k;
-        blend = muk * munk;
+    double muk = 1;
+    for (int k = 0; k <= n; k++) {
+        int nn = n;
+        int kn = k;
+        int nkn = n - k;
+        double blend = muk * munk;
         muk *= mu;
         munk /= (1.0 - mu);
         while (nn >= 1) {
@@ -972,14 +967,20 @@ sinfo_new_c_create_XYZ(new_Lookup *l)
     }
     if (NULL == (imY = cpl_image_new(size, size, CPL_TYPE_FLOAT))) {
         sinfo_msg_error(" could not allocate memory for Y !\n");
+        cpl_image_delete(imX);
         return -1;
     }
     if (NULL == (imZ = cpl_image_new(size, size, CPL_TYPE_FLOAT))) {
         sinfo_msg_error(" could not allocate memory for Z !\n");
+        cpl_image_delete(imX);
+        cpl_image_delete(imY);
         return -1;
     }
     if (NULL == (imcX = cpl_image_new(size, size, CPL_TYPE_FLOAT))) {
         sinfo_msg_error(" could not allocate memory for cX !\n");
+        cpl_image_delete(imX);
+        cpl_image_delete(imY);
+        cpl_image_delete(imZ);
         return -1;
     }
 
@@ -1026,10 +1027,8 @@ sinfo_new_c_create_XYZ(new_Lookup *l)
     }
 #define  FORW
 #ifdef BACK
-    for( x = idlx - 1;x>=0;x--)
-    {
-        for( y = idly - 1;y>=0;y--)
-        {
+    for( x = idlx - 1;x>=0;x--) {
+        for( y = idly - 1;y>=0;y--) {
             for( z = idnp - 1;z>=0;z--)
 #endif
 #ifdef FORW
