@@ -43,7 +43,7 @@ nodding observations
 #include "sinfo_cube_construct.h"
 #include "sinfo_error.h"
 #include "sinfo_utils_wrappers.h"
-//Used only for sinfo_propertylist_has
+//Used only for cpl_propertylist_has
 #include "sinfo_dfs.h"
 /*----------------------------------------------------------------------------
   Defines
@@ -241,7 +241,7 @@ sinfo_new_cubes_coadd (const char* plugin_id,cpl_parameterlist* config,
         /* get some header values and compute the CD-sinfo_matrix */
         plist=cpl_propertylist_load(name,0);
 
-        if (sinfo_propertylist_has(plist, KEY_NAME_MJD_OBS)) {
+        if (cpl_propertylist_has(plist, KEY_NAME_MJD_OBS)) {
             mjd_obs=cpl_propertylist_get_double(plist, KEY_NAME_MJD_OBS);
         } else {
             sinfo_msg_error("keyword %s does not exist",KEY_NAME_MJD_OBS);
