@@ -251,7 +251,7 @@ sinfo_new_find_distortions(const char* plugin_id,
     /* find the emission lines in each image column */
     sinfo_new_intarray_set_value(sum_pointer, 0, 0);
 
-    ck0(check = sinfo_new_find_lines(im,
+    ck0((check = sinfo_new_find_lines(im,
                     wave,
                     intens,
                     n_lines,
@@ -264,7 +264,7 @@ sinfo_new_find_distortions(const char* plugin_id,
                     cfg->halfWidth,
                     n_found_lines,
                     cfg->sigma,
-                    sum_pointer ),
+                    sum_pointer )),
         "FindLines failed!");
 
     sinfo_free_table(&tbl_line_list);
