@@ -241,6 +241,7 @@ if (cfg->calibIndicator == 1 || cfg->wavemapInd == 1) {
     if(cpl_error_get_code() != CPL_ERROR_NONE) {
       sinfo_msg_error("%s", (char* ) cpl_error_get_message());
       sinfo_qc_wcal_delete(&qc);
+      cpl_image_delete(im);
       return -1;
     }
 
@@ -256,6 +257,7 @@ if (cfg->calibIndicator == 1 || cfg->wavemapInd == 1) {
     if(cpl_error_get_code() != CPL_ERROR_NONE) {
       sinfo_msg_error("%s", (char* ) cpl_error_get_message());
       sinfo_qc_wcal_delete(&qc);
+      cpl_image_delete(im);
       return -1;
     }
 
@@ -273,6 +275,7 @@ if (cfg->calibIndicator == 1 || cfg->wavemapInd == 1) {
     if(cpl_error_get_code() != CPL_ERROR_NONE) {
       sinfo_msg_error("%s", (char* ) cpl_error_get_message());
       sinfo_qc_wcal_delete(&qc);
+      cpl_image_delete(im);
       return -1;
     }
 
@@ -280,6 +283,7 @@ if (cfg->calibIndicator == 1 || cfg->wavemapInd == 1) {
     if(cpl_error_get_code() != CPL_ERROR_NONE) {
       sinfo_msg_error("%s", (char* ) cpl_error_get_message());
       sinfo_qc_wcal_delete(&qc);
+      cpl_image_delete(im);
       return -1;
     }
     
@@ -573,6 +577,8 @@ if (cfg->calibIndicator == 1 && cfg->wavemapInd == 0) {
       sinfo_msg("cannot load table %s",tbl_name);
       sinfo_msg_error("%s", (char* ) cpl_error_get_message());
       sinfo_qc_wcal_delete(&qc);
+      cpl_image_delete(im);
+      cpl_free(col_name);
       return -1;
     }
    for (i =0; i < lx; i++) {
