@@ -40,7 +40,7 @@
  ---------------------------------------------------------------------------*/
 #include <math.h>
 
-//Used only for sinfo_propertylist_has
+//Used only for cpl_propertylist_has
 #include <irplib_stdstar.h>
 #include <sinfo_cpl_size.h>
 #include "irplib_utils.h"
@@ -241,7 +241,7 @@ sinfo_new_stdstar(const char* plugin_id,
     /* dispersion = sinfo_pfits_get_cdelt3(plist); */
 
 
-    if (sinfo_propertylist_has(plist, KEY_NAME_CDELT3)) {
+    if (cpl_propertylist_has(plist, KEY_NAME_CDELT3)) {
       disp=cpl_propertylist_get_double(plist, KEY_NAME_CDELT3);
     } else {
       sinfo_msg_warning("Keyword %s not found.",KEY_NAME_CDELT3);
@@ -316,12 +316,22 @@ sinfo_new_stdstar(const char* plugin_id,
 
     check_nomsg(std_med_dup=cpl_image_duplicate(std_med_ima));
     sinfo_clean_nan(&std_med_dup);
-    check_nomsg(cpl_image_get_maxpos(std_med_dup,&max_ima_x,&max_ima_y));
+    ima_szx=cpl_image_get_size_x(std_med_ima);
+    ima_szy=cpl_image_get_size_y(std_med_ima);
+    /* TODO: Here we remove 3 pixels at the image margin to prevent problems
+     * with spikes at the image borders that could be more intense than the PSF
+     * image peak. On the other side this does not prevent that other pixels
+     * in the image are flagged. Better would be to flag any bad pixel/outlier
+     * using HDRL.
+     */
+    int margin=3;
+    check_nomsg(cpl_image_get_maxpos_window(std_med_dup,
+                    margin,margin,ima_szx-margin,ima_szy-margin,
+                    &max_ima_x,&max_ima_y));
     sinfo_free_image(&std_med_dup);
 
 
-    ima_szx=cpl_image_get_size_x(std_med_ima);
-    ima_szy=cpl_image_get_size_y(std_med_ima);
+
     wllx= ((max_ima_x-psf_sz)>0)       ? (max_ima_x-psf_sz) : 1;
     wlly= ((max_ima_y-psf_sz)>0)       ? (max_ima_y-psf_sz) : 1;
     wurx= ((max_ima_x+psf_sz)<ima_szx) ? (max_ima_x+psf_sz) : ima_szx ;
@@ -337,7 +347,6 @@ sinfo_new_stdstar(const char* plugin_id,
     check_nomsg(max_ima_cy=cpl_image_get_centroid_y_window(std_med_ima,wllx,
                                                              wlly,wurx,wury));
 
-
       xshift=max_ima_cx-ima_szx/2;
       yshift=max_ima_cy-ima_szy/2;
 
@@ -362,7 +371,6 @@ sinfo_new_stdstar(const char* plugin_id,
         psf_sz = (psf_sz > 4) ? psf_sz : 4;
       }
 
-
       ck0_nomsg(sinfo_qclog_add_int(qclog_tbl,"QC FWHM LLX",cfg->llx,
                                     "STD star FWHM LLX","%d"));
       ck0_nomsg(sinfo_qclog_add_int(qclog_tbl,"QC FWHM LLY",cfg->lly,
@@ -404,7 +412,6 @@ sinfo_new_stdstar(const char* plugin_id,
 
      }
 
-
     /*
     sinfo_msg("Gauss fit params: xc,yc,amp,bkg,fwhm_x,fwhm_y,angle\n");
     for ( i = 0 ; i < 7 ; i++ )
@@ -412,6 +419,7 @@ sinfo_new_stdstar(const char* plugin_id,
         sinfo_msg("fpar[%d]=%f dpar[%d]=%f\n",i,fpar[i],i,dpar[i]);
       }
     */
+
     if(CPL_ERROR_NONE == cpl_image_fit_gaussian(std_med_ima,
                                                 max_ima_x,
                                                 max_ima_y,
@@ -440,6 +448,7 @@ sinfo_new_stdstar(const char* plugin_id,
       cpl_error_reset();
 
     }
+
     sinfo_free_image(&std_med_ima);
 
       /*
@@ -454,7 +463,7 @@ sinfo_new_stdstar(const char* plugin_id,
       cfg -> llx = (cfg -> llx  > 0 ) ? cfg -> llx  : 1;
 
       if((cfg->llx+2*cfg->halfbox_x) >= ima_szx) {
-    cfg -> halfbox_x=(int) ((ima_szx-cfg->llx-1)/2);
+        cfg -> halfbox_x=(int) ((ima_szx-cfg->llx-1)/2);
         check1++;
       }
 
@@ -467,7 +476,6 @@ sinfo_new_stdstar(const char* plugin_id,
      ck0_nomsg(sinfo_qclog_add_int(qclog_tbl,"QC CHECK1",check1,
                                     "Check on evaluation box","%d"));
 
-
     /*
       sinfo_msg("llx= %d lly= %d\n",cfg->llx, cfg->lly);
       sinfo_msg("halfbox_x=%d halfbox_y=%d\n",cfg->halfbox_x,cfg->halfbox_y);
@@ -525,7 +533,6 @@ sinfo_new_stdstar(const char* plugin_id,
      }
 
 
-
 	ck0_nomsg(sinfo_qclog_add_int(qclog_tbl,"QC CHECK2",
                                        check2,"Check on evaluation box","%d"));
 
@@ -619,11 +626,8 @@ sinfo_new_stdstar(const char* plugin_id,
 
         ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,"QC CONVFCT",cleanfactor,
                                          "Conversion factor","%g"));
-
         ck0_nomsg(sinfo_qclog_add_int(qclog_tbl,"QC CHECK3",check3,
                                       "Check evaluation box","%d"));
-
-
         ck0(sinfo_pro_save_ima(img_spct,ref_set,sof,cfg->outName,
                     PRO_STD_STAR_SPECTRUM,qclog_tbl,
                  plugin_id,config),
