@@ -43,6 +43,7 @@
 #include "sinfo_hidden.h"
 
 #include "sinfo_utilities.h"
+#include "sinfo_utilities_scired.h"
 #include "sinfo_utils_wrappers.h"
 #include "sinfo_error.h"
 
@@ -292,7 +293,7 @@ sinfo_new_wave_cal_slit2(const char* plugin_id,
         /*find the emission lines in each image column*/
         sinfo_new_intarray_set_value(sum_pointer, 0, 0);
 
-        ck0(check = sinfo_new_find_lines(im,
+        ck0( (check = sinfo_new_find_lines(im,
                         wave,
                         intens,
                         n_lines,
@@ -305,7 +306,7 @@ sinfo_new_wave_cal_slit2(const char* plugin_id,
                         cfg->halfWidth,
                         n_found_lines,
                         cfg->sigma,
-                        sum_pointer),
+                        sum_pointer) ),
             "sinfo_findLines failed!");
 
         /*---------------------------------------------------------------------
@@ -872,6 +873,7 @@ sinfo_image_resample(const char* plugin_id,
     cpl_parameter* p=NULL;
     cpl_image* wstk_img=NULL;
     cpl_image* map_img=NULL;
+    int x_cen=0;
 
     check_nomsg(p = cpl_parameterlist_find(config,
                     "sinfoni.wavecal.n_coeffs"));
@@ -902,11 +904,13 @@ sinfo_image_resample(const char* plugin_id,
            " sinfo_definedResampling() failed" ) ;
 
 
-
+    x_cen=0.5*cpl_image_get_size_x(wstk_img);
     ck0(sinfo_pro_save_ima(res_ima,ref_set,sof,WAVECAL_RESAMPLED_OUT_FILENAME,
                     PRO_RESAMPLED_WAVE,NULL,plugin_id,config),
         "cannot save ima %s",WAVECAL_RESAMPLED_OUT_FILENAME);
 
+    sinfo_set_wcs_cal_image(res_ima,WAVECAL_RESAMPLED_OUT_FILENAME,
+                            (double)x_cen,(double)x_cen,1.,(double)cpix,cwav,dis);
 
     cleanup:
 
