@@ -51,77 +51,13 @@ sinfo_clean_header(cpl_propertylist** header);
 static void
 sinfo_clean_cube_header(cpl_propertylist** header);
 
-
-static FILE * 
-sinfo_paf_print_header(
-                const char    *   filename,
-                const char    *   paf_id,
-                const char    *   paf_desc,
-                const char    *   login_name,
-                char    *   datetime) ;
-
-
-
 /**@{*/
 /**
  * @defgroup sinfo_pro_save Functions to save a product
  *
  * TBD
  */
-/*--------------------------------------------------------------------------*/
-/**
-   @brief    Open a new PAF file, output a default header.
-   @param    filename    Name of the file to create.
-   @param    paf_id        PAF identificator.
-   @param    paf_desc    PAF description.
-   @param    login_name  Login name
-   @param    datetime    Date
-   @return    Opened file pointer.
 
-   This function creates a new PAF file with the requested file name.
-   If another file already exists with the same name, it will be
-   overwritten (if the file access rights allow it).
-
-   A default header is produced according to the VLT DICB standard. You
-   need to provide an identificator (paf_id) of the producer of the
-   file. Typically, something like "ISAAC/zero_point".
-
-   The PAF description (paf_desc) is meant for humans. Typically,
-   something like "Zero point computation results".
-
-   This function returns an opened file pointer, ready to receive more
-   data through fprintf's. The caller is responsible for fclose()ing
-   the file.
- */
-/*--------------------------------------------------------------------------*/
-static FILE * 
-sinfo_paf_print_header(
-                const char    *   filename,
-                const char    *      paf_id,
-                const char    *    paf_desc,
-                const char    *   login_name,
-                char    *   datetime)
-{
-    FILE * paf ;
-
-    if ((paf=fopen(filename, "w"))==NULL) {
-        sinfo_msg_error("cannot create PAF file [%s]", filename);
-        return NULL ;
-    }
-    fprintf(paf, "PAF.HDR.START         ;# start of header\n");
-    fprintf(paf, "PAF.TYPE              \"pipeline product\" ;\n");
-    fprintf(paf, "PAF.ID                \"%s\"\n", paf_id);
-    fprintf(paf, "PAF.NAME              \"%s\"\n", filename);
-    fprintf(paf, "PAF.DESC              \"%s\"\n", paf_desc);
-    fprintf(paf, "PAF.CRTE.NAME         \"%s\"\n", login_name) ;
-    fprintf(paf, "PAF.CRTE.DAYTIM       \"%s\"\n", datetime) ;
-    fprintf(paf, "PAF.LCHG.NAME         \"%s\"\n", login_name) ;
-    fprintf(paf, "PAF.LCHG.DAYTIM       \"%s\"\n", datetime) ;
-    fprintf(paf, "PAF.CHCK.CHECKSUM     \"\"\n");
-    fprintf(paf, "PAF.HDR.END           ;# end of header\n");
-    fprintf(paf, "\n");
-    return paf ;
-}
 /**
    @name sinfo_update_fits_card_int
    @brief update an integer card in the header of a FITS file
@@ -272,6 +208,7 @@ sinfo_update_ims_fits_card_string(cpl_imagelist* iml,
                     plist,CPL_IO_DEFAULT)!=CPL_ERROR_NONE) {
         sinfo_msg_error( "getting header from reference ima frame %s",file);
         cpl_propertylist_delete(plist) ;
+        return -1 ;
     }
     cpl_propertylist_delete(plist) ;
     return 0;
@@ -317,7 +254,7 @@ static int sinfo_save_paf(char* name_p,
   strcpy(key_name,KEY_NAME_PIPEFILE);        
   strcpy(key_paf,KEY_NAME_PIPEFILE);        
   sinfo_blank2dot(key_paf,key_dpaf);
-  if (sinfo_propertylist_has(plist, key_name)) {
+  if (cpl_propertylist_has(plist, key_name)) {
     fprintf(paf,"%-21s \"%s\" ;# %s\" \n",key_dpaf,
 	    cpl_propertylist_get_string(plist,key_name),KEY_HELP_PIPEFILE);
   }
@@ -326,7 +263,7 @@ static int sinfo_save_paf(char* name_p,
   strcpy(key_name,KEY_NAME_PRO_TYPE);
   strcpy(key_paf,PAF_NAME_PRO_TYPE);    
   sinfo_blank2dot(key_paf,key_dpaf);
-  if (sinfo_propertylist_has(plist, key_name)) {
+  if (cpl_propertylist_has(plist, key_name)) {
     fprintf(paf,"%-21s \"%s\" ;# %s\" \n", key_dpaf,
 	    cpl_propertylist_get_string(plist,key_name),KEY_HELP_PRO_TYPE);
   }
@@ -334,7 +271,7 @@ static int sinfo_save_paf(char* name_p,
   strcpy(key_name,KEY_NAME_PRO_DATANCOM); 
   strcpy(key_paf,PAF_NAME_PRO_DATANCOM); 
   sinfo_blank2dot(key_paf,key_dpaf);
-  if (sinfo_propertylist_has(plist,key_name)) {
+  if (cpl_propertylist_has(plist,key_name)) {
     fprintf(paf,"%-21s %d ;# %s\" \n",key_dpaf,
 	    cpl_propertylist_get_int(plist,key_name),KEY_HELP_PRO_DATANCOM);
   }
@@ -342,7 +279,7 @@ static int sinfo_save_paf(char* name_p,
   strcpy(key_name,KEY_NAME_NCORRS_NAME);
   strcpy(key_paf,PAF_NAME_NCORRS_NAME);
   sinfo_blank2dot(key_paf,key_dpaf);
-  if (sinfo_propertylist_has(plist, key_name)) {
+  if (cpl_propertylist_has(plist, key_name)) {
     fprintf(paf,"%-21s \"%s\" ;# %s \n", key_dpaf,
 	    cpl_propertylist_get_string(plist,key_name),KEY_HELP_NCORRS_NAME);
   }
@@ -350,7 +287,7 @@ static int sinfo_save_paf(char* name_p,
   strcpy(key_name,KEY_NAME_DET_NDSAMPLES);
   strcpy(key_paf,PAF_NAME_DET_NDSAMPLES);
   sinfo_blank2dot(key_paf,key_dpaf);        
-  if (sinfo_propertylist_has(plist, key_name)) {
+  if (cpl_propertylist_has(plist, key_name)) {
     fprintf(paf,"%-21s %d ;# %s \n",key_dpaf, 
 	    cpl_propertylist_get_int(plist,key_name),KEY_HELP_DET_NDSAMPLES);
   }
@@ -358,7 +295,7 @@ static int sinfo_save_paf(char* name_p,
   strcpy(key_name,KEY_NAME_FILT_NAME);      
   strcpy(key_paf,PAF_NAME_FILT_NAME);      
   sinfo_blank2dot(key_paf,key_dpaf);        
-  if (sinfo_propertylist_has(plist, key_name)) {
+  if (cpl_propertylist_has(plist, key_name)) {
     fprintf(paf,"%-21s \"%s\" ;# %s \n", key_dpaf,
 	    cpl_propertylist_get_string(plist,key_name),KEY_HELP_FILT_NAME);
   }
@@ -366,7 +303,7 @@ static int sinfo_save_paf(char* name_p,
   strcpy(key_name,KEY_NAME_FILT_ID);        
   strcpy(key_paf,PAF_NAME_FILT_ID);        
   sinfo_blank2dot(key_paf,key_dpaf);        
-  if (sinfo_propertylist_has(plist, key_name)) {
+  if (cpl_propertylist_has(plist, key_name)) {
     fprintf(paf,"%-21s \"%s\" ;# %s \n",key_dpaf, 
 	    cpl_propertylist_get_string(plist,key_name),KEY_HELP_FILT_ID);
   }
@@ -374,7 +311,7 @@ static int sinfo_save_paf(char* name_p,
   strcpy(key_name,KEY_NAME_PREOPTICS);        
   strcpy(key_paf,PAF_NAME_PREOPTICS);        
   sinfo_blank2dot(key_paf,key_dpaf);        
-  if (sinfo_propertylist_has(plist, key_name)) {
+  if (cpl_propertylist_has(plist, key_name)) {
     fprintf(paf,"%-21s \"%s\" ;# %s \n",key_dpaf, 
 	    cpl_propertylist_get_string(plist,key_name),KEY_HELP_PREOPTICS);
   }
@@ -382,7 +319,7 @@ static int sinfo_save_paf(char* name_p,
   strcpy(key_name,KEY_NAME_GRAT_NAME);        
   strcpy(key_paf,PAF_NAME_GRAT_NAME);        
   sinfo_blank2dot(key_paf,key_dpaf);        
-  if (sinfo_propertylist_has(plist, key_name)) {
+  if (cpl_propertylist_has(plist, key_name)) {
     fprintf(paf, "%-21s \"%s\" ;# %s \n",key_dpaf, 
 	    cpl_propertylist_get_string(plist,key_name),KEY_HELP_GRAT_NAME);
   }
@@ -390,7 +327,7 @@ static int sinfo_save_paf(char* name_p,
   strcpy(key_name,KEY_NAME_GRAT_WLEN);        
   strcpy(key_paf,PAF_NAME_GRAT_WLEN);        
   sinfo_blank2dot(key_paf,key_dpaf);        
-  if (sinfo_propertylist_has(plist, key_name)) {
+  if (cpl_propertylist_has(plist, key_name)) {
     fprintf(paf, "%-21s %f ;# %s \n", key_dpaf,
 	    cpl_propertylist_get_double(plist,key_name),KEY_HELP_GRAT_WLEN);
   }
@@ -398,7 +335,7 @@ static int sinfo_save_paf(char* name_p,
   strcpy(key_name,KEY_NAME_PRO_RECID);  
   strcpy(key_paf,PAF_NAME_PRO_RECID);  
   sinfo_blank2dot(key_paf,key_dpaf);        
-  if (sinfo_propertylist_has(plist, key_name)) {
+  if (cpl_propertylist_has(plist, key_name)) {
     fprintf(paf,"%-21s \"%s\" ;# %s \n", key_dpaf,
 	    cpl_propertylist_get_string(plist,key_name),KEY_HELP_PRO_RECID);
   }
@@ -408,12 +345,12 @@ static int sinfo_save_paf(char* name_p,
   strcpy(key_name,KEY_NAME_PRO_DRSID); 
   strcpy(key_paf,PAF_NAME_PRO_DRSID); 
   sinfo_blank2dot(key_paf,key_dpaf);        
-  if (sinfo_propertylist_has(plist, key_name)) {
+  if (cpl_propertylist_has(plist, key_name)) {
     fprintf(paf,"%-21s \"%s\" ;# %s \n",key_dpaf, 
 	    cpl_propertylist_get_string(plist,key_name),KEY_HELP_PRO_DRSID);
   }
 
-  if (sinfo_propertylist_has(plist,KEY_NAME_DATE_OBS)) {
+  if (cpl_propertylist_has(plist,KEY_NAME_DATE_OBS)) {
     sval = sinfo_pfits_get_date_obs(plist);
     strcpy(key_paf,KEY_NAME_DATE_OBS); 
     sinfo_blank2dot(key_paf,key_dpaf);        
@@ -422,7 +359,7 @@ static int sinfo_save_paf(char* name_p,
   }
 
 
-  if (sinfo_propertylist_has(plist,KEY_NAME_TEL_AIRM_START)) {
+  if (cpl_propertylist_has(plist,KEY_NAME_TEL_AIRM_START)) {
     dval = sinfo_pfits_get_airmass_start(plist);
     strcpy(key_paf,PAF_NAME_TEL_AIRM_START); 
     sinfo_blank2dot(key_paf,key_dpaf);        
@@ -430,13 +367,13 @@ static int sinfo_save_paf(char* name_p,
 	    dval,KEY_HELP_TEL_AIRM_START) ;
   }
 
-  if (sinfo_propertylist_has(plist,KEY_NAME_ARCFILE)) {
+  if (cpl_propertylist_has(plist,KEY_NAME_ARCFILE)) {
     sval = sinfo_pfits_get_arcfile(plist);
     strcpy(key_paf,KEY_NAME_ARCFILE);
     sinfo_blank2dot(key_paf,key_dpaf);      
     fprintf(paf, "%-21s \"%s\" ;# %s \n", key_dpaf,sval,KEY_HELP_ARCFILE) ;
 
-  } else if (sinfo_propertylist_has(plist,KEY_NAME_PRO_REC1_RAW1_NAME)) {
+  } else if (cpl_propertylist_has(plist,KEY_NAME_PRO_REC1_RAW1_NAME)) {
     sval = sinfo_pfits_get_rec1raw1name(plist);
     strcpy(key_paf,KEY_NAME_ARCFILE);
     sinfo_blank2dot(key_paf,key_dpaf);       
@@ -445,7 +382,7 @@ static int sinfo_save_paf(char* name_p,
     sinfo_msg_error("%s is missing QC LOG will fail!",KEY_NAME_ARCFILE);
   }
 
-  if (sinfo_propertylist_has(plist,KEY_NAME_TPL_ID)) {
+  if (cpl_propertylist_has(plist,KEY_NAME_TPL_ID)) {
     sval = sinfo_pfits_get_templateid(plist);
     strcpy(key_paf,PAF_NAME_TPL_ID);
     sinfo_blank2dot(key_paf,key_dpaf);       
@@ -454,7 +391,7 @@ static int sinfo_save_paf(char* name_p,
 
   }
 
-  if (sinfo_propertylist_has(plist,KEY_NAME_DET_DIT)) { 
+  if (cpl_propertylist_has(plist,KEY_NAME_DET_DIT)) { 
     strcpy(key_paf,PAF_NAME_DET_DIT); 
     sinfo_blank2dot(key_paf,key_dpaf);        
     fprintf(paf,"%-21s %f ; # %s\n", key_dpaf,
@@ -462,14 +399,14 @@ static int sinfo_save_paf(char* name_p,
   }
 
 
-  if (sinfo_propertylist_has(plist,KEY_NAME_DET_NDIT)) {
+  if (cpl_propertylist_has(plist,KEY_NAME_DET_NDIT)) {
     strcpy(key_paf,PAF_NAME_DET_NDIT); 
     sinfo_blank2dot(key_paf,key_dpaf); 
     fprintf(paf,"%-21s %d ; # %s\n", key_dpaf,
 	    sinfo_pfits_get_ndit(plist),KEY_HELP_DET_NDIT) ;
   }
 
-  if (sinfo_propertylist_has(plist,KEY_NAME_NCORRS_NAME)) {
+  if (cpl_propertylist_has(plist,KEY_NAME_NCORRS_NAME)) {
     sval = sinfo_pfits_get_ncorrs_name(plist);
     strcpy(key_paf,PAF_NAME_NCORRS_NAME); 
     sinfo_blank2dot(key_paf,key_dpaf);        
@@ -478,7 +415,7 @@ static int sinfo_save_paf(char* name_p,
 	    sval, KEY_HELP_NCORRS_NAME) ;
   }
 
-  if (sinfo_propertylist_has(plist,KEY_NAME_DPR_TYPE)) {
+  if (cpl_propertylist_has(plist,KEY_NAME_DPR_TYPE)) {
     sval = sinfo_pfits_get_dpr_type(plist);
     strcpy(key_paf,PAF_NAME_DPR_TYPE); 
     sinfo_blank2dot(key_paf,key_dpaf);        
@@ -486,7 +423,7 @@ static int sinfo_save_paf(char* name_p,
 	    sval, KEY_HELP_DPR_TYPE) ;
   }
 
-  if (sinfo_propertylist_has(plist,KEY_NAME_DPR_TECH)) {
+  if (cpl_propertylist_has(plist,KEY_NAME_DPR_TECH)) {
     sval = sinfo_pfits_get_dpr_tech(plist);
     strcpy(key_paf,PAF_NAME_DPR_TECH); 
     sinfo_blank2dot(key_paf,key_dpaf);   
@@ -495,7 +432,7 @@ static int sinfo_save_paf(char* name_p,
   }
 
 
-  if (sinfo_propertylist_has(plist,KEY_NAME_DPR_CATG)) {
+  if (cpl_propertylist_has(plist,KEY_NAME_DPR_CATG)) {
     sval = sinfo_pfits_get_dpr_catg(plist);
     strcpy(key_paf,PAF_NAME_DPR_CATG); 
     sinfo_blank2dot(key_paf,key_dpaf); 
@@ -508,7 +445,7 @@ static int sinfo_save_paf(char* name_p,
   fprintf(paf, "%-21s \"%s\" ; # %s\n", key_dpaf,
 	  pro_catg, KEY_HELP_PRO_CATG) ;
 
-  if (sinfo_propertylist_has(plist,KEY_NAME_INS_SETUP)) {
+  if (cpl_propertylist_has(plist,KEY_NAME_INS_SETUP)) {
     sval = sinfo_pfits_get_ins_setup(plist);
     strcpy(key_paf,PAF_NAME_INS_SETUP); 
     sinfo_blank2dot(key_paf,key_dpaf); 
@@ -588,11 +525,13 @@ int sinfo_pro_save_ima(
     char      *         name_p ;
 
     cpl_propertylist *   plist =NULL;
-    cpl_frame       *   first_frame=NULL;
+    //cpl_frame       *   first_frame=NULL;
     char            *   ref_file=NULL;
 
     /* Get the reference file  */
-    first_frame = cpl_frameset_get_first(ref) ;
+    cpl_frameset_iterator* it = cpl_frameset_iterator_new(ref);
+    cpl_frame *first_frame = cpl_frameset_iterator_get(it);
+
     ref_file = (char*) cpl_strdup(cpl_frame_get_filename(first_frame)) ;
 
     name_o = cpl_malloc(FILE_NAME_SZ * sizeof(char));
@@ -605,6 +544,7 @@ int sinfo_pro_save_ima(
         sinfo_msg_error( "getting header from reference ima frame %s",ref_file);
         cpl_propertylist_delete(plist) ;
         cpl_free(ref_file);
+        cpl_frameset_iterator_delete(it);
         return -1 ;
     }
 
@@ -630,6 +570,7 @@ int sinfo_pro_save_ima(
         cpl_free(ref_file);
         cpl_free(name_o);
         cpl_free(name_p);
+        cpl_frameset_iterator_delete(it);
         return -1 ;
     }
 
@@ -644,6 +585,7 @@ int sinfo_pro_save_ima(
     cpl_free(name_o);
     cpl_free(name_p);
     cpl_free(ref_file);
+    cpl_frameset_iterator_delete(it);
 
     return 0 ;
 }
@@ -680,10 +622,11 @@ int sinfo_pro_save_tbl(
     char *    name_o =NULL;
     char *    name_p =NULL;
     cpl_propertylist *   plist=NULL ;
-    cpl_frame* first_frame=NULL;
     char* ref_file=NULL;
     /* Get the reference file  */
-    first_frame = cpl_frameset_get_first(ref) ;
+
+    cpl_frameset_iterator* it = cpl_frameset_iterator_new(ref);
+    cpl_frame *first_frame = cpl_frameset_iterator_get(it);
     ref_file = cpl_strdup(cpl_frame_get_filename(first_frame)) ;
 
     name_o = cpl_malloc(FILE_NAME_SZ * sizeof(char));
@@ -699,6 +642,7 @@ int sinfo_pro_save_tbl(
         cpl_free(ref_file);
         cpl_free(name_o);
         cpl_free(name_p);
+        cpl_frameset_iterator_delete(it);
         return -1 ;
     }
     sinfo_clean_header(&plist);
@@ -717,6 +661,7 @@ int sinfo_pro_save_tbl(
         cpl_free(ref_file);
         cpl_free(name_o);
         cpl_free(name_p);
+        cpl_frameset_iterator_delete(it);
         return -1 ;
     }
 
@@ -731,6 +676,7 @@ int sinfo_pro_save_tbl(
     cpl_free(name_o);
     cpl_free(name_p);
     cpl_free(ref_file);
+    cpl_frameset_iterator_delete(it);
     return 0 ;
 }
 
@@ -768,11 +714,12 @@ int sinfo_pro_save_ims(
     char *               name_p=NULL;
 
     cpl_propertylist * plist=NULL ;
-    cpl_frame* first_frame=NULL;
     char* ref_file=NULL;
 
     /* Get the reference file  */
-    first_frame = cpl_frameset_get_first(ref) ;
+    cpl_frameset_iterator* it = cpl_frameset_iterator_new(ref);
+    cpl_frame *first_frame = cpl_frameset_iterator_get(it);
+
     ref_file = cpl_strdup(cpl_frame_get_filename(first_frame)) ;
 
     name_o = cpl_malloc(FILE_NAME_SZ * sizeof(char));
@@ -787,6 +734,7 @@ int sinfo_pro_save_ims(
         cpl_free(ref_file);
         cpl_free(name_o);
         cpl_free(name_p);
+        cpl_frameset_iterator_delete(it);
         return -1 ;
     }
     sinfo_clean_header(&plist);
@@ -813,6 +761,7 @@ int sinfo_pro_save_ims(
         cpl_free(ref_file);
         cpl_free(name_o);
         cpl_free(name_p);
+        cpl_frameset_iterator_delete(it);
         return -1 ;
     }
 
@@ -826,6 +775,7 @@ int sinfo_pro_save_ims(
     cpl_free(name_o);
     cpl_free(name_p);
     cpl_free(ref_file);
+    cpl_frameset_iterator_delete(it);
     return 0 ;
 }
 
@@ -879,10 +829,9 @@ sinfo_log_pro(char* name_o,
 static void
 sinfo_check_name(const char* in, char** ou, int type, char** paf) {
 
-    char* tmp=NULL;
     char  name_b[512] ;
     if (strstr(in, "." ) != NULL ) {
-        tmp = sinfo_new_get_rootname(in);
+        char* tmp = sinfo_new_get_rootname(in);
         strcpy(name_b,tmp);
     } else {
         snprintf(name_b, MAX_NAME_SIZE-1,"%s", in) ;
@@ -956,7 +905,7 @@ sinfo_pfits_put_qc(
         strcpy(key_help,cpl_table_get_string(qclog,"key_help",i));
 
         /* sinfo_msg("name=%s type=%s value=%s\n",key_name,key_type,key_value); */
-        if(!sinfo_propertylist_has(plist,key_name)) {
+        if(!cpl_propertylist_has(plist,key_name)) {
             if(strcmp(key_type,"CPL_TYPE_STRING") == 0) {
                 cpl_propertylist_append_string(plist, key_name,key_value) ;
                 cpl_propertylist_set_comment(plist, key_name,key_help) ;
