@@ -35,7 +35,7 @@
 /*-----------------------------------------------------------------------------
                                 Includes
 -----------------------------------------------------------------------------*/
-//Used only for sinfo_propertylist_has
+//Used only for cpl_propertylist_has
 #include "sinfo_dfs.h"
 
 #include <stdio.h>
@@ -83,8 +83,8 @@ sinfo_new_stack_frames(cpl_parameterlist* cfg,
     sinfo_msg("------------------------------") ;
     sinfo_msg("PREPARE STACKED SET %d",id) ;
     sinfo_msg("------------------------------") ;
-    ck0(ind=sinfo_new_prepare_stacked_frames(plugin_id,cfg, set, NULL,procatg,
-                    id,fk)," no: %d", ind) ;
+    ck0( ( ind = sinfo_new_prepare_stacked_frames(plugin_id,cfg, set, NULL,procatg,
+                    id,fk) )," no: %d", ind) ;
     sinfo_msg("------------------------------") ;
     sinfo_msg("PREPARED STACKED SET %d",id) ;
     sinfo_msg("------------------------------") ;
@@ -116,7 +116,7 @@ sinfo_new_get_dummy_sky(cpl_frameset* obj_set)
     check(plist = cpl_propertylist_load(filename, 0),
           "getting header from reference ima frame %s",filename);
 
-    if (sinfo_propertylist_has(plist, KEY_NAME_DPR_TYPE)) {
+    if (cpl_propertylist_has(plist, KEY_NAME_DPR_TYPE)) {
         cpl_propertylist_set_string(plist, KEY_NAME_DPR_TYPE, "SKY");
     } else {
         cpl_propertylist_append_string(plist, KEY_NAME_DPR_TYPE,"SKY") ;
@@ -273,7 +273,7 @@ sinfo_new_get_dummy_obj_sky_stacked(cpl_frameset* obj_set,cpl_frameset** set,
         cknull(plist = cpl_propertylist_load(sky_name, 0),
                "getting header from reference ima frame %s",sky_name);
 
-        if (sinfo_propertylist_has(plist, KEY_NAME_DPR_TYPE)) {
+        if (cpl_propertylist_has(plist, KEY_NAME_DPR_TYPE)) {
             cpl_propertylist_set_string(plist, KEY_NAME_DPR_TYPE, "SKY");
         } else {
             cpl_propertylist_append_string(plist, KEY_NAME_DPR_TYPE,"SKY") ;
@@ -471,7 +471,7 @@ sinfo_get_dummy_obj_sky_stacked_and_cubes(cpl_frameset* obj_set,
         cknull(plist = cpl_propertylist_load(sky_name, 0),
                "getting header from reference ima frame %s",sky_name);
 
-        if (sinfo_propertylist_has(plist, KEY_NAME_DPR_TYPE)) {
+        if (cpl_propertylist_has(plist, KEY_NAME_DPR_TYPE)) {
             cpl_propertylist_set_string(plist, KEY_NAME_DPR_TYPE, "SKY");
         } else {
             cpl_propertylist_append_string(plist, KEY_NAME_DPR_TYPE,"SKY") ;
@@ -522,7 +522,7 @@ sinfo_get_dummy_obj_sky_stacked_and_cubes(cpl_frameset* obj_set,
         sinfo_msg("--------------------------------------");
 
         /* cube generation */
-        ck0(ind=sinfo_new_cubes_build(plugin_id,config,wrk_set,pro_ctg,i),
+        ck0( (ind = sinfo_new_cubes_build(plugin_id,config,wrk_set,pro_ctg,i) ) ,
             "GENERATING CUBE no. %d\n", ind) ;
         sinfo_msg("--------------------------------------");
         sinfo_msg("BUILT CUBE %d",i);
@@ -1017,8 +1017,8 @@ int sinfo_cub_stk_frames(cpl_parameterlist* config,
                 "Cannot stack frames");
 
             /* cube generation */
-            ck0(ind=sinfo_new_cubes_build(recipe_id,config,wrk_set,
-                            *pro_ctg_cube,i),
+            ck0( ( ind=sinfo_new_cubes_build(recipe_id,config,wrk_set,
+                            *pro_ctg_cube,i) ) ,
                 "GENERATING CUBE no. %d\n", ind) ;
 
             check_nomsg(sinfo_extract_frames_group_type(wrk_set,
@@ -1111,8 +1111,8 @@ int sinfo_cub_stk_frames(cpl_parameterlist* config,
 
 
                 /* cube generation */
-                ck0(ind=sinfo_new_cubes_build(recipe_id,config,wrk_set,
-                                *pro_ctg_cube,i),
+                ck0( ( ind = sinfo_new_cubes_build(recipe_id,config,wrk_set,
+                                *pro_ctg_cube,i) ),
                     "Error GENERATING CUBE no. %d\n", ind) ;
 
 
@@ -1197,8 +1197,8 @@ int sinfo_cub_stk_frames(cpl_parameterlist* config,
                 sinfo_msg("------------------------------") ;
                 sinfo_msg("BUILDING CUBE %d",i);
                 sinfo_msg("------------------------------") ;
-                ck0(ind=sinfo_new_cubes_build(recipe_id,config,wrk_set,
-                                *pro_ctg_cube,i),
+                ck0( ( ind=sinfo_new_cubes_build(recipe_id,config,wrk_set,
+                                *pro_ctg_cube,i) ),
                     "Error GENERATING CUBE no. %d\n", ind) ;
 
                 sinfo_msg("------------------------------") ;
