@@ -519,7 +519,6 @@ void sinfo_new_convert_ZEROs_to_0_for_cubes(cpl_imagelist * cube)
 {
     int i ;
     int inp=0;
-    cpl_image* i_img=NULL;  
 
     if ( cube == NULL )
     {
@@ -530,7 +529,7 @@ void sinfo_new_convert_ZEROs_to_0_for_cubes(cpl_imagelist * cube)
 
     for ( i = 0 ; i < inp ; i++ )
     {
-      i_img=cpl_imagelist_get(cube,i);
+      cpl_image* i_img=cpl_imagelist_get(cube,i);
       sinfo_new_convert_ZEROs_to_0_for_images(i_img) ;
       cpl_imagelist_set(cube,i_img,i);
     }
@@ -551,7 +550,6 @@ sinfo_new_convert_ZEROs_to_0_for_cubes_range(cpl_imagelist * cube,
                                              const int z_min,const int z_max)
 {
     int i ;
-    cpl_image* i_img=NULL;  
 
     if ( cube == NULL )
     {
@@ -560,7 +558,7 @@ sinfo_new_convert_ZEROs_to_0_for_cubes_range(cpl_imagelist * cube,
     }
     for ( i = z_min ; i < z_max ; i++ )
     {
-      i_img=cpl_imagelist_get(cube,i);
+      cpl_image* i_img=cpl_imagelist_get(cube,i);
       sinfo_new_convert_ZEROs_to_0_for_images(i_img) ;
       cpl_imagelist_set(cube,i_img,i);
     }
@@ -607,7 +605,6 @@ void sinfo_new_convert_0_to_ZERO_for_cubes(cpl_imagelist * cube)
 {
     int i ;
     int inp=0;
-    cpl_image* i_img=NULL;
 
     if ( cube == NULL )
     {
@@ -617,7 +614,7 @@ void sinfo_new_convert_0_to_ZERO_for_cubes(cpl_imagelist * cube)
     inp=cpl_imagelist_get_size(cube);
     for ( i = 0 ; i < inp ; i++ )
     {
-      i_img=cpl_imagelist_get(cube,i);
+      cpl_image* i_img=cpl_imagelist_get(cube,i);
       sinfo_new_convert_0_to_ZEROs_for_images(i_img) ;
       cpl_imagelist_set(cube,i_img,i);
     }
@@ -639,7 +636,6 @@ sinfo_new_convert_0_to_ZERO_for_cubes_range(cpl_imagelist * cube,
 {
     int i ;
     //int inp=0;
-    cpl_image* i_img=NULL;
 
     if ( cube == NULL )
     {
@@ -649,7 +645,7 @@ sinfo_new_convert_0_to_ZERO_for_cubes_range(cpl_imagelist * cube,
     //inp=cpl_imagelist_get_size(cube);
     for ( i = z_min ; i < z_max ; i++ )
     {
-      i_img=cpl_imagelist_get(cube,i);
+      cpl_image* i_img=cpl_imagelist_get(cube,i);
       sinfo_new_convert_0_to_ZEROs_for_images(i_img) ;
       cpl_imagelist_set(cube,i_img,i);
     }
@@ -752,7 +748,6 @@ double * sinfo_new_xcorrel(
     int      nsteps ;
     int      i ;
     int      step ;
-    int      nval ;
     /*double   r;*/
 
 
@@ -781,7 +776,7 @@ double * sinfo_new_xcorrel(
     xcorr = cpl_malloc(nsteps * sizeof(double));
     for (step=STEP_MIN ; step<STEP_MAX ; step++) {
         xcorr[step-STEP_MIN] = 0.00 ;
-        nval = 0 ;
+        int nval = 0 ;
         for (i=0 ; i<width_t ; i++) {
             if ((i+step >= 0) &&
                 (i+step < width_i)) {
@@ -978,12 +973,10 @@ static int new_get_vec ( float * xdat,
                     float * epar,
                     int   * npar )
 {
-    double dj ;
     double dy ;
     double mii ;
     double mji ;
     double mjj ;
-    double wn ;
     int i, j, n, r ;
 
     /* loop to modify and scale the sinfo_matrix */
@@ -1016,7 +1009,7 @@ static int new_get_vec ( float * xdat,
     /* loop to calculate correction sinfo_vector */
     for ( j = 0 ; j < nfree ; j++ )
     {
-        dj = 0.0 ;
+        double dj = 0.0 ;
         mjj = matrix1[j][j] ;
         if ( mjj <= 0.0)               /* not allowed */
         {
@@ -1040,7 +1033,7 @@ static int new_get_vec ( float * xdat,
     /* loop through the data points */
     for ( n = 0 ; n < (*ndat) ; n++ )
     {
-        wn = wdat[n] ;               /* get weight */
+        double wn = wdat[n] ;               /* get weight */
         if ( wn > 0.0 )              /* legal weight */
         {
             dy = ydat[n] - new_gaussian( &xdat[(*xdim) * n], epar/*, npar*/ ) ;
@@ -1075,15 +1068,11 @@ static void new_get_mat ( float * xdat,
                      float * epar/*,
                      int   * npar */)
 {
-    double wd ;
-    double wn ;
-    double yd ;
-    int i, j, n ;
 
-    for ( j = 0 ; j < nfree ; j++ )
+    for ( int j = 0 ; j < nfree ; j++ )
     {
         vec[j] = 0.0 ; /* zero sinfo_vector */
-        for ( i = 0 ; i<= j ; i++ )   
+        for ( int i = 0 ; i<= j ; i++ )   
         /* zero sinfo_matrix only on and below diagonal */
         {
             matrix1[j][i] = 0.0 ;
@@ -1092,19 +1081,19 @@ static void new_get_mat ( float * xdat,
     sinfo_chi2 = 0.0 ;  /* reset reduced chi-squared */
     
     /* loop through data points */
-    for ( n = 0 ; n < (*ndat) ; n++ )
+    for ( int n = 0 ; n < (*ndat) ; n++ )
     {
-        wn = wdat[n] ;
+        double wn = wdat[n] ;
         if ( wn > 0.0 )  /* legal weight ? */
         {
-            yd = ydat[n] - new_gaussian( &xdat[(*xdim) * n], fpar/*, npar*/ ) ;
+            double yd = ydat[n] - new_gaussian( &xdat[(*xdim) * n], fpar/*, npar*/ ) ;
             new_gaussian_deriv( &xdat[(*xdim) * n], fpar, epar/*, npar*/ ) ;
             sinfo_chi2 += yd * yd * wn ; /* add to chi-squared */
-            for ( j = 0 ; j < nfree ; j++ )
+            for ( int j = 0 ; j < nfree ; j++ )
             {
-                wd = epar[parptr[j]] * wn ;  /* weighted derivative */
+                double wd = epar[parptr[j]] * wn ;  /* weighted derivative */
                 vec[j] += yd * wd ;       /* fill sinfo_vector */
-                for ( i = 0 ; i <= j ; i++ ) /* fill sinfo_matrix */
+                for ( int i = 0 ; i <= j ; i++ ) /* fill sinfo_matrix */
                 {
                     matrix1[j][i] += epar[parptr[i]] * wd ;
                 }
@@ -1131,9 +1120,8 @@ static int new_inv_mat (void)
     double even ;
     double hv[MAXPAR] ;
     double mjk ;
-    double rowmax ;
     int evin ;
-    int i, j, k, row ;
+    int i, j, k ;
     int per[MAXPAR] ;
    
     /* set permutation array */
@@ -1145,8 +1133,8 @@ static int new_inv_mat (void)
     for ( j = 0 ; j < nfree ; j++ ) /* in j-th column */
     {
         /* determine largest element of a row */                               
-        rowmax = fabs ( matrix2[j][j] ) ;
-        row = j ;                         
+        double rowmax = fabs ( matrix2[j][j] ) ;
+        int row = j ;                         
 
         for ( i = j + 1 ; i < nfree ; i++ )
         {
@@ -1351,7 +1339,7 @@ sinfo_my_fit(float x[], float y[], int ndata, float sig[], int mwt, float *a,
            float *b, float *siga, float *sigb, float *chi2, float *q)
 {
     int i ;
-    float wt, t, sxoss, sx=0., sy=0., st2=0., ss, sigdat ;
+    float t, sxoss, sx=0., sy=0., st2=0., ss ;
 
     *b = 0. ;             /*accumulate sums ...*/
     if ( mwt )
@@ -1359,7 +1347,7 @@ sinfo_my_fit(float x[], float y[], int ndata, float sig[], int mwt, float *a,
         ss = 0. ;
         for ( i = 0 ; i < ndata ; i++ )  /*... with weights*/
         {
-            wt = 1./SQR(sig[i]) ;
+            float wt = 1./SQR(sig[i]) ;
             ss += wt ;
             sx += x[i]*wt ;
             sy += y[i]*wt ;
@@ -1412,7 +1400,7 @@ sinfo_my_fit(float x[], float y[], int ndata, float sig[], int mwt, float *a,
          * for unweighted data evaluate typical sig using chi2, and adjust
          * the standard deviation
          */
-        sigdat = sqrt ((*chi2)/(ndata - 2)) ;
+        float sigdat = sqrt ((*chi2)/(ndata - 2)) ;
         *siga *= sigdat ;
         *sigb *= sigdat ;
     }
