@@ -231,7 +231,6 @@ int sinfo_stectrum_ima2table(
   int ny=0;
   int nraw=0;
   int i=0;
-  double amp=0;
   double wav=0;
  
   double step=0;
@@ -290,7 +289,7 @@ int sinfo_stectrum_ima2table(
 
   for(i=1;i<nraw;i++) {
     wav+=step;
-    amp=(double)pidata[i];
+    double amp=(double)pidata[i];
     cpl_table_set_double(*tbl,"WAVE",i,wav);
     cpl_table_set_double(*tbl,"INT",i,amp);
   }
@@ -474,7 +473,6 @@ sinfo_new_extract_spectrum_from_resampled_flat( cpl_image * resflat,
 {
     cpl_image * retIm ;
     int col, row ;
-    int n ;
     float* array=NULL ;
     float cleanMean ;
     Vector * spectrum ;
@@ -504,7 +502,7 @@ sinfo_new_extract_spectrum_from_resampled_flat( cpl_image * resflat,
     pidata=cpl_image_get_data_float(resflat);
     for ( row = 0 ; row < ily ; row++ )
     {
-        n = 0 ;
+        int n = 0 ;
         for ( col = 0 ; col < ilx ; col++ )
         {
             if ( !isnan(pidata[col + row*ilx]) )
@@ -690,11 +688,6 @@ cpl_image * sinfo_new_optimal_extraction_from_cube( cpl_imagelist * cube,
 
     double variance ;
     double xdat[2] ;
-    float weighted_sum ;
-    float counts_tot ;
-    float counts_bkg ;
-    float bkg_tot ;
-
 
     int first_col, last_col ;
     int first_row, last_row ;
@@ -704,18 +697,15 @@ cpl_image * sinfo_new_optimal_extraction_from_cube( cpl_imagelist * cube,
     float cenpix = 0;
     float cenLambda = 0;
     float dispersion = 0;
-    float lambda=0;
     float lambda_start=0;
 
     int ilx=0;
     int ily=0;
     int inp=0;
-    float* pidata=NULL;
     float* padata=NULL;
     float* podata=NULL;
     float tmp_val=0;
     cpl_propertylist* plist=NULL;
-    cpl_image* i_img=NULL;
 
 
     /* TODO: the sky here is not really used. We remove compilation warning */
@@ -962,13 +952,13 @@ cpl_image * sinfo_new_optimal_extraction_from_cube( cpl_imagelist * cube,
     podata=cpl_image_get_data_float(retIm);
     for ( z = 0 ; z < inp ; z++ )
     {
-      i_img=cpl_imagelist_get(cube,z);
-      pidata=cpl_image_get_data_float(i_img);
-        weighted_sum = 0. ;
-        counts_tot=0.;
-        counts_bkg=0.;
+        cpl_image* i_img=cpl_imagelist_get(cube,z);
+        float* pidata=cpl_image_get_data_float(i_img);
+        float weighted_sum = 0. ;
+        float counts_tot=0.;
+        float counts_bkg=0.;
 
-        bkg_tot=0.;
+        float bkg_tot=0.;
 
         if(qc_info==1) {
            sinfo_new_fit_2d_gaussian(i_img,gfit_par,
@@ -1012,7 +1002,7 @@ cpl_image * sinfo_new_optimal_extraction_from_cube( cpl_imagelist * cube,
         }
 
         podata[z] = weighted_sum ;
-        lambda=lambda_start+z*dispersion;
+        float lambda=lambda_start+z*dispersion;
         cpl_table_set_float(*spectrum,"wavelength" ,z,lambda);
         /* cpl_table_set_float(*spectrum,"intensity" ,z,weighted_sum); */
         cpl_table_set_float(*spectrum,"counts_tot" ,z,counts_tot);
@@ -1070,20 +1060,15 @@ Vector * sinfo_new_extract_sky_from_cube( cpl_imagelist * cube,
 {
     Vector * spectrum ;
     int x, y, z ;
-    int n ;
     int n_sky ;
     int x_low , x_high ;
     int y_low , y_high ;
     int hi_x, lo_x ;
-    float * to_average ;
-    float   cleanMean ;
 
     int ilx=0;
     int ily=0;
     int inp=0;
     float* pidata=NULL;
-    cpl_image* i_img=NULL;
-
 
     ilx=cpl_image_get_size_x(cpl_imagelist_get(cube,0));
     ily=cpl_image_get_size_y(cpl_imagelist_get(cube,0));
@@ -1184,16 +1169,17 @@ Vector * sinfo_new_extract_sky_from_cube( cpl_imagelist * cube,
     /* go through the image planes */
     for ( z = 0 ; z < inp ; z++ )
     {
-      i_img=cpl_imagelist_get(cube,z);
+      cpl_image* i_img=cpl_imagelist_get(cube,z);
       pidata=cpl_image_get_data_float(i_img);
         /* allocate memory for the sky pixels in one image plane */
+        float* to_average=NULL;
         if (NULL == (to_average = (float*) cpl_calloc(n_sky, sizeof (float))))
         {
             sinfo_msg_error(" could not allocate memory!") ;
             sinfo_new_destroy_vector(spectrum) ;
             return NullVector ;
         }
-        n = 0 ;
+        int n = 0 ;
         switch(posindicator)
         {
             /* lower right sinfo_edge */
@@ -1250,6 +1236,7 @@ Vector * sinfo_new_extract_sky_from_cube( cpl_imagelist * cube,
                 break ;
             default:
                 sinfo_msg_error(" wrong position indicator index!\n") ;
+                cpl_free(to_average) ;
                 return NullVector ;
                 break ;
         }
@@ -1260,7 +1247,7 @@ Vector * sinfo_new_extract_sky_from_cube( cpl_imagelist * cube,
         }
 
         /* now take a clean mean of the sky "image" */
-        cleanMean = sinfo_new_clean_mean (to_average, n, loReject, hiReject) ;
+        float cleanMean = sinfo_new_clean_mean (to_average, n, loReject, hiReject) ;
         if (cleanMean == FLT_MAX)
         {
             sinfo_msg_error(" could not take a clean mean!\n") ;
@@ -1295,14 +1282,13 @@ Vector * sinfo_new_sum_rectangle_of_cube_spectra( cpl_imagelist * cube,
                                      int ury )
 {
     Vector          * sum ;
-    pixelvalue      *local_rectangle ;
-    int             i, j, k, l, m ;
+    int             i, j, k, l ;
     int             recsize ;
     int ilx=0;
     int ily=0;
     int inp=0;
-    float* pidata=NULL;
-    cpl_image* i_img=NULL;
+
+
 
 
     ilx=cpl_image_get_size_x(cpl_imagelist_get(cube,0));
@@ -1342,10 +1328,10 @@ Vector * sinfo_new_sum_rectangle_of_cube_spectra( cpl_imagelist * cube,
      */
     for ( i = 0 ; i < inp ; i++ )
     {
-      i_img=cpl_imagelist_get(cube,i);
-      pidata=cpl_image_get_data_float(i_img);
-        m = 0 ;
-        local_rectangle = (pixelvalue *) cpl_calloc (recsize, 
+      cpl_image* i_img=cpl_imagelist_get(cube,i);
+      float* pidata=cpl_image_get_data_float(i_img);
+        int m = 0 ;
+        pixelvalue* local_rectangle = (pixelvalue *) cpl_calloc (recsize, 
                                          sizeof (pixelvalue*));
 
         for ( j = lly ; j <= ury ; j++ )
@@ -1386,14 +1372,12 @@ Vector * sinfo_new_sum_circle_of_cube_spectra( cpl_imagelist * cube,
                                   int       radius )
 {
     Vector          * sum ;
-    pixelvalue      * circle ;
-    int             i, j, k, l, m, n ;
+    int             i, j, k, l, n ;
     int             circsize ;
     int ilx=0;
     int ily=0;
     int inp=0;
     float* pidata=NULL;
-    cpl_image* i_img=NULL;
 
 
     ilx=cpl_image_get_size_x(cpl_imagelist_get(cube,0));
@@ -1447,10 +1431,10 @@ Vector * sinfo_new_sum_circle_of_cube_spectra( cpl_imagelist * cube,
      */
     for ( i = 0 ; i < inp ; i++ )
     {
-      i_img=cpl_imagelist_get(cube,i);
+      cpl_image* i_img=cpl_imagelist_get(cube,i);
       pidata=cpl_image_get_data_float(i_img);
-        m = 0 ;
-        circle = (pixelvalue *) cpl_calloc (circsize, sizeof (pixelvalue*));
+        int m = 0 ;
+        pixelvalue* circle = (pixelvalue *) cpl_calloc (circsize, sizeof (pixelvalue*));
 
         for ( j = centery - radius ; j <= centery + radius ; j++ )
         {
@@ -1498,15 +1482,12 @@ Vector * sinfo_new_mean_rectangle_of_cube_spectra( cpl_imagelist * cube,
                                      int ury )
 {
     Vector          * mean ;
-    pixelvalue      *local_rectangle ;
-    int             i, j, k, l, m ;
-    int             recsize, nv ;
+    int             i, j, k, l ;
+    int             recsize ;
     int ilx=0;
     int ily=0;
     int inp=0;
     float* pidata=NULL;
-    cpl_image* i_img=NULL;
-
 
     ilx=cpl_image_get_size_x(cpl_imagelist_get(cube,0));
     ily=cpl_image_get_size_y(cpl_imagelist_get(cube,0));
@@ -1545,10 +1526,10 @@ Vector * sinfo_new_mean_rectangle_of_cube_spectra( cpl_imagelist * cube,
      */
     for ( i = 0 ; i < inp ; i++ )
     {
-      i_img=cpl_imagelist_get(cube,i);
+      cpl_image* i_img=cpl_imagelist_get(cube,i);
       pidata=cpl_image_get_data_float(i_img);
-        m = 0 ;
-        local_rectangle = (pixelvalue *) cpl_calloc (recsize, 
+        int m = 0 ;
+        pixelvalue* local_rectangle = (pixelvalue *) cpl_calloc (recsize, 
                            sizeof (pixelvalue*));
 
         for ( j = lly ; j <= ury ; j++ )
@@ -1559,7 +1540,7 @@ Vector * sinfo_new_mean_rectangle_of_cube_spectra( cpl_imagelist * cube,
                 m ++ ;
             }
         }
-        nv = 0 ;
+        int nv = 0 ;
         for ( l = 0 ; l < recsize ; l++ )
         {
             if ( isnan(local_rectangle[l]) )
@@ -1600,14 +1581,12 @@ sinfo_new_mean_circle_of_cube_spectra( cpl_imagelist * cube,
                                   int       radius )
 {
     Vector          * mean ;
-    pixelvalue      * circle ;
-    int             i, j, k, l, m, n ;
-    int             circsize, nv ;
+    int             i, j, k, l, n ;
+    int             circsize ;
     int ilx=0;
     int ily=0;
     int inp=0;
     float* pidata=NULL;
-    cpl_image* i_img=NULL;
 
 
     ilx=cpl_image_get_size_x(cpl_imagelist_get(cube,0));
@@ -1661,10 +1640,10 @@ sinfo_new_mean_circle_of_cube_spectra( cpl_imagelist * cube,
      */
     for ( i = 0 ; i < inp ; i++ )
     {
-      i_img=cpl_imagelist_get(cube,i);
+      cpl_image* i_img=cpl_imagelist_get(cube,i);
       pidata=cpl_image_get_data_float(i_img);
-        m = 0 ;
-        circle = (pixelvalue *) cpl_calloc (circsize, sizeof (pixelvalue*));
+        int m = 0 ;
+        pixelvalue* circle = (pixelvalue *) cpl_calloc (circsize, sizeof (pixelvalue*));
 
         for ( j = centery - radius ; j <= centery + radius ; j++ )
         {
@@ -1679,7 +1658,7 @@ sinfo_new_mean_circle_of_cube_spectra( cpl_imagelist * cube,
             }
         }
 
-        nv = 0 ;
+        int nv = 0 ;
         for ( l = 0 ; l < circsize ; l++ )
         {
             if ( isnan(circle[l]) )
@@ -1721,10 +1700,6 @@ Vector * sinfo_new_blackbody_spectrum( char * templateSpec, double temp )
     double cenLambda ;
     double firstLambda ;
     double disp ;
-    double lambda ;
-    double intens ;
-    double denom ;
-    double norm ;
     cpl_propertylist* plist=NULL;
 
     if ( NULL == templateSpec )
@@ -1785,7 +1760,7 @@ Vector * sinfo_new_blackbody_spectrum( char * templateSpec, double temp )
     firstLambda = cenLambda - cenpix * disp ;
     for ( n = 0 ; n < npix ; n++ )
     {
-        lambda = firstLambda + disp * (double)n ;
+        double lambda = firstLambda + disp * (double)n ;
         /* convert from microns to m */
 
         lambda /= 1.0e6 ;
@@ -1793,12 +1768,12 @@ Vector * sinfo_new_blackbody_spectrum( char * templateSpec, double temp )
          * by 1./(expm1(PLANCK*SPEED_OF_LIGHT/(lambda*BOLTZMANN*temp))) 
          * for better accuracy if argument of exponential is small 
          */
-        denom = 1./(expm1(PLANCK*SPEED_OF_LIGHT/(lambda*BOLTZMANN*temp))) ;
-        intens = 2.*PI_NUMB*PLANCK*SPEED_OF_LIGHT*SPEED_OF_LIGHT / 
+        double denom = 1./(expm1(PLANCK*SPEED_OF_LIGHT/(lambda*BOLTZMANN*temp))) ;
+        double intens = 2.*PI_NUMB*PLANCK*SPEED_OF_LIGHT*SPEED_OF_LIGHT / 
                  pow(lambda, 5) * denom ;
         retSpec->data[n] = intens ;   
     }
-    norm = retSpec->data[npix/2] ;
+    double norm = retSpec->data[npix/2] ;
     for ( n = 0 ; n < npix ; n++ )
     {
         retSpec->data[n] /= norm ;
@@ -1828,15 +1803,12 @@ Vector * sinfo_new_median_rectangle_of_cube_spectra( cpl_imagelist * cube,
                                              int ury )
 {
     Vector          * med ;
-    pixelvalue      *local_rectangle ;
-    int             i, j, k, m ;
+    int             i, j, k ;
     int             recsize ;
     int ilx=0;
     int ily=0;
     int inp=0;
     float* pidata=NULL;
-    cpl_image* i_img=NULL;
-
 
     ilx=cpl_image_get_size_x(cpl_imagelist_get(cube,0));
     ily=cpl_image_get_size_y(cpl_imagelist_get(cube,0));
@@ -1876,10 +1848,10 @@ Vector * sinfo_new_median_rectangle_of_cube_spectra( cpl_imagelist * cube,
     for ( i = 0 ; i < inp ; i++ )
     {
 
-      i_img=cpl_imagelist_get(cube,i);
+      cpl_image* i_img=cpl_imagelist_get(cube,i);
       pidata=cpl_image_get_data_float(i_img);
-      m = 0 ;
-      local_rectangle=(pixelvalue *)cpl_calloc(recsize, sizeof (pixelvalue*));
+      int m = 0 ;
+      pixelvalue* local_rectangle=(pixelvalue *)cpl_calloc(recsize, sizeof (pixelvalue*));
 
         for ( j = lly ; j <= ury ; j++ )
         {
@@ -1926,15 +1898,12 @@ Vector * sinfo_new_median_circle_of_cube_spectra( cpl_imagelist * cube,
                                   int       radius )
 {
     Vector          * med ;
-    pixelvalue      * circle ;
-    int             i, j, k, l, m, n ;
-    int             circsize, nv ;
+    int             i, j, k, l, n ;
+    int             circsize ;
     int ilx=0;
     int ily=0;
     int inp=0;
     float* pidata=NULL;
-    cpl_image* i_img=NULL;
-
 
     ilx=cpl_image_get_size_x(cpl_imagelist_get(cube,0));
     ily=cpl_image_get_size_y(cpl_imagelist_get(cube,0));
@@ -1987,10 +1956,10 @@ Vector * sinfo_new_median_circle_of_cube_spectra( cpl_imagelist * cube,
      */
     for ( i = 0 ; i < inp ; i++ )
     {
-      i_img=cpl_imagelist_get(cube,i);
+      cpl_image* i_img=cpl_imagelist_get(cube,i);
       pidata=cpl_image_get_data_float(i_img);
-        m = 0 ;
-        circle = (pixelvalue *) cpl_calloc (circsize, sizeof (pixelvalue*));
+        int m = 0 ;
+        pixelvalue* circle = (pixelvalue *) cpl_calloc (circsize, sizeof (pixelvalue*));
 
         for ( j = centery - radius ; j <= centery + radius ; j++ )
         {
@@ -2005,7 +1974,7 @@ Vector * sinfo_new_median_circle_of_cube_spectra( cpl_imagelist * cube,
             }
         }
 
-        nv = 0 ;
+        int nv = 0 ;
         for ( l = 0 ; l < circsize ; l++ )
         {
             if ( isnan(circle[l]) )
@@ -2051,14 +2020,12 @@ sinfo_new_cleanmean_rectangle_of_cube_spectra( cpl_imagelist * cube,
                                           float hi_reject )
 {
     Vector          * clean ;
-    pixelvalue      *local_rectangle ;
-    int             i, j, k, m ;
+    int             i, j, k ;
     int             recsize ;
     int ilx=0;
     int ily=0;
     int inp=0;
     float* pidata=NULL;
-    cpl_image* i_img=NULL;
 
 
     ilx=cpl_image_get_size_x(cpl_imagelist_get(cube,0));
@@ -2098,10 +2065,10 @@ sinfo_new_cleanmean_rectangle_of_cube_spectra( cpl_imagelist * cube,
      */
     for ( i = 0 ; i < inp ; i++ )
     {
-      i_img=cpl_imagelist_get(cube,i);
+      cpl_image* i_img=cpl_imagelist_get(cube,i);
       pidata=cpl_image_get_data_float(i_img);
-      m = 0 ;
-      local_rectangle=(pixelvalue *) cpl_calloc(recsize, sizeof (pixelvalue*));
+      int m = 0 ;
+      pixelvalue* local_rectangle=(pixelvalue *) cpl_calloc(recsize, sizeof (pixelvalue*));
 
         for ( j = lly ; j <= ury ; j++ )
         {
@@ -2152,14 +2119,12 @@ sinfo_new_cleanmean_circle_of_cube_spectra( cpl_imagelist * cube,
                                   float     hi_reject )
 {
     Vector          * clean ;
-    pixelvalue      * circle ;
-    int             i, j, k, l, m, n ;
-    int             circsize, nv ;
+    int             i, j, k, l, n ;
+    int             circsize ;
     int ilx=0;
     int ily=0;
     int inp=0;
     float* pidata=NULL;
-    cpl_image* i_img=NULL;
 
     ilx=cpl_image_get_size_x(cpl_imagelist_get(cube,0));
     ily=cpl_image_get_size_y(cpl_imagelist_get(cube,0));
@@ -2212,10 +2177,10 @@ sinfo_new_cleanmean_circle_of_cube_spectra( cpl_imagelist * cube,
      */
     for ( i = 0 ; i < inp ; i++ )
     {
-      i_img=cpl_imagelist_get(cube,i);
+      cpl_image* i_img=cpl_imagelist_get(cube,i);
       pidata=cpl_image_get_data_float(i_img);
-        m = 0 ;
-        circle = (pixelvalue *) cpl_calloc (circsize, sizeof (pixelvalue*));
+        int m = 0 ;
+        pixelvalue* circle = (pixelvalue *) cpl_calloc (circsize, sizeof (pixelvalue*));
 
         for ( j = centery - radius ; j <= centery + radius ; j++ )
         {
@@ -2230,7 +2195,7 @@ sinfo_new_cleanmean_circle_of_cube_spectra( cpl_imagelist * cube,
             }
         }
 
-        nv = 0 ;
+        int nv = 0 ;
         for ( l = 0 ; l < circsize ; l++ )
         {
             if ( isnan(circle[l]) )
@@ -2272,15 +2237,10 @@ sinfo_new_shift_array ( float * input, int n_elements,
     float  *         shifted ;
     int              samples = KERNEL_SAMPLES ;
     int           i ;
-    float            fx ;
-    float            rx ;
-    int              px ;
     int              tabx ;
     float            value ;
     /*size_t           pos ;*/
     register float * pix ;
-    int              mid;
-    float            norm ;
 
     /* error handling: test entries */
     if (input==NULL) 
@@ -2306,13 +2266,13 @@ sinfo_new_shift_array ( float * input, int n_elements,
         return shifted ;
     }
     
-    mid = (int)samples/(int)2 ;
+    int mid = (int)samples/(int)2 ;
 
     for (i=1 ; i<  n_elements-2 ; i++) 
     {
-        fx = (float)i+shift ;
-        px = sinfo_new_nint(fx) ;
-        rx = fx - (float)px ;
+        float fx = (float)i+shift ;
+        int px = sinfo_new_nint(fx) ;
+        float rx = fx - (float)px ;
         pix = input ;
 
         if ((px>=1) && (px<(n_elements-2))) 
@@ -2350,7 +2310,7 @@ sinfo_new_shift_array ( float * input, int n_elements,
                  * Also sum up interpolation kernel coefficients
                  * for further normalization
                  */
-                norm =      ker[mid+tabx] +
+                float norm =      ker[mid+tabx] +
                             ker[tabx] +
                             ker[mid-tabx] +
                             ker[samples-tabx-1] ;
@@ -2469,9 +2429,8 @@ Vector * sinfo_new_clean_mean_circle_of_cube_spectra(cpl_imagelist * cube,
                                   float     hi_reject )
 {
     Vector          * clean ;
-    pixelvalue      * circle ;
-    int             i, j, k, l, m, n ;
-    int             circsize, nv ;
+    int             i, j, k, l, n ;
+    int             circsize ;
     int lx=0;
     int ly=0;
     int lz=0;
@@ -2532,8 +2491,8 @@ Vector * sinfo_new_clean_mean_circle_of_cube_spectra(cpl_imagelist * cube,
     {
       img=cpl_imagelist_get(cube,i);
       pidata=cpl_image_get_data(img);
-      m = 0 ;
-      circle = (pixelvalue *) cpl_calloc (circsize, sizeof (pixelvalue*));
+      int m = 0 ;
+      pixelvalue* circle = (pixelvalue *) cpl_calloc (circsize, sizeof (pixelvalue*));
 
       for ( j = centery - radius ; j <= centery + radius ; j++ )
         {
@@ -2548,7 +2507,7 @@ Vector * sinfo_new_clean_mean_circle_of_cube_spectra(cpl_imagelist * cube,
             }
         }
 
-        nv = 0 ;
+        int nv = 0 ;
         for ( l = 0 ; l < circsize ; l++ )
         {
             if ( isnan(circle[l]) )
@@ -2594,8 +2553,7 @@ Vector * sinfo_new_clean_mean_rectangle_of_cube_spectra( cpl_imagelist * cube,
                                           float hi_reject )
 {
     Vector          * clean ;
-    pixelvalue      *rectangle ;
-    int             i, j, k, m ;
+    int             i, j, k;
     int             recsize ;
     int lx=0;
     int ly=0;
@@ -2641,8 +2599,8 @@ Vector * sinfo_new_clean_mean_rectangle_of_cube_spectra( cpl_imagelist * cube,
      */
     for ( i = 0 ; i < lz ; i++ )
     {
-        m = 0 ;
-        rectangle = (pixelvalue *) cpl_calloc (recsize, sizeof (pixelvalue*));
+        int m = 0 ;
+        pixelvalue* rectangle = (pixelvalue *) cpl_calloc (recsize, sizeof (pixelvalue*));
         img=cpl_imagelist_get(cube,i);
         pidata=cpl_image_get_data(img);
         for ( j = lly ; j <= ury ; j++ )
