@@ -95,7 +95,6 @@ cpl_frameset * sinfo_extract_frameset(
                 const char          *   tag)
 {
     cpl_frameset    *   out ;
-    const cpl_frame *   cur_frame ;
     cpl_frame       *   loc_frame ;
     int                 nbframes, nbext ;
     int                 i ;
@@ -116,7 +115,7 @@ cpl_frameset * sinfo_extract_frameset(
     /* Loop on the requested frames and store them in out */
     nbext = 0 ;
     for (i=0 ; i<nbframes ; i++) {
-        cur_frame = cpl_frameset_get_frame_const(in, i) ;
+        const cpl_frame* cur_frame = cpl_frameset_get_frame_const(in, i) ;
         if (!strcmp(cpl_frame_get_tag(cur_frame), tag)) {
             loc_frame = cpl_frame_duplicate(cur_frame) ;
             cpl_frameset_insert(out, loc_frame) ;
