@@ -43,7 +43,7 @@
 
  */
 /*----------------------------------------------------------------------------*/
-
+/* TODO: not used */
 cpl_image*
 sinfo_vector_to_image(const cpl_vector* vector,cpl_type type)
 {
@@ -161,7 +161,7 @@ sinfo_ima_line_cor(cpl_parameterlist * parlist, cpl_frameset* in)
     return cpl_error_get_code();
 
 }
-
+/* TODO: not used */
 int
 sinfo_table_column_dump(cpl_table* t, const char* name, cpl_type type)
 {
@@ -219,7 +219,7 @@ sinfo_table_column_dump(cpl_table* t, const char* name, cpl_type type)
 @param shift shift to be applied
 @return pointer to a new allocated shifted table
  */
-
+/* TODO: not used */
 cpl_table*
 sinfo_table_shift_column_spline3(cpl_table* t,
                                  const char* col,
@@ -336,6 +336,7 @@ sinfo_table_shift_column_spline3(cpl_table* t,
 @param r shift rest
 @return pointer to a new allocated shifted table
  */
+/* TODO: not used */
 cpl_table*
 sinfo_table_shift_column_int(const cpl_table* t,
                              const char* col,
@@ -378,7 +379,7 @@ sinfo_table_shift_column_int(const cpl_table* t,
 @param order polynomial order
 @return pointer to a new allocated shifted table
  */
-
+/* TODO: not used */
 cpl_table*
 sinfo_table_shift_column_poly(cpl_table* t,
                               const char* col,
@@ -538,7 +539,7 @@ void sinfo_new_destroy_array(float ** array)
         *array = NULL;
     }
 }
-
+/* TODO: not used */
 void sinfo_new_destroy_stringarray(char ** array, int size_x)
 {
     int i ;
@@ -552,10 +553,9 @@ void sinfo_new_destroy_stringarray(char ** array, int size_x)
 
 void sinfo_new_destroy_2Dintarray(int *** array, int size_x)
 {
-    int i ;
 
     if((*array) != NULL) {
-        for ( i = 0 ; i < size_x ; i++ ) {
+        for ( int i = 0 ; i < size_x ; i++ ) {
             if((*array)[i] != NULL) {
                 cpl_free( (*array)[i] );
                 (*array)[i]=NULL;
@@ -597,9 +597,8 @@ float * sinfo_new_floatarray( int size)
 
 void sinfo_new_destroy_2Dfloatarray(float *** array, int size_x)
 {
-    int i ;
     if((*array) != NULL) {
-        for ( i = 0 ; i < size_x ; i++ ) {
+        for ( int i = 0 ; i < size_x ; i++ ) {
             if((*array)[i] != NULL) {
                 cpl_free( (*array)[i] );
                 (*array)[i]=NULL;
@@ -612,10 +611,9 @@ void sinfo_new_destroy_2Dfloatarray(float *** array, int size_x)
 
 void sinfo_new_destroy_2Ddoublearray(double *** array, int size_x)
 {
-    int i ;
 
     if((*array) != NULL) {
-        for ( i = 0 ; i < size_x ; i++ ) {
+        for ( int i = 0 ; i < size_x ; i++ ) {
             if((*array)[i] != NULL) {
                 cpl_free( (*array)[i] );
                 (*array)[i]=NULL;
@@ -687,16 +685,17 @@ void sinfo_new_destroy_intarray(int ** array)
     cpl_free( *array ) ;
     *array=NULL;
 }
-
+/* TODO: not used */
 int sinfo_new_intarray_get_value( int * array, int i )
 {
     return array[i] ;
 }
-
+/* TODO: not used */
 float sinfo_new_Stats_get_cleanstdev(Stats * stats)
 {
     return stats -> cleanstdev ;
 }
+/* TODO: not used */
 float sinfo_new_Stats_get_cleanmean(Stats * stats)
 {
     return stats -> cleanmean ;
@@ -794,15 +793,17 @@ sinfo_new_imagelist_load_frameset(const cpl_frameset * frameset,
 {
     cpl_image  * image     = NULL;
     cpl_imagelist  * imagelist = NULL;
-    const cpl_frame  * frame     = cpl_frameset_get_first_const(frameset);
+
+    cpl_frameset_iterator* it = cpl_frameset_iterator_new(frameset);
+    const cpl_frame *frame = cpl_frameset_iterator_get_const(it);
+
     const int nz = cpl_frameset_get_size(frameset);
     int       i;
 
     /* Require imagelist to contain at least one image */
     cpl_ensure(nz > 0, CPL_ERROR_DATA_NOT_FOUND, NULL);
 
-    for (i = 0; frame != NULL;
-                    i++, frame = cpl_frameset_get_next_const(frameset)) {
+    for (i = 0; i<nz; i++) {
 
         const char * name = cpl_frame_get_filename(frame);
         if (name == NULL) break; /* Error check */
@@ -823,6 +824,8 @@ sinfo_new_imagelist_load_frameset(const cpl_frameset * frameset,
 
         if (cpl_imagelist_set(imagelist, image, i)) break;
         image = NULL; /* Image is now part of the imagelist */
+        cpl_frameset_iterator_advance(it, 1);
+        frame = cpl_frameset_iterator_get_const(it);
 
     }
 
@@ -832,6 +835,7 @@ sinfo_new_imagelist_load_frameset(const cpl_frameset * frameset,
         cpl_imagelist_delete(imagelist);
         imagelist = NULL;
     }
+    cpl_frameset_iterator_delete(it);
     return imagelist;
 
 }
@@ -853,7 +857,7 @@ char ** sinfo_new_frameset_to_filenames(cpl_frameset *set, int *nfiles)
     int nbframes=0;
     int i=0;
 
-    cpl_frame *curr_frame;
+    //cpl_frame *curr_frame;
 
     if (set == NULL) {
         return NULL;
@@ -869,12 +873,16 @@ char ** sinfo_new_frameset_to_filenames(cpl_frameset *set, int *nfiles)
      */
     filenames = cpl_malloc(nbframes * sizeof(char *));
 
-    curr_frame = cpl_frameset_get_first(set);
+    cpl_frameset_iterator* it = cpl_frameset_iterator_new(set);
+    const cpl_frame *curr_frame = cpl_frameset_iterator_get(it);
+
     for (i = 0; i < nbframes; i++) {
         filenames[i]=(char*) cpl_frame_get_filename(curr_frame);
-        curr_frame = cpl_frameset_get_next(set);
-    }
 
+        cpl_frameset_iterator_advance(it, 1);
+        curr_frame = cpl_frameset_iterator_get_const(it);
+    }
+    cpl_frameset_iterator_delete(it);
 
     /*
      * Set the number of files found
@@ -903,6 +911,7 @@ char ** sinfo_new_frameset_to_filenames(cpl_frameset *set, int *nfiles)
    Adopted from: Cristian Levin - ESO La Silla, 1-Apr-1991
  */
 /*----------------------------------------------------------------------------*/
+/* TODO: not used */
 double sinfo_spline_hermite(double xp,
                             const double *x,
                             const double *y,
@@ -1144,7 +1153,7 @@ sinfo_image_filter_linear(const cpl_image *img, const cpl_matrix * mx)
     return sinfo_image_filter_mode(img, mx, CPL_FILTER_LINEAR);
 
 }
-
+/* TODO: not used */
 cpl_image * sinfo_image_filter_linear2(const cpl_image *img,
                                        const cpl_matrix * mx)
 {
