@@ -21,7 +21,7 @@
 #endif
 #include <irplib_stdstar.h>
 
-//Used only for sinfo_propertylist_has
+//Used only for cpl_propertylist_has
 #include "sinfo_dfs.h"
 
 //Used only for sinfo_band
@@ -54,12 +54,14 @@ static void
 sinfo_set_coord1(cpl_propertylist** plist,
                  const double crpix1,
                  const double crval1,
-                 const double cdelt1);
+                 const double cdelt1,
+                 const int is_science);
 static void
 sinfo_set_coord2(cpl_propertylist** plist,
                  const double crpix2,
                  const double crval2,
-                 const double cdelt2);
+                 const double cdelt2,
+                 const int is_science);
 static void
 sinfo_set_coord3(cpl_propertylist** plist,
                  const int crpix3,
@@ -292,8 +294,7 @@ sinfo_auto_size_cube(float* offsetx,
 {
 
   int n=0;
-  float offx=0;
-  float offy=0;
+
   float min_offx=0;
   float max_offx=0;
   float min_offy=0;
@@ -301,8 +302,8 @@ sinfo_auto_size_cube(float* offsetx,
 
   sinfo_msg ("Computation of output cube size") ;
   for ( n = 0 ; n < nframes ; n++ ) {
-    offx = offsetx[n];  /* was - */
-    offy = offsety[n];  /* was - */
+    float offx = offsetx[n];  /* was - */
+    float offy = offsety[n];  /* was - */
     /* sinfo_msg("frame %d offx=%f offy=%f",n,offx,offy); */
     if(n==0) {
       min_offx=offx;
@@ -346,17 +347,15 @@ sinfo_auto_size_cube5(object_config * cfg,
                     float* max_offx, float* max_offy)
 {
 
-  char* name =NULL;
+
   int n=0;
-  float offx=0;
-  float offy=0;
 
   cpl_propertylist * plist=NULL;
   sinfo_msg ("Automatic computation of output cube size") ;
   for ( n = 0 ; n < cfg->nframes ; n++ ) {
-    name = cfg->framelist[n] ;
+    char* name = cfg->framelist[n] ;
     plist=cpl_propertylist_load(name,0);
-    offx = sinfo_pfits_get_cumoffsetx(plist);  /* was - */
+    float offx = sinfo_pfits_get_cumoffsetx(plist);  /* was - */
     if(cpl_error_get_code() != CPL_ERROR_NONE) {
       sinfo_msg_warning(" could not read fits header keyword cummoffsetx!");
       sinfo_msg_warning(" set it to  0");
@@ -365,7 +364,7 @@ sinfo_auto_size_cube5(object_config * cfg,
       /* return -1 ; */
     }
 
-    offy = sinfo_pfits_get_cumoffsety(plist); /* was - */
+    float offy = sinfo_pfits_get_cumoffsety(plist); /* was - */
     sinfo_free_propertylist(&plist);
     if(cpl_error_get_code() != CPL_ERROR_NONE) {
       sinfo_msg_warning(" could not read fits header keyword! cumoffsety") ;
@@ -427,7 +426,6 @@ sinfo_read_distances(const int nslits, const char* distlist)
   int i=0;
   int* status=NULL;
   float * distances = NULL;
-  float tmp_float=0;
   char tbl_distances_name[FILE_NAME_SZ];
   cpl_table* tbl_distances = NULL;
 
@@ -444,6 +442,7 @@ sinfo_read_distances(const int nslits, const char* distlist)
   if(cpl_error_get_code() != CPL_ERROR_NONE) {
     sinfo_msg_error("Before loading input table");
     sinfo_msg_error("%s", (char* ) cpl_error_get_message());
+    cpl_free(distances);
     return NULL;
   }
   strcpy(tbl_distances_name,distlist);
@@ -451,11 +450,12 @@ sinfo_read_distances(const int nslits, const char* distlist)
   if(cpl_error_get_code() != CPL_ERROR_NONE) {
     sinfo_msg_error("loading input table %s",tbl_distances_name);
     sinfo_msg_error("%s", (char* ) cpl_error_get_message());
+    cpl_free(distances);
     return NULL;
   }
 
   for (i =0 ; i< nslits-1; i++){
-    tmp_float=cpl_table_get_float(tbl_distances,"slitlet_distance",i,status);
+    float tmp_float=cpl_table_get_float(tbl_distances,"slitlet_distance",i,status);
     if(cpl_error_get_code() != CPL_ERROR_NONE) {
       sinfo_msg_error("reading col %s from table %s","slitlet_distance",
                        tbl_distances_name);
@@ -488,8 +488,7 @@ sinfo_read_slitlets_edges(const int nslits, const char* poslist)
   int n=0;
   int i=0;
   int* status=NULL;
-  float edge_x=0;
-  float edge_y=0;
+
   float ** slit_edges = NULL;
 
   slit_edges = sinfo_new_2Dfloatarray(nslits, 2) ;
@@ -508,8 +507,8 @@ sinfo_read_slitlets_edges(const int nslits, const char* poslist)
   }
 
   for (i =0 ; i< nslits; i++){
-    edge_x=cpl_table_get_double(tbl_slitpos,"pos1",i,status);
-    edge_y=cpl_table_get_double(tbl_slitpos,"pos2",i,status);
+    float edge_x=cpl_table_get_double(tbl_slitpos,"pos1",i,status);
+    float edge_y=cpl_table_get_double(tbl_slitpos,"pos2",i,status);
     if(cpl_error_get_code() != CPL_ERROR_NONE) {
       sinfo_msg_error("error reading tbl %s row %d",tbl_slitpos_name,i);
       sinfo_msg_error("%s", (char* ) cpl_error_get_message());
@@ -571,8 +570,7 @@ cpl_imagelist * sinfo_new_cube_getvig(
     int ily=0;
     int inp=0;
     */
-    cpl_image* i_img=NULL;
-    cpl_image* o_img=NULL;
+
 
     if (cube_in==NULL) return NULL ;
 /*
@@ -598,9 +596,9 @@ cpl_imagelist * sinfo_new_cube_getvig(
     /* Loop on all input planes */
     for (i=0 ; i<cpl_imagelist_get_size(cube_in) ; i++) {
 
-      i_img=cpl_imagelist_get(cube_in,i);
+      cpl_image* i_img=cpl_imagelist_get(cube_in,i);
         /* Extract a slit from this plane   */
-                o_img = sinfo_new_image_getvig(i_img,
+        cpl_image* o_img = sinfo_new_image_getvig(i_img,
                         loleft_x, loleft_y,
                         upright_x, upright_y) ;
         cpl_imagelist_set(cube_out,o_img,i);
@@ -637,8 +635,7 @@ sinfo_new_image_getvig(
     cpl_image    *        slit_img ;
     int                 i, j ;
     register
-    pixelvalue  *       inpt,
-                                *       outpt ;
+
     int         outlx, outly ;
     int ilx=0;
     int ily=0;
@@ -669,8 +666,8 @@ sinfo_new_image_getvig(
     podata=cpl_image_get_data_float(slit_img);
 
     for (j=0 ; j<outly ; j++) {
-        inpt = pidata+loleft_x-1 + (j+loleft_y-1)*ilx ;
-        outpt = podata + j*outlx ;
+        pixelvalue* inpt = pidata+loleft_x-1 + (j+loleft_y-1)*ilx ;
+        pixelvalue* outpt = podata + j*outlx ;
         for (i=0 ; i<outlx ; i++) {
             *outpt++ = *inpt++ ;
         }
@@ -714,6 +711,69 @@ sinfo_new_set_wcs_cube(cpl_imagelist* cub, const char* name, double clambda,
   return 0;
 
 }
+
+
+
+/**
+@brief set world coordinate system for an image
+@name sinfo_new_set_wcs_image
+@param img input image
+@param name file name
+@param crpix1    image reference pixel on x
+@param crval1    value at crpix1
+@param cdelt1    value of step along x
+@param crpix2    image reference pixel on y
+@param crval2    value at crpix2
+@param cdelt2    value of step along y
+*/
+
+int
+sinfo_set_wcs_cal_image(cpl_image* img,
+                        const char* name,
+                        double crpix1,
+                        double crval1,
+                        double cdelt1,
+                        double crpix2,
+                        double crval2,
+                        double cdelt2)
+{
+  cpl_propertylist* plist=NULL;
+
+  if ((cpl_error_code)((plist = cpl_propertylist_load(name, 0)) == NULL)) {
+    sinfo_msg_error( "getting header from frame %s",name);
+    cpl_propertylist_delete(plist) ;
+    return -1 ;
+  }
+
+  sinfo_msg("crpix1=%g crval1=%g cdelt1=%g",crpix1,crval1,cdelt1);
+  sinfo_set_coord1(&plist,crpix1,crval1,cdelt1,0);
+  sinfo_msg("crpix2=%g crval2=%g cdelt2=%g",crpix2,crval2,cdelt2);
+  sinfo_set_coord2(&plist,crpix2,crval2,cdelt2,0);
+  cpl_propertylist_erase_regexp(plist, "^CDELT*",0);
+
+  double cd1_1=0;
+  double cd1_2=0;
+  double cd2_1=0;
+  double cd2_2=0;
+  /* simple case with radangle=0 */
+  cd1_1 = +cdelt1;
+  cd1_2 = 0;
+  cd2_1 = 0;
+  cd2_2 = +cdelt2;
+  sinfo_set_cd_matrix2(&plist,cd1_1,cd1_2,cd2_1,cd2_2);
+
+  if (cpl_image_save(img, name, CPL_BPP_IEEE_FLOAT,
+                     plist,CPL_IO_DEFAULT)!=CPL_ERROR_NONE) {
+    sinfo_msg_error( "Cannot save the product %s",name);
+    cpl_propertylist_delete(plist) ;
+    return -1 ;
+  }
+  cpl_propertylist_delete(plist) ;
+  return 0;
+
+}
+
+
 /**
 @brief set world coordinate system for an image
 @name sinfo_new_set_wcs_image
@@ -801,9 +861,9 @@ sinfo_new_change_plist_cube (cpl_propertylist * plist,
             float center_y )
 {
 
-    float pixelscale ;
-    double ra ;
-    double dec ;
+
+
+
     double angle ;
     float radangle ;
     double cd1_1, cd1_2, cd2_1, cd2_2 ;
@@ -825,13 +885,15 @@ sinfo_new_change_plist_cube (cpl_propertylist * plist,
 
     strcpy(firsttext, "sinfo_rec_objnod -f \0") ;
 
-    pixelscale = sinfo_pfits_get_pixscale(plist)/2. ;
-    ra = sinfo_pfits_get_ra(plist) ;
-    dec = sinfo_pfits_get_DEC(plist) ;
+    float pixelscale = sinfo_pfits_get_pixscale(plist)/2. ;
+/*
+    double ra = sinfo_pfits_get_ra(plist) ;
+    double dec = sinfo_pfits_get_DEC(plist) ;
+*/
 
     //get better coordinate values
-    ra=sinfo_pfits_get_targ_alpha(plist);
-    dec=sinfo_pfits_get_targ_delta(plist);
+    double ra=sinfo_pfits_get_targ_alpha(plist);
+    double dec=sinfo_pfits_get_targ_delta(plist);
     //sinfo_msg("ra=%f",ra);
     //sinfo_msg("dec=%f",dec);
     ra=sinfo_hms2deg(ra);
@@ -858,8 +920,8 @@ sinfo_new_change_plist_cube (cpl_propertylist * plist,
     cd2_2 = +cdelt2*cos(radangle);
 
 
-    sinfo_set_coord1(&plist,crpix1,crval1,cdelt1);
-    sinfo_set_coord2(&plist,crpix2,crval2,cdelt2);
+    sinfo_set_coord1(&plist,crpix1,crval1,cdelt1,1);
+    sinfo_set_coord2(&plist,crpix2,crval2,cdelt2,1);
     sinfo_set_coord3(&plist,crpix3,crval3,cdelt3);
     sinfo_set_cd_matrix2(&plist,cd1_1,cd1_2,cd2_1,cd2_2);
     sinfo_set_cd_matrix3(&plist,0,0,0,0,dispersion);
@@ -876,17 +938,27 @@ sinfo_new_change_plist_cube (cpl_propertylist * plist,
 @param crpix1 value of CRPIX1 (ref pixel axis 1 coord in pix coordinates)
 @param crval1 value of CRVAL1 (ref pixel axis 1 coord in sky coordinates)
 @param cdelt1 value of CDELT1 (ref pixel axis 1 size )
+@param is_science switch to set different ctype and cunit values and comments
 @return updated propertylist
 */
 static void
 sinfo_set_coord1(cpl_propertylist** plist,
                  const double crpix1,
                  const double crval1,
-                 const double cdelt1)
+                 const double cdelt1,
+                 const int is_science)
 {
-   cpl_propertylist_erase_regexp(*plist, "^CTYPE1",0);
-    cpl_propertylist_insert_after_string(*plist,"EXPTIME","CTYPE1","RA---TAN");
-    cpl_propertylist_set_comment(*plist, "CTYPE1", "Projected Rectascension");
+
+    if(is_science) {
+       cpl_propertylist_erase_regexp(*plist, "^CTYPE1",0);
+       cpl_propertylist_insert_after_string(*plist,"EXPTIME","CTYPE1","RA---TAN");
+       cpl_propertylist_set_comment(*plist, "CTYPE1", "Projected Rectascension");
+    } else {
+        cpl_propertylist_erase_regexp(*plist, "^CTYPE1",0);
+        cpl_propertylist_insert_after_string(*plist,"EXPTIME","CTYPE1","PIPXEL");
+        cpl_propertylist_set_comment(*plist, "CTYPE1", "pixel unit");
+    }
+
     cpl_propertylist_erase_regexp(*plist, "^CRPIX1",0);
     cpl_propertylist_insert_after_double(*plist,"CTYPE1","CRPIX1", crpix1) ;
     cpl_propertylist_set_comment(*plist, "CRPIX1","Reference pixel in RA" ) ;
@@ -898,11 +970,15 @@ sinfo_set_coord1(cpl_propertylist** plist,
     cpl_propertylist_erase_regexp(*plist, "^CDELT1",0);
     cpl_propertylist_insert_after_double(*plist,"CRVAL1","CDELT1",cdelt1 ) ;
     cpl_propertylist_set_comment(*plist, "CDELT1","pixel scale" ) ;
-
-    cpl_propertylist_erase_regexp(*plist, "^CUNIT1",0);
-    cpl_propertylist_insert_after_string(*plist, "CDELT1",  "CUNIT1", "deg" ) ;
-    cpl_propertylist_set_comment(*plist, "CUNIT1","RA-UNIT" ) ;
-
+    if(is_science) {
+       cpl_propertylist_erase_regexp(*plist, "^CUNIT1",0);
+       cpl_propertylist_insert_after_string(*plist, "CDELT1",  "CUNIT1", "deg" ) ;
+       cpl_propertylist_set_comment(*plist, "CUNIT1","RA-UNIT" ) ;
+    } else {
+        cpl_propertylist_erase_regexp(*plist, "^CUNIT1",0);
+        cpl_propertylist_insert_after_string(*plist, "CDELT1",  "CUNIT1", "PIXEL" ) ;
+        cpl_propertylist_set_comment(*plist, "CUNIT1","pixel unit" ) ;
+    }
     return;
 }
 
@@ -919,12 +995,18 @@ static void
 sinfo_set_coord2(cpl_propertylist** plist,
                  const double crpix2,
                  const double crval2,
-                 const double cdelt2)
+                 const double cdelt2,
+                 const int is_science)
 {
-    cpl_propertylist_erase_regexp(*plist, "^CTYPE2",0);
-    cpl_propertylist_insert_after_string(*plist,"CUNIT1","CTYPE2","DEC--TAN");
-    cpl_propertylist_set_comment(*plist, "CTYPE2", "Projected Declination") ;
-
+    if(is_science) {
+        cpl_propertylist_erase_regexp(*plist, "^CTYPE2",0);
+        cpl_propertylist_insert_after_string(*plist,"CUNIT1","CTYPE2","DEC--TAN");
+        cpl_propertylist_set_comment(*plist, "CTYPE2", "Projected Declination") ;
+    } else {
+        cpl_propertylist_erase_regexp(*plist, "^CTYPE2",0);
+        cpl_propertylist_insert_after_string(*plist,"CUNIT1","CTYPE2","PIXEL");
+        cpl_propertylist_set_comment(*plist, "CTYPE2", "pixel unit") ;
+    }
     cpl_propertylist_erase_regexp(*plist, "^CRPIX2",0);
     cpl_propertylist_insert_after_double(*plist,"CTYPE2","CRPIX2",crpix2 ) ;
     cpl_propertylist_set_comment(*plist, "CRPIX2", "Reference pixel in DEC") ;
@@ -936,16 +1018,20 @@ sinfo_set_coord2(cpl_propertylist** plist,
     cpl_propertylist_erase_regexp(*plist,"^CDELT2",0);
     cpl_propertylist_insert_after_double(*plist,"CRVAL2","CDELT2",cdelt2 ) ;
     cpl_propertylist_set_comment(*plist,"CDELT2","pixel scale") ;
-
-    cpl_propertylist_erase_regexp(*plist,"^CUNIT2",0);
-    cpl_propertylist_insert_after_string(*plist,"CDELT2","CUNIT2", "deg" ) ;
-    cpl_propertylist_set_comment(*plist,"CUNIT2","DEC-UNIT") ;
+    if(is_science) {
+        cpl_propertylist_erase_regexp(*plist,"^CUNIT2",0);
+        cpl_propertylist_insert_after_string(*plist,"CDELT2","CUNIT2", "deg" ) ;
+        cpl_propertylist_set_comment(*plist,"CUNIT2","DEC-UNIT") ;
+    } else {
+        cpl_propertylist_erase_regexp(*plist,"^CUNIT2",0);
+        cpl_propertylist_insert_after_string(*plist,"CDELT2","CUNIT2", "PIXEL" ) ;
+        cpl_propertylist_set_comment(*plist,"CUNIT2","pixel unitT") ;
+    }
 
 
 }
 
 
-
 /**
 @brief set world coordinate system
 @param plist input propertylist
@@ -1245,9 +1331,9 @@ sinfo_new_change_plist_image (cpl_propertylist * plist,
             float center_y )
 {
 
-    float pixelscale ;
-    double ra ;
-    double dec ;
+
+
+
     double angle ;
     float radangle ;
     float cd1_1, cd1_2, cd2_1, cd2_2 ;
@@ -1269,15 +1355,17 @@ sinfo_new_change_plist_image (cpl_propertylist * plist,
 
     strcpy(firsttext, "sinfo_rec_objnod -f \0") ;
 
-    pixelscale = sinfo_pfits_get_pixscale(plist)/2. ;
-    ra = sinfo_pfits_get_ra(plist) ;
-    dec = sinfo_pfits_get_DEC(plist) ;
+    float pixelscale = sinfo_pfits_get_pixscale(plist)/2. ;
+/*
+    double ra = sinfo_pfits_get_ra(plist) ;
+    double dec = sinfo_pfits_get_DEC(plist) ;
+*/
 
 
 
     //get better coordinate values
-    ra=sinfo_pfits_get_targ_alpha(plist);
-    dec=sinfo_pfits_get_targ_delta(plist);
+    double ra=sinfo_pfits_get_targ_alpha(plist);
+    double dec=sinfo_pfits_get_targ_delta(plist);
     ra=sinfo_hms2deg(ra);
     dec=sinfo_sess2deg(dec);
 
@@ -1307,8 +1395,8 @@ sinfo_new_change_plist_image (cpl_propertylist * plist,
 
 
 
-    check_nomsg(sinfo_set_coord1(&plist,crpix1,crval1,cdelt1));
-    check_nomsg(sinfo_set_coord2(&plist,crpix2,crval2,cdelt2));
+    check_nomsg(sinfo_set_coord1(&plist,crpix1,crval1,cdelt1,1));
+    check_nomsg(sinfo_set_coord2(&plist,crpix2,crval2,cdelt2,1));
     check_nomsg(sinfo_set_cd_matrix2(&plist,cd1_1,cd1_2,cd2_1,cd2_2));
 
 
@@ -1322,7 +1410,7 @@ sinfo_new_change_plist_image (cpl_propertylist * plist,
 @param cubes input imagelist
 @param n_cubes number of cubes
 */
-
+/* TODO: not used */
 cpl_imagelist**
 sinfo_new_sinfoni_correct_median(cpl_imagelist** cubes, const int n_cubes)
 {
@@ -1370,13 +1458,9 @@ sinfo_new_sinfoni_correct_median(cpl_imagelist** cubes, const int n_cubes)
 int sinfo_new_sinfoni_correct_median_it(cpl_imagelist** inp)
 {
 
-  double local_median=0;
-  int z=0;
-  cpl_image* img=NULL;
-
-  for(z=0;z< cpl_imagelist_get_size((*inp)); z++) {
-    img=cpl_imagelist_get((*inp),z);
-    local_median=sinfo_new_my_median_image(img);
+  for(int z=0;z< cpl_imagelist_get_size((*inp)); z++) {
+    cpl_image* img=cpl_imagelist_get((*inp),z);
+    double local_median=sinfo_new_my_median_image(img);
     if(!isnan(local_median)) {
       cpl_image_subtract_scalar(img,local_median);
     }  else {
@@ -1396,7 +1480,7 @@ int sinfo_new_sinfoni_correct_median_it(cpl_imagelist** inp)
 @param nc  size of cube
 @param sky_cube output sky cube
 */
-
+/* TODO: not used */
 cpl_imagelist** sinfo_new_sinfoni_correct_sky(cpl_imagelist** cubes,
                   const int nc,
                   cpl_imagelist* sky_cube)
@@ -1426,10 +1510,9 @@ cpl_imagelist** sinfo_new_sinfoni_correct_sky(cpl_imagelist** cubes,
   int sky_lx=0;
   /* int sky_ly=0; */
 
-  float* pidata=NULL;
-  float* p_sky_data=NULL;
+
   cpl_image* i_img=NULL;
-  cpl_image* sky_img=NULL;
+
 
 
   if ( cubes == NULL ) {
@@ -1449,9 +1532,10 @@ cpl_imagelist** sinfo_new_sinfoni_correct_sky(cpl_imagelist** cubes,
   }
 
   cubes_sky = (cpl_imagelist**) cpl_calloc (nc, sizeof (cpl_imagelist*)) ;
+  float* pidata;
   for(z=0;z< inp; z++) {
-    sky_img=cpl_imagelist_get(sky_cube,z);
-    p_sky_data=cpl_image_get_data_float(sky_img);
+    cpl_image* sky_img=cpl_imagelist_get(sky_cube,z);
+    float* p_sky_data=cpl_image_get_data_float(sky_img);
     for(y=0;y< ily; y++) {
       for(x=0;x< ilx; x++) {
         /* here we start to do a k-s clipping */
@@ -1544,6 +1628,7 @@ cpl_imagelist** sinfo_new_sinfoni_correct_sky(cpl_imagelist** cubes,
 @param sig_cube sigma
 @param ovr_cube overlapping points
 */
+/* TODO: not used */
 cpl_imagelist** sinfo_new_sinfoni_correct_sky2(cpl_imagelist** cubes,
                   const int nc,
                   cpl_imagelist* sky_cube,
@@ -1581,14 +1666,6 @@ cpl_imagelist** sinfo_new_sinfoni_correct_sky2(cpl_imagelist** cubes,
   int sky_lx=0;
   int med_lx=0;
 
-
-  float* p_ovr_data=NULL;
-  float* p_msk_data=NULL;
-  float* p_avg_data=NULL;
-  float* p_sig_data=NULL;
-  float* p_sky_data=NULL;
-  float* p_med_data=NULL;
-
   float* pidata=NULL;
 
   if ( cubes == NULL ) {
@@ -1615,12 +1692,12 @@ cpl_imagelist** sinfo_new_sinfoni_correct_sky2(cpl_imagelist** cubes,
   med_lx=ilx;
 
   for(z=0;z< inp; z++) {
-    p_ovr_data=cpl_image_get_data_float(cpl_imagelist_get(ovr_cube,z));
-    p_msk_data=cpl_image_get_data_float(cpl_imagelist_get(msk_cube,z));
-    p_avg_data=cpl_image_get_data_float(cpl_imagelist_get(avg_cube,z));
-    p_sig_data=cpl_image_get_data_float(cpl_imagelist_get(sig_cube,z));
-    p_sky_data=cpl_image_get_data_float(cpl_imagelist_get(sky_cube,z));
-    p_med_data=cpl_image_get_data_float(cpl_imagelist_get(med_cube,z));
+    float* p_ovr_data=cpl_image_get_data_float(cpl_imagelist_get(ovr_cube,z));
+    float* p_msk_data=cpl_image_get_data_float(cpl_imagelist_get(msk_cube,z));
+    float* p_avg_data=cpl_image_get_data_float(cpl_imagelist_get(avg_cube,z));
+    float* p_sig_data=cpl_image_get_data_float(cpl_imagelist_get(sig_cube,z));
+    float* p_sky_data=cpl_image_get_data_float(cpl_imagelist_get(sky_cube,z));
+    float* p_med_data=cpl_image_get_data_float(cpl_imagelist_get(med_cube,z));
 
 
     for(y=0;y< ily; y++) {
@@ -1772,7 +1849,7 @@ sinfo_new_assign_offset(const int n,
   }
   sinfo_msg_debug("offx=%f offy=%f",offx,offy);
 
-  if (sinfo_propertylist_has(plist, KEY_NAME_MJD_OBS)) {
+  if (cpl_propertylist_has(plist, KEY_NAME_MJD_OBS)) {
     mjd_obs=cpl_propertylist_get_double(plist, KEY_NAME_MJD_OBS);
   } else {
     sinfo_msg_error("keyword %s does not exist",KEY_NAME_MJD_OBS);
@@ -1853,7 +1930,7 @@ sinfo_new_assign_offset2(const int n,
     return -1 ;
   }
 
-  if (sinfo_propertylist_has(plist, KEY_NAME_MJD_OBS)) {
+  if (cpl_propertylist_has(plist, KEY_NAME_MJD_OBS)) {
     mjd_obs=cpl_propertylist_get_double(plist, KEY_NAME_MJD_OBS);
   } else {
     sinfo_msg_error("keyword %s does not exist",KEY_NAME_MJD_OBS);
@@ -1906,7 +1983,7 @@ sinfo_new_assign_offset2(const int n,
 @param offsetx frames X offset array
 @param offsety frames Y offset array
 */
-
+/* TODO: not used */
 int
 sinfo_new_object_assign_offset(const char* name,
                                const int n,
@@ -1977,7 +2054,7 @@ sinfo_new_object_assign_offset(const char* name,
     */
 
 
-  if (sinfo_propertylist_has(plist, KEY_NAME_MJD_OBS)) {
+  if (cpl_propertylist_has(plist, KEY_NAME_MJD_OBS)) {
     mjd_obs=cpl_propertylist_get_double(plist, KEY_NAME_MJD_OBS);
   } else {
     sinfo_msg_error("keyword %s does not exist",KEY_NAME_MJD_OBS);
@@ -2079,6 +2156,7 @@ return outcube2;
   @return   the broadband filter id
  */
 /*----------------------------------------------------------------------------*/
+/* TODO: not used */
 sinfo_band sinfo_get_associated_filter(const char * f)
 {
     if (!strcmp(f, "J"))            return SINFO_BAND_J ;
@@ -2126,6 +2204,7 @@ sinfo_band sinfo_get_associated_filter(const char * f)
   @return   the broadband filter id
  */
 /*----------------------------------------------------------------------------*/
+/* TODO: not used */
 sinfo_band sinfo_get_bbfilter(const char * f)
 {
     if (!strcmp(f, "J"))            return SINFO_BAND_J ;
