@@ -227,6 +227,7 @@ sinfo_select_table_rows(cpl_table *t,  const char *column,
    @param    p        parameter to deallocate
  */
 /*---------------------------------------------------------------------------*/
+/* TODO: not used */
 void sinfo_free_parameter(cpl_parameter **p) 
 {if(p){cpl_parameter_delete(*p);            *p = NULL;}}
 
@@ -237,6 +238,7 @@ void sinfo_free_parameter(cpl_parameter **p)
    @param    a        parameter to deallocate
  */
 /*---------------------------------------------------------------------------*/
+/* TODO: not used */
 void sinfo_free_apertures(cpl_apertures **a) 
 {if(a){cpl_apertures_delete(*a);            *a = NULL;}}
 /*---------------------------------------------------------------------------*/
@@ -321,6 +323,7 @@ void sinfoni_free_matrix(cpl_matrix **m)
    @param    p        Parameter list to deallocate
  */
 /*---------------------------------------------------------------------------*/
+/* TODO: not used */
 void sinfo_free_parameterlist(cpl_parameterlist **p) 
 {if(p){cpl_parameterlist_delete(*p);    *p = NULL;}}
 /*----------------------------------------------------------------------------*/
@@ -398,9 +401,9 @@ void sinfo_free_array_image(cpl_image ***a) {if(*a){cpl_free(*a); *a = NULL;}}
 /*---------------------------------------------------------------------------*/
 void sinfo_free_image_array(cpl_image ***a, const int n) 
 {
-    int i=0;
+
     if((*a) != NULL) {
-        for (i=0; i < n; i++) {
+        for (int i=0; i < n; i++) {
             if((*a)[i] != NULL) {
                 sinfo_free_image(&(*a)[i]);
                 (*a)[i]=NULL;
@@ -420,9 +423,9 @@ void sinfo_free_image_array(cpl_image ***a, const int n)
 /*---------------------------------------------------------------------------*/
 void sinfo_free_float_array(float ***a, const int n) 
 {
-    int i=0;
+
     if((*a) != NULL) {
-        for (i=0; i < n; i++) {
+        for (int i=0; i < n; i++) {
             if((*a)[i] != NULL) {
                 sinfo_free_float(&(*a)[i]);
                 (*a)[i]=NULL;
@@ -465,6 +468,7 @@ sinfo_free_bivector(cpl_bivector **bv) {
    @param    s        Stats object to deallocate
  */
 /*---------------------------------------------------------------------------*/
+/* TODO: not used */
 void sinfo_free_stats(cpl_stats **s) {if(s){cpl_stats_delete(*s); *s = NULL;}}
 /*---------------------------------------------------------------------------*/
 /**
@@ -490,6 +494,7 @@ void sinfo_unwrap_matrix(cpl_matrix **m)
    @param    b        Bi-vector to deallocate
  */
 /*---------------------------------------------------------------------------*/
+/* TODO: not used */
 void sinfo_unwrap_bivector_vectors(cpl_bivector **b) 
 {if(b){cpl_bivector_unwrap_vectors(*b); *b = NULL;}}
 
