@@ -193,7 +193,7 @@ int sinfo_utl_cube_combine(
     }
  
     cnt = 0 ;
-    while ( fscanf( file_list, "%f %f",&tmpoffx, &tmpoffy) != EOF )
+    while ( fscanf( file_list, "%10f %10f",&tmpoffx, &tmpoffy) != EOF )
     {
       cnt ++ ;
     }
@@ -212,6 +212,10 @@ int sinfo_utl_cube_combine(
     files = (const char**) cpl_calloc(MAX_NAME_SIZE,sizeof(const char*));
     if ( NULL == (file_list = fopen (name_i, "r" ) ) )
     {
+        if(files != NULL) {
+          cpl_free(files);
+          files=NULL;
+        }
       sinfo_msg_error("cannot open %s\n", name_i) ;
       return -1 ;
     }
