@@ -276,12 +276,15 @@ FitParams ** sinfo_new_fit_params( int n_params )
     if ( NULL == (temp_params = cpl_calloc ( n_params , sizeof (FitParams) ) ) )
     {
         sinfo_msg_error (" could not allocate memory\n") ;
+        cpl_free(new_params);
         return NULL ;
     }
     if ( NULL == (temp_fit_mem = (float *) cpl_calloc( n_params*MAXPAR, 
                     sizeof (float) ) ) )
     {
         sinfo_msg_error (" could not allocate memory\n") ;
+        cpl_free(temp_params);
+        cpl_free(new_params);
         return NULL ;
     }
 
@@ -290,6 +293,9 @@ FitParams ** sinfo_new_fit_params( int n_params )
                     (float *) cpl_calloc( n_params*MAXPAR, sizeof (float) ) ) )
     {
         sinfo_msg_error (" could not allocate memory\n") ;
+        cpl_free(temp_params);
+        cpl_free(new_params);
+        cpl_free(temp_fit_mem);
         return NULL ;
     }
 
@@ -389,7 +395,7 @@ void sinfo_new_dump_fit_params_to_ascii ( FitParams ** params, const char * file
 @param filename
 @return params: filled FitParams object
  */
-
+/* TODO: not used */
 void 
 sinfo_new_dump_ascii_to_fit_params ( FitParams ** params, char * filename )
 {
@@ -498,11 +504,11 @@ int sinfo_new_find_lines(cpl_image * lineImage,
     float * wave_mem;
     int   * dummy_row ;
     int i, j, k, m ;
-    int position ;
+
     int gmax, gmin ;
     int col ;
     int * row_mem;
-    float sum ;
+
     float angst ;
 
     int lx=0;
@@ -624,7 +630,7 @@ int sinfo_new_find_lines(cpl_image * lineImage,
     for ( col = 0 ; col < lx ; col++ )
     {
         n_found_lines[col] = 0 ;
-        sum = 0. ;
+        float sum = 0. ;
         for ( i = 0 ; i < ly ; i++ )
         {
             if (isnan(pdata[col + i*lx]) )
@@ -729,8 +735,8 @@ int sinfo_new_find_lines(cpl_image * lineImage,
         }
 
         /* do the cross sinfo_new_correlitioation */
-        position = INT32_MAX ;
-        position = sinfo_new_correlation(column+5, conv_lines+5, ly-10 ) ; 
+        //int position = INT32_MAX ;
+        int position = sinfo_new_correlation(column+5, conv_lines+5, ly-10 ) ;
         if ( abs (position) > ly / 4 )
         {
             sinfo_msg_warning(" sorry, shift of artificial data relative to"
@@ -836,7 +842,7 @@ int sinfo_new_find_lines(cpl_image * lineImage,
 @param  lineCenter 
 @param lineIntensity
  */
-
+/* TODO: not used */
 int 
 sinfo_new_read_list( char * listname, 
                      float * lineCenter, 
@@ -1232,9 +1238,9 @@ float sinfo_new_polyfit( FitParams ** par,
     float * weight, * resid ;
     float * newlam, * newpos, * newwet ;
     float * wcoefs=NULL ;
-    float chisq, result ;
+    float chisq;
     float offset ;
-    int num, found ;
+    int num;
     int i, j, k, n ;
 
     /* reset the fit coefficients and their errors */
@@ -1298,7 +1304,7 @@ float sinfo_new_polyfit( FitParams ** par,
     n = 0 ;
     for ( i = 0 ; i < (par[0] -> n_params) ; i ++ )
     {
-        found = -1 ;
+        int found = -1 ;
         /* find the given column and go through the lines in that column */
         for ( j = 0 ; j < n_lines ; j ++ )
         {
@@ -1389,7 +1395,7 @@ float sinfo_new_polyfit( FitParams ** par,
     j = 0 ;
     for ( i = 0 ; i < num ; i++ )
     {
-        result = 0. ;
+        float result = 0. ;
         for ( k = 0 ; k < n_fitcoefs ; k++ )
         {
             result += acoefs[k] * pow(posit[i], k) ;
@@ -1475,7 +1481,7 @@ float sinfo_new_coefs_cross_fit ( int      n_columns,
                                   int      n_fitcoefs,
                                   float    sigma_factor )
 {
-    float col_index;
+
     float* sub_col_index=NULL ;
     float* sub_acoefs=NULL ;
     float* sub_dacoefs=NULL ;
@@ -1580,7 +1586,7 @@ float sinfo_new_coefs_cross_fit ( int      n_columns,
     for ( i = 0 ; i < n_columns ; i++ )
     {
         /* associate the column indices to the corresponding array */
-        col_index = (float) i ;
+        float col_index = (float) i ;
 
         /* take only the reasonnable coefficients */
         if ( !isnan(acoefs[i]) && 
@@ -1599,7 +1605,10 @@ float sinfo_new_coefs_cross_fit ( int      n_columns,
     {
         sinfo_msg_error("not enough data found to determine "
                         "the fit coefficients.\n") ;
-
+        cpl_free(wcoefs) ;
+        cpl_free(sub_dacoefs) ;
+        cpl_free(sub_col_index) ;
+        cpl_free(sub_acoefs) ;
         return FLT_MAX ;
     }
 
@@ -1659,7 +1668,7 @@ float sinfo_new_coefs_cross_fit ( int      n_columns,
                    associating a wavelength value to 
      each pixel by using the fit coefficients determined before.
  */
-
+/* TODO: not used */
 cpl_image * sinfo_new_wave_map( cpl_image * lineImage,
                                 float   ** bcoefs,
                                 int        n_a_fitcoefs,
@@ -1673,11 +1682,11 @@ cpl_image * sinfo_new_wave_map( cpl_image * lineImage,
     float cenpos, cenpix ;
     float centreval, centrepix, wavelag ;
     float  pixvalue ;
-    float a_initial ;
+
     int i, j, k, l/*, m*/, line, col, row, found, sign ;
     int var, maxlag, cmin, cmax, offset ;
     double * result ;
-    float col_off ;
+
     float angst ;
     double xcorr_max ;
     int delta ;
@@ -1779,7 +1788,7 @@ cpl_image * sinfo_new_wave_map( cpl_image * lineImage,
         {
             emline[i] = 0. ;
         }
-        col_off = (float)col - (float)(ilx-1)/2. ;
+        float col_off = (float)col - (float)(ilx-1)/2. ;
 
         /* determine the coefficients by using the given bcoefs */
         for ( i = 0 ; i < n_a_fitcoefs ; i++ ) 
@@ -1796,7 +1805,7 @@ cpl_image * sinfo_new_wave_map( cpl_image * lineImage,
                 a[i] += bcoefs[i][j] * pow(col_off, j) ;
             }
         }
-        a_initial = a[0] ;
+        float a_initial = a[0] ;
 
         /* go through the lines and generate an artificial spectrum */
         for ( line = 0 ; line < n_lines ; line++ )
@@ -2038,7 +2047,7 @@ cpl_image * sinfo_new_wave_map( cpl_image * lineImage,
      or an image convolved with an
      appropriate function in spectral direction)
  */
-
+/* TODO: not used */
 int sinfo_new_wavelength_calibration( cpl_image   * image,
                                       FitParams ** par ,
                                       float     ** bcoefs,
@@ -2066,8 +2075,8 @@ int sinfo_new_wavelength_calibration( cpl_image   * image,
     float     *  dacoefs ;
     float     ** abuf ;
     float     ** dabuf ;
-    float        chisq_poly, chisq_cross ;
-    int          zeroind ;
+
+
     /*float     *  mem ;*/
     int lx=0;
     int ly=0;
@@ -2209,7 +2218,8 @@ int sinfo_new_wavelength_calibration( cpl_image   * image,
 
     for ( i = 0 ; i < lx ; i++ )
     {
-        zeroind = 0 ;
+        int zeroind = 0 ;
+        float chisq_poly;
         if ( FLT_MAX == (chisq_poly = sinfo_new_polyfit( par, i, 
                         n_found_lines[i],
                         ly, dispersion,
@@ -2254,6 +2264,7 @@ int sinfo_new_wavelength_calibration( cpl_image   * image,
     /* fit each acoefs across the columns to smooth the result */
     for ( i = 0 ; i < n_a_fitcoefs ; i++ )
     {
+        float chisq_cross;
         if ( FLT_MAX == (chisq_cross = sinfo_new_coefs_cross_fit(lx, 
                         abuf[i],
                         dabuf[i],
@@ -2425,8 +2436,6 @@ cpl_image * sinfo_new_defined_resampling( cpl_image * image,
                                           int    * centralpix )
 {
     cpl_image * retImage ;
-    cpl_image * tempCalImage ;
-    cpl_image * tempImage ;
     float lambda ;
     float dif, lambda_renorm ;
     float * retimagecol = NULL;//[2560] ; /* retimagecol[n_rows] ; */
@@ -2436,13 +2445,13 @@ cpl_image * sinfo_new_defined_resampling( cpl_image * image,
     float* x_renorm=NULL ;
 
     float * imageptr ;
-    float sum, new_sum ;
+    float new_sum ;
     float disp, mindisp ;
     int *calcolpos=NULL;//[2560];
     int i/*, j*/, col, row, testrow ;
     int half_width, firstpos ;
     int dispInd ;
-    int n ;
+
     int flag;
     float temprow;
     float minLambda = 0. ;
@@ -2450,7 +2459,7 @@ cpl_image * sinfo_new_defined_resampling( cpl_image * image,
     /*double * polycoeffs ;*/
     double poly ;
     /*float error;*/
-    int zeroind ;
+
     int ilx=0;
     int ily=0;
     int clx=0;
@@ -2541,6 +2550,9 @@ cpl_image * sinfo_new_defined_resampling( cpl_image * image,
     if ( dispInd == 0 )
     {
         sinfo_msg_error(" zero dispersion?\n");
+        cpl_free(imagecol) ;
+        cpl_free(calcol) ;
+        cpl_free(x_renorm) ;
         return NULL ;
     }
 
@@ -2550,12 +2562,14 @@ cpl_image * sinfo_new_defined_resampling( cpl_image * image,
     {
 
         /* allocate a temp image */
+        cpl_image* tempCalImage=NULL;
         if ( NULL == ( tempCalImage = cpl_image_new(clx,cly,CPL_TYPE_FLOAT)))
         {
             sinfo_msg_error(" cannot allocate a new image\n");
             return NULL ;
         }
         ptcdata=cpl_image_get_data_float(tempCalImage);
+        cpl_image* tempImage=NULL;
         if ( NULL == ( tempImage = cpl_image_new( ilx, ily,CPL_TYPE_FLOAT)))
         {
             sinfo_msg_error(" cannot allocate a new image\n");
@@ -2566,7 +2580,7 @@ cpl_image * sinfo_new_defined_resampling( cpl_image * image,
 
         for ( col = 0 ; col < clx ; col++ )
         {
-            n = cly - 1 ;
+            int n = cly - 1 ;
             for ( row = 0 ; row < cly ; row++ )
             {
                 ptcdata[col+row*clx] = pcdata[col+n*clx] ;
@@ -2708,15 +2722,23 @@ cpl_image * sinfo_new_defined_resampling( cpl_image * image,
     olx=cpl_image_get_size_x(retImage);
     oly=cpl_image_get_size_y(retImage);
     /* now go through the columns */
+    /* OLD setting: this later on would hit the size of imagecol,
+     * calcolpos arrays as raw,testraw can go upt to oly>n_rows
+     * for this reason we oversize the arrays retimagecol,calcolpos
     retimagecol = cpl_malloc(*n_rows * sizeof(retimagecol[0]));
-    calcolpos = cpl_malloc(*n_rows * sizeof(calcolpos[0]));    
+    calcolpos = cpl_malloc(*n_rows * sizeof(calcolpos[0]));
+    */
+
+    retimagecol = cpl_malloc(oly * sizeof(retimagecol[0]));
+    calcolpos = cpl_malloc(oly * sizeof(calcolpos[0]));
+
     for ( col = 0 ; col < olx ; col++ )
     {
         /*------------------------------------------------------------------ 
          * copy the columns of the source image and the wavemap image into
          * buffer arrays to speed things up
          */
-        sum = 0. ;
+        float sum = 0. ;
         for ( row = 0 ; row < ily ; row++ )
         {
             imagecol[row] = pidata[col + row*ilx] ; 
@@ -2740,7 +2762,7 @@ cpl_image * sinfo_new_defined_resampling( cpl_image * image,
                 calcolpos[(int) temprow]  = row;
         }
 
-        zeroind = 0 ;
+        int zeroind = 0 ;
 
 
         for ( row = 0 ; row < oly ; row++ )
@@ -2779,8 +2801,8 @@ cpl_image * sinfo_new_defined_resampling( cpl_image * image,
                     calcolpos[row]=calcolpos[row]-1;
                 }
             }
-            testrow = calcolpos[row];
 
+            testrow = calcolpos[row];
             /*-----------------------------------------------------------------
              * at this point calcol[testrow-1] < lambda <= calcol[testrow] 
              * now determine the box position in which the polint fit is 
