@@ -75,24 +75,19 @@ sinfo_cube_gen_gauss2d_with_noise(const int sx,
 {
 
   int z=0;
-  cpl_imagelist* cube=NULL;
-  cpl_image* img_o=NULL;
-  cpl_image* img_s=NULL;
   double a0=1;
   double a1=-2;
   double a2=1;
   double x=100;
-  double y=0;
-
   char name[SIZE];
 
   sinfo_msg_warning("Prepare data cube with 2D Gauss");
  
-  cube=cpl_imagelist_new();
+  cpl_imagelist* cube=cpl_imagelist_new();
   for(z=0;z<sz;z++) {
-    y =a0+a1*x*z+a2*x*z*z;
-    img_o=cpl_image_new(sx,sy,CPL_TYPE_FLOAT);
-    img_s=cpl_image_new(sx,sy,CPL_TYPE_FLOAT);
+    double y =a0+a1*x*z+a2*x*z*z;
+    cpl_image* img_o=cpl_image_new(sx,sy,CPL_TYPE_FLOAT);
+    cpl_image* img_s=cpl_image_new(sx,sy,CPL_TYPE_FLOAT);
     cpl_image_fill_gaussian(img_o,xc,yc,y,sigx,sigy);
     cpl_image_fill_noise_uniform(img_s,min_noise,max_noise);
     cpl_image_add(img_o,img_s);
